@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -123,12 +123,12 @@ public class ProgrammingError extends RuntimeException implements EffectiveThrow
         super(cause);
     }
 
-    ProgrammingError() {
-        super();
+    protected ProgrammingError(final String message, final Throwable cause) {
+        super(message, cause);
     }
 
-    ProgrammingError(final String message, final Throwable cause) {
-        super(message, cause);
+    ProgrammingError() {
+        super();
     }
 
     ProgrammingError(final String message, final Throwable cause, final boolean enableSuppression, final boolean writableStackTrace) {
