@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,11 +24,10 @@ package org.ojalgo.array;
 import java.math.BigDecimal;
 import java.util.AbstractList;
 import java.util.RandomAccess;
-import java.util.concurrent.ExecutionException;
-import java.util.concurrent.ForkJoinPool;
-import java.util.concurrent.RecursiveAction;
+import java.util.function.Supplier;
 
 import org.ojalgo.ProgrammingError;
+import org.ojalgo.array.BasicArray.BaseFactory;
 import org.ojalgo.function.BinaryFunction;
 import org.ojalgo.function.FunctionSet;
 import org.ojalgo.function.NullaryFunction;
@@ -58,28 +57,29 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
 
     public static final class Factory<N extends Comparable<N>> implements Factory1D.MayBeSparse<Array1D<N>, Array1D<N>, Array1D<N>> {
 
-        private final BasicArray.Factory<N> myDelegate;
+        private transient BasicArray.Factory<N> myDelegate = null;
+        private final Supplier<BasicArray.Factory<N>> myDelegateSupplier;
 
-        Factory(final DenseArray.Factory<N> denseArray) {
+        Factory(final DenseArray.Factory<N, ?> denseArray) {
             super();
-            myDelegate = new BasicArray.Factory<>(denseArray);
+            myDelegateSupplier = () -> new BasicArray.Factory<>(denseArray);
         }
 
         @Override
         public Array1D<N> copy(final Access1D<?> source) {
-            BasicArray<N> basic = myDelegate.make(source.count());
+            BasicArray<N> basic = this.delegate().make(source.count());
             basic.fillMatching(source);
             return basic.wrapInArray1D();
         }
 
         @Override
         public FunctionSet<N> function() {
-            return myDelegate.function();
+            return this.delegate().function();
         }
 
         @Override
         public MathType getMathType() {
-            return myDelegate.getMathType();
+            return this.delegate().getMathType();
         }
 
         @Override
@@ -94,24 +94,24 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
 
         @Override
         public Array1D<N> makeFilled(final long count, final NullaryFunction<?> supplier) {
-            BasicArray<N> basic = myDelegate.make(count);
+            BasicArray<N> basic = this.delegate().make(count);
             basic.fillAll(supplier);
             return basic.wrapInArray1D();
         }
 
         @Override
         public Array1D<N> newDenseBuilder(final long count) {
-            return myDelegate.makeToBeFilled(count).wrapInArray1D();
+            return this.delegate().makeToBeFilled(count).wrapInArray1D();
         }
 
         @Override
         public Array1D<N> newSparseBuilder(final long count) {
-            return myDelegate.makeStructuredZero(count).wrapInArray1D();
+            return this.delegate().makeStructuredZero(count).wrapInArray1D();
         }
 
         @Override
         public Scalar.Factory<N> scalar() {
-            return myDelegate.scalar();
+            return this.delegate().scalar();
         }
 
         public TensorFactory1D<N, Array1D<N>> tensor() {
@@ -122,130 +122,11 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
             return array.wrapInArray1D();
         }
 
-    }
-
-    static final class QuickAscendingSorter extends RecursiveAction {
-
-        private static final long serialVersionUID = 1L;
-
-        private final long high;
-        private final long low;
-        private final Array1D<?> myArray;
-
-        private QuickAscendingSorter(final Array1D<?> array, final long low, final long high) {
-            super();
-            myArray = array;
-            this.low = low;
-            this.high = high;
-        }
-
-        QuickAscendingSorter(final Array1D<?> array) {
-            this(array, 0L, array.count() - 1L);
-        }
-
-        @Override
-        protected void compute() {
-
-            long i = low, j = high;
-
-            double pivot = myArray.doubleValue(low + (high - low) / 2);
-
-            while (i <= j) {
-
-                while (myArray.doubleValue(i) < pivot) {
-                    i++;
-                }
-                while (myArray.doubleValue(j) > pivot) {
-                    j--;
-                }
-
-                if (i <= j) {
-                    myArray.exchange(i, j);
-                    i++;
-                    j--;
-                }
-            }
-
-            QuickAscendingSorter tmpPartL = null;
-            QuickAscendingSorter tmpPartH = null;
-
-            if (low < j) {
-                tmpPartL = new QuickAscendingSorter(myArray, low, j);
-                tmpPartL.fork();
-            }
-            if (i < high) {
-                tmpPartH = new QuickAscendingSorter(myArray, i, high);
-                tmpPartH.fork();
-            }
-            if (tmpPartL != null) {
-                tmpPartL.join();
-            }
-            if (tmpPartH != null) {
-                tmpPartH.join();
-            }
-        }
-
-    }
-
-    static final class QuickDescendingSorter extends RecursiveAction {
-
-        private static final long serialVersionUID = 1L;
-
-        private final long high;
-        private final long low;
-        private final Array1D<?> myArray;
-
-        private QuickDescendingSorter(final Array1D<?> array, final long low, final long high) {
-            super();
-            myArray = array;
-            this.low = low;
-            this.high = high;
-        }
-
-        QuickDescendingSorter(final Array1D<?> array) {
-            this(array, 0L, array.count() - 1L);
-        }
-
-        @Override
-        protected void compute() {
-
-            long i = low, j = high;
-
-            double pivot = myArray.doubleValue(low + (high - low) / 2);
-
-            while (i <= j) {
-
-                while (myArray.doubleValue(i) > pivot) {
-                    i++;
-                }
-                while (myArray.doubleValue(j) < pivot) {
-                    j--;
-                }
-
-                if (i <= j) {
-                    myArray.exchange(i, j);
-                    i++;
-                    j--;
-                }
-            }
-
-            QuickDescendingSorter tmpPartL = null;
-            QuickDescendingSorter tmpPartH = null;
-
-            if (low < j) {
-                tmpPartL = new QuickDescendingSorter(myArray, low, j);
-                tmpPartL.fork();
-            }
-            if (i < high) {
-                tmpPartH = new QuickDescendingSorter(myArray, i, high);
-                tmpPartH.fork();
-            }
-            if (tmpPartL != null) {
-                tmpPartL.join();
-            }
-            if (tmpPartH != null) {
-                tmpPartH.join();
+        private BasicArray.Factory<N> delegate() {
+            if (myDelegate == null) {
+                myDelegate = myDelegateSupplier.get();
             }
+            return myDelegate;
         }
 
     }
@@ -262,7 +143,7 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
     public static final Factory<Double> Z032 = Array1D.factory(ArrayZ032.FACTORY);
     public static final Factory<Double> Z064 = Array1D.factory(ArrayZ064.FACTORY);
 
-    public static <N extends Comparable<N>> Array1D.Factory<N> factory(final DenseArray.Factory<N> denseFactory) {
+    public static <N extends Comparable<N>> Array1D.Factory<N> factory(final DenseArray.Factory<N, ?> denseFactory) {
         return new Array1D.Factory<>(denseFactory);
     }
 
@@ -290,6 +171,36 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
         length = (myLimit - myFirst) / myStep;
     }
 
+    @Override
+    public void add(final int index, final byte addend) {
+        myDelegate.add(this.convert(index), addend);
+    }
+
+    @Override
+    public void add(final int index, final double addend) {
+        myDelegate.add(this.convert(index), addend);
+    }
+
+    @Override
+    public void add(final int index, final float addend) {
+        myDelegate.add(this.convert(index), addend);
+    }
+
+    @Override
+    public void add(final int index, final int addend) {
+        myDelegate.add(this.convert(index), addend);
+    }
+
+    @Override
+    public void add(final int index, final long addend) {
+        myDelegate.add(this.convert(index), addend);
+    }
+
+    @Override
+    public void add(final int index, final short addend) {
+        myDelegate.add(this.convert(index), addend);
+    }
+
     @Override
     public void add(final long index, final byte addend) {
         myDelegate.add(this.convert(index), addend);
@@ -674,13 +585,7 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
 
         } else {
 
-            //this.sortAscending(0L, this.count() - 1L);
-
-            try {
-                ForkJoinPool.commonPool().submit(new QuickAscendingSorter(this)).get();
-            } catch (InterruptedException | ExecutionException exception) {
-                exception.printStackTrace();
-            }
+            this.sortAscending(0L, this.count() - 1L);
         }
     }
 
@@ -693,13 +598,7 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
 
         } else {
 
-            //this.sortDescending(0L, this.count() - 1L);
-
-            try {
-                ForkJoinPool.commonPool().submit(new QuickDescendingSorter(this)).get();
-            } catch (InterruptedException | ExecutionException exception) {
-                exception.printStackTrace();
-            }
+            this.sortDescending(0L, this.count() - 1L);
         }
     }
 
@@ -769,7 +668,7 @@ public final class Array1D<N extends Comparable<N>> extends AbstractList<N> impl
 
         return new Factory1D<>() {
 
-            ArrayFactory<N, ?> delegate = myDelegate.factory();
+            BaseFactory<N, ?> delegate = myDelegate.factory();
 
             public FunctionSet<?> function() {
                 return delegate.function();
