@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,8 +22,10 @@
 package org.ojalgo.array;
 
 import java.math.BigDecimal;
+import java.util.function.Supplier;
 
 import org.ojalgo.ProgrammingError;
+import org.ojalgo.array.BasicArray.BaseFactory;
 import org.ojalgo.function.BinaryFunction;
 import org.ojalgo.function.FunctionSet;
 import org.ojalgo.function.NullaryFunction;
@@ -56,28 +58,29 @@ public final class Array2D<N extends Comparable<N>>
 
     public static final class Factory<N extends Comparable<N>> implements Factory2D.MayBeSparse<Array2D<N>, Array2D<N>, Array2D<N>> {
 
-        private final BasicArray.Factory<N> myDelegate;
+        private transient BasicArray.Factory<N> myDelegate = null;
+        private final Supplier<BasicArray.Factory<N>> myDelegateSupplier;
 
-        Factory(final DenseArray.Factory<N> denseArray) {
+        Factory(final DenseArray.Factory<N, ?> denseArray) {
             super();
-            myDelegate = new BasicArray.Factory<>(denseArray);
+            myDelegateSupplier = () -> new BasicArray.Factory<>(denseArray);
         }
 
         @Override
         public Array2D<N> copy(final Access2D<?> source) {
-            BasicArray<N> basic = myDelegate.make(source.count());
+            BasicArray<N> basic = this.delegate().make(source.count());
             basic.fillMatching(source);
             return basic.wrapInArray2D(source.countRows());
         }
 
         @Override
         public FunctionSet<N> function() {
-            return myDelegate.function();
+            return this.delegate().function();
         }
 
         @Override
         public MathType getMathType() {
-            return myDelegate.getMathType();
+            return this.delegate().getMathType();
         }
 
         @Override
@@ -92,30 +95,37 @@ public final class Array2D<N extends Comparable<N>>
 
         @Override
         public Array2D<N> makeFilled(final long rows, final long columns, final NullaryFunction<?> supplier) {
-            BasicArray<N> basic = myDelegate.makeToBeFilled(rows, columns);
+            BasicArray<N> basic = this.delegate().makeToBeFilled(rows, columns);
             basic.fillAll(supplier);
             return basic.wrapInArray2D(rows);
         }
 
         @Override
         public Array2D<N> newDenseBuilder(final long nbRows, final long nbCols) {
-            return myDelegate.makeToBeFilled(nbRows, nbCols).wrapInArray2D(nbRows);
+            return this.delegate().makeToBeFilled(nbRows, nbCols).wrapInArray2D(nbRows);
         }
 
         @Override
         public Array2D<N> newSparseBuilder(final long nbRows, final long nbCols) {
-            return myDelegate.makeStructuredZero(nbRows, nbCols).wrapInArray2D(nbRows);
+            return this.delegate().makeStructuredZero(nbRows, nbCols).wrapInArray2D(nbRows);
         }
 
         @Override
         public Scalar.Factory<N> scalar() {
-            return myDelegate.scalar();
+            return this.delegate().scalar();
         }
 
         public TensorFactory2D<N, Array2D<N>> tensor() {
             return TensorFactory2D.of(this);
         }
 
+        private BasicArray.Factory<N> delegate() {
+            if (myDelegate == null) {
+                myDelegate = myDelegateSupplier.get();
+            }
+            return myDelegate;
+        }
+
     }
 
     public static final Factory<ComplexNumber> C128 = Array2D.factory(ArrayC128.FACTORY);
@@ -130,7 +140,7 @@ public final class Array2D<N extends Comparable<N>>
     public static final Factory<Double> Z032 = Array2D.factory(ArrayZ032.FACTORY);
     public static final Factory<Double> Z064 = Array2D.factory(ArrayZ064.FACTORY);
 
-    public static <N extends Comparable<N>> Array2D.Factory<N> factory(final DenseArray.Factory<N> denseArray) {
+    public static <N extends Comparable<N>> Array2D.Factory<N> factory(final DenseArray.Factory<N, ?> denseArray) {
         return new Array2D.Factory<>(denseArray);
     }
 
@@ -148,6 +158,16 @@ public final class Array2D<N extends Comparable<N>>
         myColumnsCount = structure == 0L ? 0L : delegate.count() / structure;
     }
 
+    @Override
+    public void add(final int index, final double addend) {
+        myDelegate.add(index, addend);
+    }
+
+    @Override
+    public void add(final int index, final float addend) {
+        myDelegate.add(index, addend);
+    }
+
     @Override
     public void add(final long index, final byte addend) {
         myDelegate.add(index, addend);
@@ -861,7 +881,7 @@ public final class Array2D<N extends Comparable<N>>
 
         return new Factory2D<>() {
 
-            ArrayFactory<N, ?> delegate = myDelegate.factory();
+            BaseFactory<N, ?> delegate = myDelegate.factory();
 
             public FunctionSet<?> function() {
                 return delegate.function();
