@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -27,12 +27,7 @@ import java.util.Comparator;
 
 import org.ojalgo.array.operation.AMAX;
 import org.ojalgo.array.operation.AXPY;
-import org.ojalgo.function.BigFunction;
-import org.ojalgo.function.FunctionSet;
-import org.ojalgo.function.aggregator.AggregatorSet;
-import org.ojalgo.function.aggregator.BigAggregator;
 import org.ojalgo.scalar.BigScalar;
-import org.ojalgo.scalar.Scalar;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Mutate1D;
 import org.ojalgo.type.math.MathType;
@@ -44,37 +39,18 @@ import org.ojalgo.type.math.MathType;
  */
 public class ArrayR256 extends ReferenceTypeArray<BigDecimal> {
 
-    public static final DenseArray.Factory<BigDecimal> FACTORY = new DenseArray.Factory<>() {
+    public static final ReferenceTypeArray.Factory<BigDecimal> FACTORY = new ReferenceTypeArray.Factory<>(MathType.R256) {
 
-        @Override
-        public AggregatorSet<BigDecimal> aggregator() {
-            return BigAggregator.getSet();
-        }
-
-        @Override
-        public FunctionSet<BigDecimal> function() {
-            return BigFunction.getSet();
-        }
-
-        @Override
-        public MathType getMathType() {
-            return MathType.R128;
-        }
-
-        @Override
-        public Scalar.Factory<BigDecimal> scalar() {
-            return BigScalar.FACTORY;
-        }
-
-        @Override
-        PlainArray<BigDecimal> makeDenseArray(final long size) {
-            return ArrayR256.make((int) size);
+        public ArrayR256 make(final int size) {
+            return ArrayR256.make(size);
         }
 
     };
 
     public static ArrayR256 make(final int size) {
-        return new ArrayR256(size);
+        BigDecimal[] data = new BigDecimal[size];
+        Arrays.fill(data, BigDecimal.ZERO);
+        return new ArrayR256(data);
     }
 
     public static ArrayR256 wrap(final BigDecimal... data) {
@@ -85,8 +61,9 @@ public class ArrayR256 extends ReferenceTypeArray<BigDecimal> {
         super(FACTORY, data);
     }
 
-    protected ArrayR256(final int size) {
-        super(FACTORY, size);
+    @Override
+    public void add(final int index, final double addend) {
+        this.fillOne(index, this.get(index).add(this.valueOf(addend)));
     }
 
     @Override
@@ -131,12 +108,12 @@ public class ArrayR256 extends ReferenceTypeArray<BigDecimal> {
 
     @Override
     public void sortAscending() {
-        Arrays.parallelSort(data);
+        Arrays.sort(data);
     }
 
     @Override
     public void sortDescending() {
-        Arrays.parallelSort(data, Comparator.reverseOrder());
+        Arrays.sort(data, Comparator.reverseOrder());
     }
 
     @Override
@@ -144,11 +121,6 @@ public class ArrayR256 extends ReferenceTypeArray<BigDecimal> {
         this.fillOne(index, this.get(index).add(this.valueOf(addend)));
     }
 
-    @Override
-    protected void add(final int index, final double addend) {
-        this.fillOne(index, this.get(index).add(this.valueOf(addend)));
-    }
-
     @Override
     protected void fillOne(final int index, final Access1D<?> values, final long valueIndex) {
         data[index] = this.valueOf(values.get(valueIndex));
