@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -31,13 +31,9 @@ import org.ojalgo.array.operation.OperationBinary;
 import org.ojalgo.array.operation.OperationUnary;
 import org.ojalgo.array.operation.OperationVoid;
 import org.ojalgo.function.BinaryFunction;
-import org.ojalgo.function.FunctionSet;
 import org.ojalgo.function.NullaryFunction;
-import org.ojalgo.function.PrimitiveFunction;
 import org.ojalgo.function.UnaryFunction;
 import org.ojalgo.function.VoidFunction;
-import org.ojalgo.function.aggregator.AggregatorSet;
-import org.ojalgo.function.aggregator.PrimitiveAggregator;
 import org.ojalgo.scalar.PrimitiveScalar;
 import org.ojalgo.scalar.Scalar;
 import org.ojalgo.structure.Access1D;
@@ -51,37 +47,16 @@ import org.ojalgo.type.math.MathType;
  */
 public class ArrayZ016 extends PrimitiveArray {
 
-    public static final DenseArray.Factory<Double> FACTORY = new DenseArray.Factory<>() {
+    public static final PrimitiveArray.Factory FACTORY = new PrimitiveArray.Factory(MathType.Z016) {
 
         @Override
-        public AggregatorSet<Double> aggregator() {
-            return PrimitiveAggregator.getSet();
+        public ArrayZ016 make(final int size) {
+            return ArrayZ016.make(size);
         }
-
-        @Override
-        public FunctionSet<Double> function() {
-            return PrimitiveFunction.getSet();
-        }
-
-        @Override
-        public MathType getMathType() {
-            return MathType.Z016;
-        }
-
-        @Override
-        public Scalar.Factory<Double> scalar() {
-            return PrimitiveScalar.FACTORY;
-        }
-
-        @Override
-        PlainArray<Double> makeDenseArray(final long size) {
-            return ArrayZ016.make((int) size);
-        }
-
     };
 
     public static ArrayZ016 make(final int size) {
-        return new ArrayZ016(size);
+        return new ArrayZ016(new short[size]);
     }
 
     public static ArrayZ016 wrap(final short... data) {
@@ -90,13 +65,6 @@ public class ArrayZ016 extends PrimitiveArray {
 
     public final short[] data;
 
-    protected ArrayZ016(final int size) {
-
-        super(FACTORY, size);
-
-        data = new short[size];
-    }
-
     /**
      * Array not copied! No checking!
      */
@@ -107,6 +75,16 @@ public class ArrayZ016 extends PrimitiveArray {
         this.data = data;
     }
 
+    @Override
+    public void add(final int index, final double addend) {
+        data[index] += (short) Math.round(addend);
+    }
+
+    @Override
+    public void add(final int index, final short addend) {
+        data[index] += addend;
+    }
+
     @Override
     public byte byteValue(final int index) {
         return (byte) data[index];
@@ -159,13 +137,13 @@ public class ArrayZ016 extends PrimitiveArray {
 
     @Override
     public void sortAscending() {
-        Arrays.parallelSort(data);
+        Arrays.sort(data);
     }
 
     @Override
     public void sortDescending() {
         CorePrimitiveOperation.negate(data, 0, data.length, 1, data);
-        Arrays.parallelSort(data);
+        Arrays.sort(data);
         CorePrimitiveOperation.negate(data, 0, data.length, 1, data);
     }
 
@@ -174,16 +152,6 @@ public class ArrayZ016 extends PrimitiveArray {
         data[index] += NumberDefinition.shortValue(addend);
     }
 
-    @Override
-    protected void add(final int index, final double addend) {
-        data[index] += (short) Math.round(addend);
-    }
-
-    @Override
-    protected void add(final int index, final short addend) {
-        data[index] += addend;
-    }
-
     @Override
     protected void exchange(final int firstA, final int firstB, final int step, final int count) {
         Exchange.exchange(data, firstA, firstB, step, count);
