@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -51,43 +51,80 @@ import org.ojalgo.structure.Mutate1D;
  */
 public final class NumberList<N extends Comparable<N>> implements List<N>, RandomAccess, Access1D<N>, Access1D.Visitable<N>, Mutate1D, Mutate1D.Mixable<N> {
 
-    public static final class ListFactory<N extends Comparable<N>> extends StrategyBuildingFactory<N, NumberList<N>, ListFactory<N>> {
+    public static final class ListFactory<N extends Comparable<N>> {
 
-        ListFactory(final DenseArray.Factory<N> denseFactory) {
-            super(denseFactory);
+        private GrowthStrategy myGrowthStrategy;
+        private final DenseArray.Factory<N, ?> myDenseFactory;
+
+        ListFactory(final DenseArray.Factory<N, ?> denseFactory) {
+            myGrowthStrategy = GrowthStrategy.from(denseFactory.getMathType());
+            myDenseFactory = denseFactory;
+        }
+
+        /**
+         * @param chunk Defines a capacity break point. Below this point the capacity is doubled when needed.
+         *              Above it, it is grown by adding one "chunk" at the time. Must be a power of 2. (The
+         *              builder will enforce that for you.)
+         * @return this
+         */
+        public ListFactory<N> chunk(final long chunk) {
+            myGrowthStrategy = myGrowthStrategy.chunk(chunk);
+            return this;
+        }
+
+        /**
+         * @param initial Sets the initial capacity of the "arrays" to be created using this factory.
+         * @return this
+         */
+        public ListFactory<N> initial(final long initial) {
+            myGrowthStrategy = myGrowthStrategy.initial(initial);
+            return this;
         }
 
         public NumberList<N> make() {
-            return new NumberList<>(this.getDenseFactory(), this.getGrowthStrategy());
+            return new NumberList<>(myDenseFactory, myGrowthStrategy);
+        }
+
+        /**
+         * With very large data structures, particularly sparse ones, the underlying (dense) storage is
+         * segmented. (Very large arrays are implemented as an array of arrays.) This determines the
+         * size/length of one such segment. Must be a multiple of the chunk size as well as a power of 2. (The
+         * builder will enforce this for you.)
+         */
+        public ListFactory<N> segment(final long segment) {
+            myGrowthStrategy = myGrowthStrategy.segment(segment);
+            return this;
         }
 
     }
 
-    public static <N extends Comparable<N>> Collector<N, NumberList<N>, NumberList<N>> collector(final DenseArray.Factory<N> arrayFactory) {
-        final Supplier<NumberList<N>> tmpSupplier = () -> NumberList.factory(arrayFactory).make();
-        final BiConsumer<NumberList<N>, N> tmpAccumulator = NumberList::add;
-        final BinaryOperator<NumberList<N>> tmpCombiner = (part1, part2) -> {
+    public static <N extends Comparable<N>> Collector<N, NumberList<N>, NumberList<N>> collector(final DenseArray.Factory<N, ?> arrayFactory) {
+
+        Supplier<NumberList<N>> supplier = () -> NumberList.factory(arrayFactory).make();
+        BiConsumer<NumberList<N>, N> accumulator = NumberList::add;
+        BinaryOperator<NumberList<N>> combiner = (part1, part2) -> {
             part1.addAll(part2);
             return part1;
         };
-        final Function<NumberList<N>, NumberList<N>> tmpIdentity = Function.identity();
-        return Collector.of(tmpSupplier, tmpAccumulator, tmpCombiner, tmpIdentity, Collector.Characteristics.IDENTITY_FINISH);
+        Function<NumberList<N>, NumberList<N>> finisher = Function.identity();
+
+        return Collector.of(supplier, accumulator, combiner, finisher, Collector.Characteristics.IDENTITY_FINISH);
     }
 
-    public static <N extends Comparable<N>> ListFactory<N> factory(final DenseArray.Factory<N> arrayFactory) {
+    public static <N extends Comparable<N>> ListFactory<N> factory(final DenseArray.Factory<N, ?> arrayFactory) {
         return new ListFactory<>(arrayFactory);
     }
 
     private long myActualCount;
-    private final DenseArray.Factory<N> myDenseFactory;
+    private final DenseArray.Factory<N, ?> myDenseFactory;
     private final GrowthStrategy myGrowthStrategy;
     private BasicArray<N> myStorage;
 
-    NumberList(final DenseArray.Factory<N> denseFactory, final GrowthStrategy growthStrategy) {
-        this(denseFactory, growthStrategy, growthStrategy.makeInitial(denseFactory), 0L);
+    NumberList(final DenseArray.Factory<N, ?> denseFactory, final GrowthStrategy growthStrategy) {
+        this(denseFactory, growthStrategy, growthStrategy.makeInitial(denseFactory::make), 0L);
     }
 
-    NumberList(final DenseArray.Factory<N> denseFactory, final GrowthStrategy growthStrategy, final BasicArray<N> storage, final long actualCount) {
+    NumberList(final DenseArray.Factory<N, ?> denseFactory, final GrowthStrategy growthStrategy, final BasicArray<N> storage, final long actualCount) {
 
         super();
 
@@ -107,6 +144,15 @@ public final class NumberList<N extends Comparable<N>> implements List<N>, Rando
         return true;
     }
 
+    public boolean add(final float element) {
+
+        this.ensureCapacity();
+
+        myStorage.set(myActualCount++, element);
+
+        return true;
+    }
+
     @Override
     public void add(final int index, final N element) {
 
@@ -474,7 +520,8 @@ public final class NumberList<N extends Comparable<N>> implements List<N>, Rando
             if (myStorage instanceof SegmentedArray) {
                 myStorage = ((SegmentedArray<N>) myStorage).grow();
             } else {
-                myStorage = myDenseFactory.wrapAsSegments(myStorage, myGrowthStrategy.makeChunk(myDenseFactory));
+                BasicArray<N>[] segments = (BasicArray<N>[]) new BasicArray<?>[] { myStorage, myGrowthStrategy.makeChunk(myDenseFactory::make) };
+                myStorage = new SegmentedArray<>(segments, myDenseFactory);
             }
 
         } else {
