@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,7 @@ package org.ojalgo.array;
 import java.math.MathContext;
 import java.util.Arrays;
 import java.util.function.Consumer;
-import java.util.stream.LongStream;
+import java.util.stream.IntStream;
 
 import org.ojalgo.function.BinaryFunction;
 import org.ojalgo.function.NullaryFunction;
@@ -32,10 +32,8 @@ import org.ojalgo.function.UnaryFunction;
 import org.ojalgo.function.VoidFunction;
 import org.ojalgo.function.constant.PrimitiveMath;
 import org.ojalgo.scalar.PrimitiveScalar;
-import org.ojalgo.scalar.Scalar;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.ElementView1D;
-import org.ojalgo.structure.Factory1D;
 import org.ojalgo.structure.Mutate1D;
 import org.ojalgo.structure.Structure1D;
 import org.ojalgo.type.NumberDefinition;
@@ -66,7 +64,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     public interface NonzeroReferenceTypeCallback<N extends Comparable<N>> {
 
         /**
-         * @param index Index
+         * @param index  Index
          * @param number Number (nonzero) at that index
          */
         void call(long index, N number);
@@ -76,11 +74,11 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     public static final class NonzeroView<N extends Comparable<N>> implements ElementView1D<N, NonzeroView<N>> {
 
         private int myCursor = -1;
-        private final long[] myIndices;
+        private final int[] myIndices;
         private final int myLastCursor;
         private final DenseArray<N> myValues;
 
-        private NonzeroView(final long[] indices, final DenseArray<N> values, final int initial, final int last) {
+        private NonzeroView(final int[] indices, final DenseArray<N> values, final int initial, final int last) {
 
             super();
 
@@ -91,7 +89,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
             myLastCursor = last;
         }
 
-        NonzeroView(final long[] indices, final DenseArray<N> values, final int actualLength) {
+        NonzeroView(final int[] indices, final DenseArray<N> values, final int actualLength) {
             this(indices, values, -1, actualLength - 1);
         }
 
@@ -184,84 +182,137 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         @Override
         public NonzeroView<N> trySplit() {
 
-            final int remaining = myLastCursor - myCursor;
+            int remaining = myLastCursor - myCursor;
 
             if (remaining > 1) {
 
-                final int split = myCursor + remaining / 2;
+                int split = myCursor + remaining / 2;
 
-                // BasicLogger.debug("Splitting [{}, {}) into [{}, {}) and [{}, {})", myCursor, myLastCursor, myCursor, split, split, myLastCursor);
+                // BasicLogger.debug("Splitting [{}, {}) into [{}, {}) and [{}, {})", myCursor, myLastCursor,
+                // myCursor, split, split, myLastCursor);
 
-                final NonzeroView<N> retVal = new NonzeroView<>(myIndices, myValues, myCursor, split);
+                NonzeroView<N> retVal = new NonzeroView<>(myIndices, myValues, myCursor, split);
 
                 myCursor = split;
 
                 return retVal;
 
+            } else {
+
+                return null;
             }
-            return null;
         }
 
     }
 
-    public static final class SparseFactory<N extends Comparable<N>> extends StrategyBuildingFactory<N, SparseArray<N>, SparseFactory<N>>
-            implements Factory1D<SparseArray<N>> {
+    public static final class SparseFactory<N extends Comparable<N>> extends BasicArray.BaseFactory<N, BasicArray<N>> {
 
-        SparseFactory(final DenseArray.Factory<N> denseFactory) {
-            super(denseFactory);
+        private GrowthStrategy myGrowthStrategy;
+        private final PlainArray.Factory<N, ?> myPlainFactory;
+
+        SparseFactory(final PlainArray.Factory<N, ?> plainFactory) {
+            super(plainFactory.getMathType());
+            myGrowthStrategy = GrowthStrategy.from(plainFactory.getMathType());
+            myPlainFactory = plainFactory;
+        }
+
+        /**
+         * @param chunk Defines a capacity break point. Below this point the capacity is doubled when needed.
+         *              Above it, it is grown by adding one "chunk" at the time. Must be a power of 2. (The
+         *              builder will enforce that for you.)
+         * @return this
+         */
+        public SparseFactory<N> chunk(final long chunk) {
+            myGrowthStrategy = myGrowthStrategy.chunk(chunk);
+            return this;
+        }
+
+        /**
+         * @param initial Sets the initial capacity of the "arrays" to be created using this factory.
+         * @return this
+         */
+        public SparseFactory<N> initial(final long initial) {
+            myGrowthStrategy = myGrowthStrategy.initial(initial);
+            return this;
         }
 
         @Override
         public SparseArray<N> make(final int size) {
-            return new SparseArray<>(this.getDenseFactory(), this.getGrowthStrategy(), size);
+            return new SparseArray<>(myPlainFactory, myGrowthStrategy, size);
         }
 
         @Override
-        public SparseArray<N> make(final long count) {
-            return new SparseArray<>(this.getDenseFactory(), this.getGrowthStrategy(), count);
+        public BasicArray<N> make(final long count) {
+            if (myGrowthStrategy.isSegmented(count)) {
+                return SegmentedArray.newInstance(this, count);
+            } else {
+                return new SparseArray<>(myPlainFactory, myGrowthStrategy, Math.toIntExact(count));
+            }
+        }
+
+        /**
+         * With very large data structures, particularly sparse ones, the underlying (dense) storage is
+         * segmented. (Very large arrays are implemented as an array of arrays.) This determines the
+         * size/length of one such segment. Must be a multiple of the chunk size as well as a power of 2. (The
+         * builder will enforce this for you.)
+         */
+        public SparseFactory<N> segment(final long segment) {
+            myGrowthStrategy = myGrowthStrategy.segment(segment);
+            return this;
+        }
+
+        @Override
+        long getCapacityLimit() {
+            return Long.MAX_VALUE;
         }
 
     }
 
     private static final NumberContext MATH_CONTEXT = NumberContext.ofMath(MathContext.DECIMAL64);
 
-    public static <N extends Comparable<N>> SparseFactory<N> factory(final DenseArray.Factory<N> denseFactory) {
+    public static <N extends Comparable<N>> SparseFactory<N> factory(final PlainArray.Factory<N, ?> denseFactory) {
         return new SparseFactory<>(denseFactory);
     }
 
     /**
-     * The actual number of nonzwero elements
+     * The number of nonzero elements
      */
     private int myActualLength = 0;
-    private final long myCount;
-    private final DenseArray.Factory<N> myDenseFactory;
+    /**
+     * The capacity
+     */
+    private final int mySize;
+    private final PlainArray.Factory<N, ?> myDenseFactory;
     private final GrowthStrategy myGrowthStrategy;
-    private long[] myIndices;
-    private DenseArray<N> myValues;
-    private final N myZeroNumber;
-    private final Scalar<N> myZeroScalar;
-    private final double myZeroValue;
+    private int[] myIndices;
+    private PlainArray<N> myValues;
 
-    SparseArray(final DenseArray.Factory<N> denseFactory, final GrowthStrategy growthStrategy, final long count) {
+    SparseArray(final PlainArray.Factory<N, ?> denseFactory, final GrowthStrategy growthStrategy, final int size) {
 
         super(denseFactory);
 
-        myCount = count;
+        mySize = size;
 
         myDenseFactory = denseFactory;
         myGrowthStrategy = growthStrategy;
 
-        myIndices = new long[growthStrategy.initial()];
-        myValues = growthStrategy.makeInitial(denseFactory);
+        myIndices = new int[growthStrategy.initial()];
+        myValues = growthStrategy.makeInitial(denseFactory::make);
+    }
 
-        myZeroScalar = denseFactory.scalar().zero();
-        myZeroNumber = myZeroScalar.get();
-        myZeroValue = myZeroScalar.doubleValue();
+    @Override
+    public void add(final int index, final double addend) {
+        int tmpIndex = this.index(index);
+        if (tmpIndex >= 0) {
+            myValues.add(tmpIndex, addend);
+        } else {
+            this.set(index, addend);
+        }
     }
 
     @Override
     public void add(final long index, final Comparable<?> addend) {
-        final int tmpIndex = this.index(index);
+        int tmpIndex = this.index(index);
         if (tmpIndex >= 0) {
             myValues.add(tmpIndex, addend);
         } else {
@@ -271,7 +322,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
 
     @Override
     public void add(final long index, final double addend) {
-        final int tmpIndex = this.index(index);
+        int tmpIndex = this.index(index);
         if (tmpIndex >= 0) {
             myValues.add(tmpIndex, addend);
         } else {
@@ -281,7 +332,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
 
     @Override
     public void add(final long index, final float addend) {
-        final int tmpIndex = this.index(index);
+        int tmpIndex = this.index(index);
         if (tmpIndex >= 0) {
             myValues.add(tmpIndex, addend);
         } else {
@@ -298,7 +349,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
 
     @Override
     public long count() {
-        return myCount;
+        return mySize;
     }
 
     public int countNonzeros() {
@@ -306,7 +357,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     }
 
     public long countZeros() {
-        return myCount - myActualLength;
+        return mySize - myActualLength;
     }
 
     @Override
@@ -324,21 +375,99 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     public double doubleValue(final int index) {
 
-        final int tmpIndex = this.index(index);
+        int tmpIndex = this.index(index);
         if (tmpIndex >= 0) {
             return this.doubleValueInternally(tmpIndex);
+        } else {
+            return PrimitiveMath.ZERO;
         }
-        return myZeroValue;
     }
 
     @Override
     public double doubleValue(final long index) {
 
-        final int tmpIndex = this.index(index);
+        int tmpIndex = this.index(index);
         if (tmpIndex >= 0) {
             return this.doubleValueInternally(tmpIndex);
+        } else {
+            return PrimitiveMath.ZERO;
+        }
+    }
+
+    /**
+     * Efficiently exchanges two elements in the sparse array.
+     * <p>
+     * This method is optimized for sparse arrays and handles all cases efficiently:
+     * <ul>
+     * <li>Both elements are nonzero (direct swap)</li>
+     * <li>One element is zero, other is nonzero (remove one, add other)</li>
+     * <li>Both elements are zero (no operation needed)</li>
+     * </ul>
+     *
+     * @param indexA the first index to exchange
+     * @param indexB the second index to exchange
+     */
+    public void exchange(final int indexA, final int indexB) {
+
+        if (indexA == indexB || myActualLength == 0) {
+            return; // No operation needed
+        }
+
+        int internalA = this.index(indexA);
+        int internalB = this.index(indexB);
+
+        boolean existsA = internalA >= 0;
+        boolean existsB = internalB >= 0;
+
+        if (existsA && existsB) {
+            // Both elements exist - swap values only
+            if (this.isPrimitive()) {
+                double tmpVal = myValues.doubleValue(internalA);
+                myValues.set(internalA, myValues.doubleValue(internalB));
+                myValues.set(internalB, tmpVal);
+            } else {
+                N tmpVal = myValues.get(internalA);
+                myValues.set(internalA, myValues.get(internalB));
+                myValues.set(internalB, tmpVal);
+            }
+            // No need to swap indices - they represent the original positions
+
+        } else if (existsA && !existsB) {
+            // Element A exists, B doesn't - move A to B's position
+            if (this.isPrimitive()) {
+                double valueA = myValues.doubleValue(internalA);
+                // Remove A from its current position
+                this.remove(indexA, internalA);
+                // Add A to B's position
+                this.set(indexB, valueA);
+            } else {
+                N valueA = myValues.get(internalA);
+                // Remove A from its current position
+                this.remove(indexA, internalA);
+                // Add A to B's position
+                this.set(indexB, valueA);
+            }
+
+        } else if (!existsA && existsB) {
+            // Element B exists, A doesn't - move B to A's position
+            if (this.isPrimitive()) {
+                double valueB = myValues.doubleValue(internalB);
+                // Remove B from its current position
+                this.remove(indexB, internalB);
+                // Add B to A's position
+                this.set(indexA, valueB);
+            } else {
+                N valueB = myValues.get(internalB);
+                // Remove B from its current position
+                this.remove(indexB, internalB);
+                // Add B to A's position
+                this.set(indexA, valueB);
+            }
+
+        } else {
+            // Neither element exists - no operation needed
+            // Both are zero, so swapping them has no effect
         }
-        return myZeroValue;
     }
 
     @Override
@@ -346,16 +475,16 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
 
         if (PrimitiveScalar.isSmall(PrimitiveMath.ONE, NumberDefinition.doubleValue(value))) {
 
-            myValues.fillAll(myZeroNumber);
+            myValues.fillAll(myDenseFactory.scalar().zero().get());
 
         } else {
 
             // Bad idea...
 
-            final int tmpSize = (int) this.count();
+            int tmpSize = Math.toIntExact(this.count());
 
             if (tmpSize != myIndices.length) {
-                myIndices = Structure1D.newIncreasingRange(0L, tmpSize);
+                myIndices = Structure1D.newIncreasingRange(0, tmpSize);
                 myValues = myDenseFactory.make(tmpSize);
                 myActualLength = tmpSize;
             }
@@ -369,10 +498,10 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
 
         // Bad idea...
 
-        final int tmpSize = (int) this.count();
+        int tmpSize = Math.toIntExact(this.count());
 
         if (tmpSize != myIndices.length) {
-            myIndices = Structure1D.newIncreasingRange(0L, tmpSize);
+            myIndices = Structure1D.newIncreasingRange(0, tmpSize);
             myValues = myDenseFactory.make(tmpSize);
             myActualLength = tmpSize;
         }
@@ -404,16 +533,17 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     public N get(final long index) {
 
-        final int tmpIndex = this.index(index);
+        int tmpIndex = this.index(index);
         if (tmpIndex >= 0) {
             return this.getInternally(tmpIndex);
+        } else {
+            return myDenseFactory.scalar().zero().get();
         }
-        return myZeroNumber;
     }
 
     @Override
     public long indexOfLargest() {
-        return myIndices[Math.toIntExact(myValues.indexOfLargest(0L, myActualLength, 1L))];
+        return myIndices[myValues.indexOfLargest(0, myActualLength, 1)];
     }
 
     public long limitOfRange(final long rangeFirst, final long rangeLimit) {
@@ -430,9 +560,9 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     public void modifyAll(final UnaryFunction<N> modifier) {
 
-        double zeroValue = modifier.invoke(myZeroValue);
+        double zeroValue = modifier.invoke(PrimitiveMath.ZERO);
 
-        if (MATH_CONTEXT.isDifferent(myZeroValue, zeroValue)) {
+        if (MATH_CONTEXT.isDifferent(PrimitiveMath.ZERO, zeroValue)) {
             throw new IllegalArgumentException("SparseArray zero-value modification!");
         }
 
@@ -449,10 +579,72 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         return new NonzeroView<>(myIndices, myValues, myActualLength);
     }
 
+    /**
+     * Efficiently appends a new nonzero element at the end of this sparse array.
+     * <p>
+     * This method assumes that the supplied {@code index} is strictly greater than all existing indices in
+     * the array. No search is performed; the value is simply appended. If the ascending order of indices is
+     * broken, future behavior is unspecified. If the value is zero, nothing is stored.
+     *
+     * @param index the index at which to insert the new value (must be after all existing indices)
+     * @param value the value to insert (only nonzero values are actually stored)
+     */
+    public void putLast(final int index, final double value) {
+        this.update(index, -(myActualLength + 1), value, false);
+    }
+
+    /**
+     * All elements with indices in the range [first,last] should be shifted one step to the left (their
+     * indices decreased by 1). It is safe to assume that there is currently nothing stored at 'from'. The new
+     * value 'newValue' should be placed at position 'last'. That position is typically freed by the shift. If
+     * 'newValue' is zero it doesn't have to stored. The case where the range [first,last] was originally
+     * empty, but the new value is non-zero requires special logic.
+     */
+    public void removeShiftAndInsert(final int first, final int last, final double newValue) {
+
+        boolean atFirst = false;
+        int insertPos = -1;
+
+        for (int i = 0; i < myActualLength; i++) {
+            int index = myIndices[i];
+
+            if (first == index) {
+                atFirst = true;
+            }
+
+            if (atFirst) {
+                if (first == index) {
+                    insertPos = i;
+                } else if (first < index && index <= last) {
+                    // Shift value left
+                    myIndices[i - 1] = index - 1;
+                    myValues.set(i - 1, myValues.doubleValue(i));
+                    insertPos = i; // This slot is now free for the new value
+                }
+            } else if (first < index && index <= last) {
+                // Just decrement index
+                myIndices[i] = index - 1;
+            }
+
+            if (last <= index) {
+                break;
+            }
+        }
+
+        if (insertPos >= 0) {
+            // A spot was freed, write the new value at insertPos
+            myIndices[insertPos] = last;
+            myValues.set(insertPos, newValue);
+        } else if (newValue != PrimitiveMath.ZERO) {
+            // No spot freed, newValue is nonzero, use set to insert
+            this.set(last, newValue);
+        }
+        // No spot freed, newValue is zero: do nothing
+    }
+
     @Override
     public void reset() {
         myActualLength = 0;
-        myValues.reset();
     }
 
     @Override
@@ -466,7 +658,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     public void set(final long index, final Comparable<?> value) {
 
-        final int internalIndex = this.index(index);
+        int internalIndex = this.index(index);
 
         this.update(index, internalIndex, value, false);
     }
@@ -474,7 +666,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     public void set(final long index, final double value) {
 
-        final int internalIndex = this.index(index);
+        int internalIndex = this.index(index);
 
         this.update(index, internalIndex, value, false);
     }
@@ -482,28 +674,58 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     public void set(final long index, final float value) {
 
-        final int internalIndex = this.index(index);
+        int internalIndex = this.index(index);
 
         this.update(index, internalIndex, value, false);
     }
 
     @Override
     public int size() {
-        return Math.toIntExact(myCount);
+        return mySize;
     }
 
-    public void supplyNonZerosTo(final Mutate1D consumer) {
+    /**
+     * Does NOT first reset the receiver! That means the elements in the receiver corresponding to zeros in
+     * this sparse array are not zero:ed or modified in any way.
+     */
+    public void supplyNonZerosTo(final double[] receiver) {
+        for (int n = 0; n < myActualLength; n++) {
+            receiver[myIndices[n]] = myValues.doubleValue(n);
+        }
+    }
+
+    /**
+     * Does NOT first reset the receiver! That means the elements in the receiver corresponding to zeros in
+     * this sparse array are not zero:ed or modified in any way.
+     */
+    public void supplyNonZerosTo(final Mutate1D receiver) {
         if (this.isPrimitive()) {
             for (int n = 0; n < myActualLength; n++) {
-                consumer.set(myIndices[n], myValues.doubleValue(n));
+                receiver.set(myIndices[n], myValues.doubleValue(n));
             }
         } else {
             for (int n = 0; n < myActualLength; n++) {
-                consumer.set(myIndices[n], myValues.get(n));
+                receiver.set(myIndices[n], myValues.get(n));
             }
         }
     }
 
+    @Override
+    public void supplyTo(final double[] receiver) {
+
+        Arrays.fill(receiver, PrimitiveMath.ZERO);
+
+        this.supplyNonZerosTo(receiver);
+    }
+
+    @Override
+    public void supplyTo(final Mutate1D receiver) {
+
+        receiver.reset();
+
+        this.supplyNonZerosTo(receiver);
+    }
+
     @Override
     public void visitOne(final long index, final VoidFunction<N> visitor) {
         if (this.isPrimitive()) {
@@ -542,7 +764,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         }
 
         if (limit - first > localLimit - localFirst) {
-            visitor.invoke(myZeroValue);
+            visitor.invoke(PrimitiveMath.ZERO);
         }
 
         for (int i = localFirst; i < localLimit; i++) {
@@ -569,16 +791,16 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     /**
      * Will never remove anything - just insert or update
      */
-    private void update(final long externalIndex, final int internalIndex, final Comparable<?> value, final boolean shouldStoreZero) {
+    private void update(final int externalIndex, final int internalIndex, final Comparable<?> value, final boolean shouldStoreZero) {
 
         if (internalIndex >= 0) {
             // Existing value, just update
 
             myValues.set(internalIndex, value);
 
-        } else if (shouldStoreZero || !value.equals(myZeroNumber)) {
+        } else if (shouldStoreZero || !value.equals(myDenseFactory.scalar().zero().get())) {
             // Not existing value, insert new
-            final int tmpInsInd = -(internalIndex + 1);
+            int tmpInsInd = -(internalIndex + 1);
 
             if (myActualLength + 1 <= myIndices.length) {
                 // No need to grow the backing arrays
@@ -593,9 +815,9 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
             } else {
                 // Needs to grow the backing arrays
 
-                final int tmpCapacity = myGrowthStrategy.grow(myIndices.length);
-                final long[] tmpIndices = new long[tmpCapacity];
-                final DenseArray<N> tmpValues = myDenseFactory.make(tmpCapacity);
+                int tmpCapacity = myGrowthStrategy.grow(myIndices.length);
+                int[] tmpIndices = new int[tmpCapacity];
+                PlainArray<N> tmpValues = myDenseFactory.make(tmpCapacity);
 
                 for (int i = 0; i < tmpInsInd; i++) {
                     tmpIndices[i] = myIndices[i];
@@ -607,9 +829,9 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
                     tmpIndices[i + 1] = myIndices[i];
                     tmpValues.set(i + 1, myValues.get(i));
                 }
-                for (int i = myIndices.length + 1; i < tmpIndices.length; i++) {
-                    tmpIndices[i] = Long.MAX_VALUE;
-                }
+                // for (int i = myIndices.length + 1; i < tmpIndices.length; i++) {
+                // tmpIndices[i] = Long.MAX_VALUE;
+                // }
 
                 myIndices = tmpIndices;
                 myValues = tmpValues;
@@ -621,7 +843,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     /**
      * Will never remove anything - just insert or update
      */
-    private void update(final long externalIndex, final int internalIndex, final double value, final boolean shouldStoreZero) {
+    private void update(final int externalIndex, final int internalIndex, final double value, final boolean shouldStoreZero) {
 
         if (internalIndex >= 0) {
             // Existing value, just update
@@ -630,7 +852,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
 
         } else if (shouldStoreZero || NumberContext.compare(value, PrimitiveMath.ZERO) != 0) {
             // Not existing value, insert new
-            final int tmpInsInd = -(internalIndex + 1);
+            int tmpInsInd = -(internalIndex + 1);
 
             if (myActualLength + 1 <= myIndices.length) {
                 // No need to grow the backing arrays
@@ -645,9 +867,9 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
             } else {
                 // Needs to grow the backing arrays
 
-                final int tmpCapacity = myGrowthStrategy.grow(myIndices.length);
-                final long[] tmpIndices = new long[tmpCapacity];
-                final DenseArray<N> tmpValues = myDenseFactory.make(tmpCapacity);
+                int tmpCapacity = myGrowthStrategy.grow(myIndices.length);
+                int[] tmpIndices = new int[tmpCapacity];
+                PlainArray<N> tmpValues = myDenseFactory.make(tmpCapacity);
 
                 for (int i = 0; i < tmpInsInd; i++) {
                     tmpIndices[i] = myIndices[i];
@@ -659,9 +881,9 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
                     tmpIndices[i + 1] = myIndices[i];
                     tmpValues.set(i + 1, myValues.doubleValue(i));
                 }
-                for (int i = myIndices.length + 1; i < tmpIndices.length; i++) {
-                    tmpIndices[i] = Long.MAX_VALUE;
-                }
+                // for (int i = myIndices.length + 1; i < tmpIndices.length; i++) {
+                // tmpIndices[i] = Long.MAX_VALUE;
+                // }
 
                 myIndices = tmpIndices;
                 myValues = tmpValues;
@@ -670,42 +892,26 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         }
     }
 
+    private void update(final long externalIndex, final int internalIndex, final Comparable<?> value, final boolean shouldStoreZero) {
+        this.update((int) externalIndex, internalIndex, value, shouldStoreZero);
+    }
+
+    private void update(final long externalIndex, final int internalIndex, final double value, final boolean shouldStoreZero) {
+        this.update((int) externalIndex, internalIndex, value, shouldStoreZero);
+    }
+
     @Override
     protected void exchange(final long firstA, final long firstB, final long step, final long count) {
 
-        if (this.isPrimitive()) {
+        int tmpIndexA = (int) firstA;
+        int tmpIndexB = (int) firstB;
 
-            long tmpIndexA = firstA;
-            long tmpIndexB = firstB;
+        for (int i = 0, limit = (int) count; i < limit; i++) {
 
-            double tmpVal;
+            this.exchange(tmpIndexA, tmpIndexB);
 
-            for (long i = 0L; i < count; i++) {
-
-                tmpVal = this.doubleValue(tmpIndexA);
-                this.set(tmpIndexA, this.doubleValue(tmpIndexB));
-                this.set(tmpIndexB, tmpVal);
-
-                tmpIndexA += step;
-                tmpIndexB += step;
-            }
-
-        } else {
-
-            long tmpIndexA = firstA;
-            long tmpIndexB = firstB;
-
-            N tmpVal;
-
-            for (long i = 0L; i < count; i++) {
-
-                tmpVal = this.get(tmpIndexA);
-                this.set(tmpIndexA, this.get(tmpIndexB));
-                this.set(tmpIndexB, tmpVal);
-
-                tmpIndexA += step;
-                tmpIndexB += step;
-            }
+            tmpIndexA += (int) step;
+            tmpIndexB += (int) step;
         }
     }
 
@@ -731,7 +937,7 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         double tmpValue;
 
         for (int i = 0; i < myIndices.length; i++) {
-            final long tmpIndex = myIndices[i];
+            int tmpIndex = myIndices[i];
             if (tmpIndex >= first && tmpIndex < limit && (tmpIndex - first) % step == 0L) {
                 tmpValue = PrimitiveMath.ABS.invoke(myValues.doubleValue(i));
                 if (tmpValue > tmpLargest) {
@@ -747,14 +953,15 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     protected void modify(final long first, final long limit, final long step, final Access1D<N> left, final BinaryFunction<N> function) {
 
-        final double tmpZeroValue = function.invoke(PrimitiveMath.ZERO, PrimitiveMath.ZERO);
+        double tmpZeroValue = function.invoke(PrimitiveMath.ZERO, PrimitiveMath.ZERO);
 
         if (!PrimitiveScalar.isSmall(PrimitiveMath.ONE, tmpZeroValue)) {
 
             throw new IllegalArgumentException("SparseArray zero modification!");
         }
+
         for (int i = 0; i < myIndices.length; i++) {
-            final long tmpIndex = myIndices[i];
+            int tmpIndex = myIndices[i];
             if (tmpIndex >= first && tmpIndex < limit && (tmpIndex - first) % step == 0L) {
                 myValues.modify(tmpIndex, i, left, function);
             }
@@ -764,16 +971,16 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     protected void modify(final long first, final long limit, final long step, final BinaryFunction<N> function, final Access1D<N> right) {
 
-        final double tmpZeroValue = function.invoke(PrimitiveMath.ZERO, PrimitiveMath.ZERO);
+        double tmpZeroValue = function.invoke(PrimitiveMath.ZERO, PrimitiveMath.ZERO);
 
         if (!PrimitiveScalar.isSmall(PrimitiveMath.ONE, tmpZeroValue)) {
 
             throw new IllegalArgumentException("SparseArray zero modification!");
         }
         for (int i = 0; i < myIndices.length; i++) {
-            final long tmpIndex = myIndices[i];
+            long tmpIndex = myIndices[i];
             if (tmpIndex >= first && tmpIndex < limit && (tmpIndex - first) % step == 0L) {
-                myValues.modify(tmpIndex, i, function, right);
+                myValues.modify((int) tmpIndex, i, function, right);
             }
         }
     }
@@ -781,14 +988,14 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     @Override
     protected void modify(final long first, final long limit, final long step, final UnaryFunction<N> function) {
 
-        final double tmpZeroValue = function.invoke(PrimitiveMath.ZERO);
+        double tmpZeroValue = function.invoke(PrimitiveMath.ZERO);
 
         if (!PrimitiveScalar.isSmall(PrimitiveMath.ONE, tmpZeroValue)) {
 
             throw new IllegalArgumentException("SparseArray zero modification!");
         }
-        for (int i = 0; i < myIndices.length; i++) {
-            final long tmpIndex = myIndices[i];
+        for (int i = 0; i < myActualLength; i++) {
+            int tmpIndex = myIndices[i];
             if (tmpIndex >= first && tmpIndex < limit && (tmpIndex - first) % step == 0L) {
                 myValues.modify(tmpIndex, i, function);
             }
@@ -799,11 +1006,11 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
     protected void visit(final long first, final long limit, final long step, final VoidFunction<N> visitor) {
         boolean tmpOnlyOnce = true;
         for (int i = 0; i < myIndices.length; i++) {
-            final long tmpIndex = myIndices[i];
+            int tmpIndex = myIndices[i];
             if (tmpIndex >= first && tmpIndex < limit && (tmpIndex - first) % step == 0L) {
                 myValues.visitOne(i, visitor);
             } else if (tmpOnlyOnce) {
-                visitor.invoke(myZeroValue);
+                visitor.invoke(PrimitiveMath.ZERO);
                 tmpOnlyOnce = false;
             }
         }
@@ -813,13 +1020,14 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         return myValues.count();
     }
 
-    DenseArray<N> densify() {
+    PlainArray<N> densify() {
 
-        final DenseArray<N> retVal = myDenseFactory.make((int) this.count());
+        PlainArray<N> retVal = myDenseFactory.make(this.size());
 
         if (this.isPrimitive()) {
             for (int i = 0; i < myActualLength; i++) {
                 retVal.set(myIndices[i], myValues.doubleValue(i));
+
             }
         } else {
             for (int i = 0; i < myActualLength; i++) {
@@ -856,13 +1064,13 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         if (intFrom < 0) {
             intFrom = -(intFrom + 1);
         }
-        final int first = intFrom;
+        int first = intFrom;
 
         int intTo = this.index(toExcl);
         if (intTo < 0) {
             intTo = -(intTo + 1);
         }
-        final int limit = intTo;
+        int limit = intTo;
 
         return new Access1D<>() {
 
@@ -873,12 +1081,12 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
 
             @Override
             public double doubleValue(final long index) {
-                return myValues.doubleValue(first + index);
+                return myValues.doubleValue(first + (int) index);
             }
 
             @Override
             public N get(final long index) {
-                return myValues.get(first + index);
+                return myValues.get(first + (int) index);
             }
 
             @Override
@@ -889,11 +1097,15 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
         };
     }
 
-    int index(final long index) {
+    int index(final int index) {
         return Arrays.binarySearch(myIndices, 0, myActualLength, index);
     }
 
-    LongStream indices() {
+    int index(final long index) {
+        return this.index((int) index);
+    }
+
+    IntStream indices() {
         return Arrays.stream(myIndices, 0, myActualLength);
     }
 
@@ -927,7 +1139,6 @@ public final class SparseArray<N extends Comparable<N>> extends BasicArray<N> {
                     myValues.set(i, myValues.get(i + 1));
                 }
             }
-
         }
     }
 
