@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -32,7 +32,7 @@ public final class DaemonPoolExecutor extends ThreadPoolExecutor {
     private static final ThreadGroup GROUP = new ThreadGroup("ojAlgo-daemon-group");
 
     static final DaemonPoolExecutor INSTANCE = new DaemonPoolExecutor(OjAlgoUtils.ENVIRONMENT.units, Integer.MAX_VALUE, 5L, TimeUnit.SECONDS,
-            new SynchronousQueue<Runnable>(), DaemonPoolExecutor.newThreadFactory("ojAlgo-daemon-"));
+            new SynchronousQueue<>(), DaemonPoolExecutor.newThreadFactory("ojAlgo-daemon-"));
 
     /**
      * @see java.util.concurrent.AbstractExecutorService#submit(java.util.concurrent.Callable)
@@ -72,7 +72,7 @@ public final class DaemonPoolExecutor extends ThreadPoolExecutor {
     /**
      * Like {@link Executors#newScheduledThreadPool(int)} but with identifiable (daemon) threads
      */
-    public static ExecutorService newScheduledThreadPool(final String name, final int corePoolSize) {
+    public static ScheduledExecutorService newScheduledThreadPool(final String name, final int corePoolSize) {
         return Executors.newScheduledThreadPool(corePoolSize, DaemonPoolExecutor.newThreadFactory(name));
     }
 
@@ -86,7 +86,7 @@ public final class DaemonPoolExecutor extends ThreadPoolExecutor {
     /**
      * Like {@link Executors#newSingleThreadScheduledExecutor()} but with identifiable (daemon) threads
      */
-    public static ExecutorService newSingleThreadScheduledExecutor(final String name) {
+    public static ScheduledExecutorService newSingleThreadScheduledExecutor(final String name) {
         return Executors.newSingleThreadScheduledExecutor(DaemonPoolExecutor.newThreadFactory(name));
     }
 
