@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,10 +29,23 @@ import java.util.function.IntSupplier;
 import org.ojalgo.OjAlgoUtils;
 
 /**
+ * Divide an index (int) range into smaller parts, and conquer each part in parallel. There are two ways to
+ * use this class:
+ * <ul>
+ * <li>Extend it and implement the {@link #conquer(int, int)} method, and then invoke it with
+ * {@link #invoke(int, int, int)}.
+ * <li>Use the {@link Divider} to divide a range and provide a {@link Conquerer} that will be called with the
+ * range of indices to conquer. You can get a {@link Divider} from {@link ProcessingService#newDivider()} or
+ * from {@link Parallelism#newDivider(int)}.
+ * </ul>
+ *
  * @author apete
  */
 public abstract class DivideAndConquer {
 
+    /**
+     * A conquerer is a function that will be called with a range of indices to conquer.
+     */
     @FunctionalInterface
     public interface Conquerer {
 
@@ -40,6 +53,11 @@ public abstract class DivideAndConquer {
 
     }
 
+    /**
+     * A configurable divider that can be used to divide a range of indices and conquer each part in parallel.
+     * You can configure the divider with a maximum parallelism level and a threshold for the size of the
+     * parts to conquer.
+     */
     public static final class Divider {
 
         private final ExecutorService myExecutor;
@@ -86,11 +104,10 @@ public abstract class DivideAndConquer {
             int nextWorkers = workers / 2;
 
             Future<?> firstPart = executor.submit(() -> DivideAndConquer.call(executor, first, split, threshold, nextWorkers, conquerer));
-            Future<?> secondPart = executor.submit(() -> DivideAndConquer.call(executor, split, limit, threshold, nextWorkers, conquerer));
 
             try {
+                DivideAndConquer.call(executor, split, limit, threshold, nextWorkers, conquerer);
                 firstPart.get();
-                secondPart.get();
             } catch (final InterruptedException | ExecutionException cause) {
                 throw new RuntimeException(cause);
             }
@@ -113,7 +130,8 @@ public abstract class DivideAndConquer {
      */
     public final void invoke(final int first, final int limit, final int threshold) {
 
-        // int availableWorkers = OjAlgoUtils.ENVIRONMENT.threads - DaemonPoolExecutor.INSTANCE.getActiveCount() / 2;
+        // int availableWorkers = OjAlgoUtils.ENVIRONMENT.threads -
+        // DaemonPoolExecutor.INSTANCE.getActiveCount() / 2;
         int availableWorkers = OjAlgoUtils.ENVIRONMENT.threads;
 
         DivideAndConquer.call(DaemonPoolExecutor.INSTANCE, first, limit, threshold, availableWorkers, this::conquer);
