@@ -6,12 +6,14 @@ import java.util.Collection;
 import java.util.List;
 import java.util.Map;
 import java.util.Queue;
+import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.Callable;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
-import java.util.concurrent.LinkedBlockingDeque;
+import java.util.concurrent.LinkedTransferQueue;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.Consumer;
 import java.util.function.Function;
 import java.util.function.IntSupplier;
@@ -105,11 +107,11 @@ public final class ProcessingService {
      * Will create at most {@code parallelism} tasks to work through the {@code work} items, processing them
      * with {@code computer} and collectiing the results in a {@link Map}.
      *
-     * @param <W> The work item type
-     * @param <R> The function return type
-     * @param work The collection of work items
+     * @param <W>         The work item type
+     * @param <R>         The function return type
+     * @param work        The collection of work items
      * @param parallelism The maximum number of concurrent workers that will process the work items
-     * @param computer The processing code
+     * @param computer    The processing code
      * @return A map of function input to output
      */
     public <W, R> Map<W, R> compute(final Collection<W> work, final int parallelism, final Function<W, R> computer) {
@@ -123,8 +125,12 @@ public final class ProcessingService {
         return this.compute(work, parallelism.getAsInt(), computer);
     }
 
+    /**
+     * @deprecated v56 Use {@link #newDivider()} or {@link Parallelism#newDivider(int)} instead
+     */
+    @Deprecated
     public DivideAndConquer.Divider divider() {
-        return new DivideAndConquer.Divider(myExecutor);
+        return this.newDivider();
     }
 
     /**
@@ -149,11 +155,11 @@ public final class ProcessingService {
      * therefore vital that the input type implements {@link Object#hashCode()} and
      * {@link Object#equals(Object)} properly.
      *
-     * @param <W> The input item type
-     * @param <R> The output item type
-     * @param work The collection of work items
+     * @param <W>         The input item type
+     * @param <R>         The output item type
+     * @param work        The collection of work items
      * @param parallelism The maximum number of concurrent workers that will process the work items
-     * @param mapper The mapper functiom
+     * @param mapper      The mapper functiom
      * @return The mapped results
      */
     public <W, R> Collection<R> map(final Collection<W> work, final int parallelism, final Function<W, R> mapper) {
@@ -167,6 +173,10 @@ public final class ProcessingService {
         return this.map(work, parallelism.getAsInt(), mapper);
     }
 
+    public DivideAndConquer.Divider newDivider() {
+        return new DivideAndConquer.Divider(myExecutor);
+    }
+
     /**
      * Using parallelism {@link Parallelism#CORES}.
      *
@@ -180,16 +190,16 @@ public final class ProcessingService {
      * Will create at most {@code parallelism} tasks to work through the {@code work} items, processing them
      * with {@code processor}.
      *
-     * @param <W> The work item type
-     * @param work The collection of work items
+     * @param <W>         The work item type
+     * @param work        The collection of work items
      * @param parallelism The maximum number of concurrent workers that will process the work items
-     * @param processor The processing code
+     * @param processor   The processing code
      */
     public <W> void process(final Collection<? extends W> work, final int parallelism, final Consumer<W> processor) {
 
         int concurrency = Math.min(work.size(), parallelism);
 
-        Queue<W> queue = new LinkedBlockingDeque<>(work);
+        Queue<W> queue = new LinkedTransferQueue<>(work);
 
         List<CallableConsumer<W>> tasks = new ArrayList<>(concurrency);
         for (int i = 0; i < concurrency; i++) {
@@ -264,10 +274,10 @@ public final class ProcessingService {
      * <p>
      * Each {@link TwoStepMapper.Combineable} is only worked on by a single thread, and the results are
      * combined into a single instance. The instances are not reused.
-     * 
-     * @param work The collection of work items
+     *
+     * @param work        The collection of work items
      * @param parallelism The maximum number of concurrent workers that will process the work items
-     * @param reducer A {@link TwoStepMapper.Combineable} implementation that does what you want.
+     * @param reducer     A {@link TwoStepMapper.Combineable} implementation that does what you want.
      * @return The results...
      */
     public <W, R, A extends TwoStepMapper.Combineable<W, R, A>> R reduceCombineable(final Collection<W> work, final int parallelism,
@@ -275,7 +285,7 @@ public final class ProcessingService {
 
         int concurrency = Math.min(work.size(), parallelism);
 
-        Queue<W> queue = new LinkedBlockingDeque<>(work);
+        Queue<W> queue = new LinkedTransferQueue<>(work);
 
         List<CallableMapper<W, R>> tasks = new ArrayList<>(concurrency);
         for (int i = 0; i < concurrency; i++) {
@@ -307,7 +317,7 @@ public final class ProcessingService {
 
     /**
      * Using parallelism {@link Parallelism#CORES}.
-     * 
+     *
      * @see ProcessingService#reduceCombineable(Collection, int, Supplier)
      */
     public <W, R, A extends TwoStepMapper.Combineable<W, R, A>> R reduceCombineable(final Collection<W> work, final Supplier<A> reducer) {
@@ -321,17 +331,17 @@ public final class ProcessingService {
      * <p>
      * Each {@link TwoStepMapper.Mergeable} is only worked on by a single thread, and the results are combined
      * into a single instance. The instances are not reused.
-     * 
-     * @param work The collection of work items
+     *
+     * @param work        The collection of work items
      * @param parallelism The maximum number of concurrent workers that will process the work items
-     * @param reducer A {@link TwoStepMapper.Mergeable} implementation that does what you want.
+     * @param reducer     A {@link TwoStepMapper.Mergeable} implementation that does what you want.
      * @return The results...
      */
     public <W, R, A extends TwoStepMapper.Mergeable<W, R>> R reduceMergeable(final Collection<W> work, final int parallelism, final Supplier<A> reducer) {
 
         int concurrency = Math.min(work.size(), parallelism);
 
-        Queue<W> queue = new LinkedBlockingDeque<>(work);
+        Queue<W> queue = new LinkedTransferQueue<>(work);
 
         List<CallableMapper<W, R>> tasks = new ArrayList<>(concurrency);
         for (int i = 0; i < concurrency; i++) {
@@ -363,7 +373,7 @@ public final class ProcessingService {
 
     /**
      * Using parallelism {@link Parallelism#CORES}.
-     * 
+     *
      * @see ProcessingService#reduceMergeable(Collection, int, Supplier)
      */
     public <W, R, A extends TwoStepMapper.Mergeable<W, R>> R reduceMergeable(final Collection<W> work, final Supplier<A> reducer) {
@@ -374,7 +384,7 @@ public final class ProcessingService {
      * Will create precisely {@code parallelism} tasks that each execute the {@code processor}.
      *
      * @param parallelism The number of concurrent workers/threads that will run
-     * @param processor The processing code
+     * @param processor   The processing code
      */
     public void run(final int parallelism, final Runnable processor) {
 
@@ -399,4 +409,60 @@ public final class ProcessingService {
         this.run(parallelism.getAsInt(), processor);
     }
 
+    public void run(final Runnable task1, final Runnable task2) {
+
+        Future<?> future1 = myExecutor.submit(task1);
+        Future<?> future2 = myExecutor.submit(task2);
+
+        try {
+            future1.get();
+            future2.get();
+        } catch (InterruptedException | ExecutionException cause) {
+            throw new RuntimeException(cause);
+        }
+    }
+
+    /**
+     * Will submit precisely {@code parallelism} tasks that each take from the {@code queue} feeding the items
+     * to the {@code processor}. The tasks will continue to run until the returned {@link AtomicBoolean} is
+     * set to {@code false} (or the thread is interrupted).
+     * <p>
+     * If the threads of the underlying {@link ExecutorService} are daemon threads, the JVM will not wait for
+     * them to finish before it exits. The default behaviour, using {@link #INSTANCE} or
+     * {@link #newInstance(String)}, is to make use of ojAlgo's {@link DaemonPoolExecutor}.
+     *
+     * @param <T>         The work item type
+     * @param queue       The queue to take from
+     * @param parallelism How many parallel workers to create
+     * @param processor   What to do with each of the work items
+     * @return A flag that can be used to signal the tasks to stop
+     */
+    @SuppressWarnings("unused")
+    public <T> AtomicBoolean take(final BlockingQueue<T> queue, final int parallelism, final Consumer<T> processor) {
+
+        AtomicBoolean active = new AtomicBoolean(true);
+
+        for (int i = 0; i < parallelism; i++) {
+            myExecutor.submit(() -> {
+                while (active.get()) {
+                    try {
+                        processor.accept(queue.take());
+                    } catch (InterruptedException cause) {
+                        Thread.currentThread().interrupt();
+                        break;
+                    }
+                }
+            });
+        }
+
+        return active;
+    }
+
+    /**
+     * @see ProcessingService#take(BlockingQueue, int, Consumer)
+     */
+    public <T> AtomicBoolean take(final BlockingQueue<T> queue, final IntSupplier parallelism, final Consumer<T> processor) {
+        return this.take(queue, parallelism.getAsInt(), processor);
+    }
+
 }
