@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -41,8 +41,6 @@ import org.ojalgo.netio.DataWriter;
 import org.ojalgo.netio.FromFileReader;
 import org.ojalgo.netio.ShardedFile;
 import org.ojalgo.netio.ToFileWriter;
-import org.ojalgo.type.function.AutoConsumer;
-import org.ojalgo.type.function.AutoSupplier;
 import org.ojalgo.type.function.TwoStepMapper;
 import org.ojalgo.type.management.MBeanUtils;
 import org.ojalgo.type.management.Throughput;
@@ -64,8 +62,8 @@ public final class BatchNode<T> {
         private ExecutorService myExecutor = null;
         private int myFragmentation = 64;
         private final DataInterpreter<T> myInterpreter;
+        private boolean myManaged = false;
         private int myParallelism = Parallelism.CORES.getAsInt();
-
         private int myQueueCapacity = 1024;
 
         Builder(final File directory, final DataInterpreter<T> interpreter) {
@@ -103,6 +101,14 @@ public final class BatchNode<T> {
             return this;
         }
 
+        /**
+         * Do you want a JMX bean to keep track of throughput?
+         */
+        public BatchNode.Builder<T> managed(final boolean managed) {
+            myManaged = managed;
+            return this;
+        }
+
         /**
          * @see #parallelism(IntSupplier)
          */
@@ -175,6 +181,10 @@ public final class BatchNode<T> {
             return ShardedFile.of(myDirectory, "Shard.data", this.getFragmentation());
         }
 
+        boolean isManaged() {
+            return myManaged;
+        }
+
     }
 
     private static final class TwoStepWrapper<T> implements TwoStepMapper<T, Boolean> {
@@ -218,7 +228,7 @@ public final class BatchNode<T> {
     private final IntSupplier myParallelism;
     private final ProcessingService myProcessor;
     private final int myQueueCapacity;
-    private transient Function<File, AutoSupplier<T>> myReaderFactory = null;
+    private transient Function<File, FromFileReader<T>> myReaderFactory = null;
     private final Throughput myReaderManager;
     private final ShardedFile myShards;
     private final Throughput myWriterManger;
@@ -235,12 +245,20 @@ public final class BatchNode<T> {
         myProcessor = builder.getProcessor();
         myQueueCapacity = builder.getQueueCapacity();
 
-        myWriterManger = new Throughput();
-        myReaderManager = new Throughput();
+        if (builder.isManaged()) {
 
-        String name = builder.getName();
-        MBeanUtils.register(myWriterManger, name + "-Writer");
-        MBeanUtils.register(myReaderManager, name + "-Reader");
+            myWriterManger = new Throughput();
+            myReaderManager = new Throughput();
+
+            String name = builder.getName();
+            MBeanUtils.register(myWriterManger, name + "-Writer");
+            MBeanUtils.register(myReaderManager, name + "-Reader");
+
+        } else {
+
+            myWriterManger = null;
+            myReaderManager = null;
+        }
     }
 
     /**
@@ -250,7 +268,7 @@ public final class BatchNode<T> {
         myShards.delete();
     }
 
-    public AutoConsumer<T> newWriter() {
+    public ToFileWriter<T> newWriter() {
         return ToFileWriter.newBuilder(myShards).queue(myQueueCapacity).parallelism(myParallelism).statistics(myWriterManger).build(myDistributor,
                 shard -> DataWriter.of(shard, myInterpreter));
     }
@@ -277,7 +295,7 @@ public final class BatchNode<T> {
      * Similar to {@link #processMergeable(Supplier, Consumer)} but the {@code processor} is called with the
      * aggregator instance itself rather than its extracted results. This corresponds to
      * {@link TwoStepMapper#Combineable} rather than {@link TwoStepMapper#Mergeable}.
-     * 
+     *
      * @see #processMergeable(Supplier, Consumer)
      */
     public <R, A extends TwoStepMapper<T, R>> void processCombineable(final Supplier<A> aggregatorFactory, final Consumer<A> processor) {
@@ -367,7 +385,7 @@ public final class BatchNode<T> {
      * {@link TwoStepMapper#merge(Object)} - you can only use this if merging partial (sub)results is
      * possible. Use a constructor or factory method that produce instances of that type as the argument to
      * this method.
-     * 
+     *
      * @deprecated v54 Use {@link #reduceByMerging(Supplier<A>)} instead
      */
     @Deprecated
@@ -375,7 +393,7 @@ public final class BatchNode<T> {
         return this.reduceByMerging(aggregatorFactory);
     }
 
-    private Function<File, AutoSupplier<T>> getReaderFactory() {
+    private Function<File, FromFileReader<T>> getReaderFactory() {
         if (myReaderFactory == null) {
             Function<File, DataReader<T>> baseReader = file -> DataReader.of(file, myInterpreter);
             myReaderFactory = file -> FromFileReader.newBuilder(file).parallelism(1).queue(myQueueCapacity / myParallelism.getAsInt())
@@ -386,7 +404,7 @@ public final class BatchNode<T> {
 
     private void process(final File shard, final Consumer<T> consumer) {
 
-        try (AutoSupplier<T> reader = this.newReader(shard)) {
+        try (FromFileReader<T> reader = this.newReader(shard)) {
 
             T item = null;
             while ((item = reader.read()) != null) {
@@ -403,7 +421,7 @@ public final class BatchNode<T> {
 
         A aggregator = aggregatorFactory.get(); // It's a ThreadLocal...
 
-        try (AutoSupplier<T> reader = this.newReader(shard)) {
+        try (FromFileReader<T> reader = this.newReader(shard)) {
 
             T item = null;
             while ((item = reader.read()) != null) {
@@ -423,7 +441,7 @@ public final class BatchNode<T> {
 
         A aggregator = aggregatorFactory.get(); // It's a ThreadLocal...
 
-        try (AutoSupplier<T> reader = this.newReader(shard)) {
+        try (FromFileReader<T> reader = this.newReader(shard)) {
 
             T item = null;
             while ((item = reader.read()) != null) {
@@ -439,7 +457,7 @@ public final class BatchNode<T> {
         }
     }
 
-    AutoSupplier<T> newReader(final File file) {
+    FromFileReader<T> newReader(final File file) {
         return this.getReaderFactory().apply(file);
     }
 
