@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -37,6 +37,7 @@ import java.util.function.UnaryOperator;
 import org.ojalgo.array.DenseArray;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.netio.BasicParser;
+import org.ojalgo.netio.FromFileReader;
 import org.ojalgo.series.BasicSeries;
 import org.ojalgo.series.CalendarDateSeries;
 import org.ojalgo.series.SimpleSeries;
@@ -44,7 +45,6 @@ import org.ojalgo.series.primitive.CoordinatedSet;
 import org.ojalgo.type.CalendarDate;
 import org.ojalgo.type.CalendarDateUnit;
 import org.ojalgo.type.PrimitiveNumber;
-import org.ojalgo.type.function.AutoSupplier;
 import org.ojalgo.type.keyvalue.KeyValue;
 
 public final class DataSource implements FinanceData<DatePrice> {
@@ -131,7 +131,7 @@ public final class DataSource implements FinanceData<DatePrice> {
     /**
      * All data downloaders/fetchers are deprecated. They will be removed in a future release, and most likely
      * they're already broken.
-     * 
+     *
      * @deprecated
      */
     @Deprecated
@@ -142,7 +142,7 @@ public final class DataSource implements FinanceData<DatePrice> {
     /**
      * All data downloaders/fetchers are deprecated. They will be removed in a future release, and most likely
      * they're already broken.
-     * 
+     *
      * @deprecated
      */
     @Deprecated
@@ -163,7 +163,7 @@ public final class DataSource implements FinanceData<DatePrice> {
     /**
      * All data downloaders/fetchers are deprecated. They will be removed in a future release, and most likely
      * they're already broken.
-     * 
+     *
      * @deprecated
      */
     @Deprecated
@@ -176,7 +176,7 @@ public final class DataSource implements FinanceData<DatePrice> {
     /**
      * All data downloaders/fetchers are deprecated. They will be removed in a future release, and most likely
      * they're already broken.
-     * 
+     *
      * @deprecated
      */
     @Deprecated
@@ -251,7 +251,7 @@ public final class DataSource implements FinanceData<DatePrice> {
 
         List<DatePrice> value = new ArrayList<>();
 
-        try (AutoSupplier<? extends DatePrice> reader = myFetcher.getReader(myParser)) {
+        try (FromFileReader<? extends DatePrice> reader = myFetcher.getReader(myParser)) {
             reader.forEach(value::add);
         } catch (final Exception cause) {
             BasicLogger.error(cause, "Fetch problem for {}!", myFetcher.getClass().getSimpleName());
@@ -276,11 +276,12 @@ public final class DataSource implements FinanceData<DatePrice> {
         return this.getLocalDateSeries(this.getHistoricalPrices(), resolution);
     }
 
-    public BasicSeries<LocalDate, PrimitiveNumber> getLocalDateSeries(final CalendarDateUnit resolution, final DenseArray.Factory<Double> denseArrayFactory) {
+    public BasicSeries<LocalDate, PrimitiveNumber> getLocalDateSeries(final CalendarDateUnit resolution,
+            final DenseArray.Factory<Double, ?> denseArrayFactory) {
         return this.getLocalDateSeries(this.getHistoricalPrices(), resolution);
     }
 
-    public BasicSeries<LocalDate, PrimitiveNumber> getLocalDateSeries(final DenseArray.Factory<Double> denseArrayFactory) {
+    public BasicSeries<LocalDate, PrimitiveNumber> getLocalDateSeries(final DenseArray.Factory<Double, ?> denseArrayFactory) {
         return this.getLocalDateSeries(this.getHistoricalPrices(), myFetcher.getResolution());
     }
 
