@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -62,6 +62,16 @@ public final class PrimitiveFunction extends FunctionSet<Double> {
 
     }
 
+    @FunctionalInterface
+    public interface Nullary extends NullaryFunction<Double> {
+
+        @Override
+        default Double invoke() {
+            return Double.valueOf(this.doubleValue());
+        }
+
+    }
+
     @FunctionalInterface
     public interface Parameter extends ParameterFunction<Double> {
 
@@ -85,8 +95,8 @@ public final class PrimitiveFunction extends FunctionSet<Double> {
     public static final class SampleDomain {
 
         private final double myIncrement;
-        private final double myPeriod;
         private final int myNumberOfSamples;
+        private final double myPeriod;
 
         public SampleDomain(final double period, final int nbSamples) {
             super();
@@ -145,6 +155,10 @@ public final class PrimitiveFunction extends FunctionSet<Double> {
         return SET;
     }
 
+    public static Nullary nullary(final double value) {
+        return () -> value;
+    }
+
     private PrimitiveFunction() {
         super();
     }
