@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,12 +21,8 @@
  */
 package org.ojalgo.function.multiary;
 
-import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
-import org.ojalgo.scalar.ComplexNumber;
-import org.ojalgo.scalar.RationalNumber;
 import org.ojalgo.structure.Access1D;
 
 /**
@@ -53,7 +49,7 @@ public final class LinearFunction<N extends Comparable<N>> implements MultiaryFu
 
         public LinearFunction<N> make(final int arity) {
             if (myCoefficients != null) {
-                return new LinearFunction<>(myFactory.rows(myCoefficients));
+                return new LinearFunction<>(myFactory.row(myCoefficients));
             } else {
                 return new LinearFunction<>(myFactory.make(1, arity));
             }
@@ -65,60 +61,6 @@ public final class LinearFunction<N extends Comparable<N>> implements MultiaryFu
         return new Factory<>(factory);
     }
 
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static LinearFunction<ComplexNumber> makeComplex(final Access1D<?> coefficients) {
-        // return new LinearFunction<>(GenericStore.C128.rows(coefficients));
-        return LinearFunction.factory(GenericStore.C128).coefficients(coefficients).make(coefficients.size());
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static LinearFunction<ComplexNumber> makeComplex(final int arity) {
-        // return new LinearFunction<>(GenericStore.C128.make(1, arity));
-        return LinearFunction.factory(GenericStore.C128).make(arity);
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static LinearFunction<Double> makePrimitive(final Access1D<?> coefficients) {
-        // return new LinearFunction<>(Primitive64Store.FACTORY.rows(coefficients));
-        return LinearFunction.factory(Primitive64Store.FACTORY).coefficients(coefficients).make(coefficients.size());
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static LinearFunction<Double> makePrimitive(final int arity) {
-        // return new LinearFunction<>(Primitive64Store.FACTORY.make(1, arity));
-        return LinearFunction.factory(Primitive64Store.FACTORY).make(arity);
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static LinearFunction<RationalNumber> makeRational(final Access1D<?> coefficients) {
-        // return new LinearFunction<>(GenericStore.Q128.rows(coefficients));
-        return LinearFunction.factory(GenericStore.Q128).coefficients(coefficients).make(coefficients.size());
-    }
-
-    /**
-     * @deprecated v53 Use {@link #factory(PhysicalStore.Factory)} instead.
-     */
-    @Deprecated
-    public static LinearFunction<RationalNumber> makeRational(final int arity) {
-        // return new LinearFunction<>(GenericStore.Q128.make(1, arity));
-        return LinearFunction.factory(GenericStore.Q128).make(arity);
-    }
-
     public static <N extends Comparable<N>> LinearFunction<N> wrap(final PhysicalStore<N> coefficients) {
         return new LinearFunction<>(coefficients);
     }
@@ -136,6 +78,7 @@ public final class LinearFunction<N extends Comparable<N>> implements MultiaryFu
         myCoefficients = coefficients;
     }
 
+    @Override
     public int arity() {
         return Math.toIntExact(myCoefficients.count());
     }
@@ -150,6 +93,7 @@ public final class LinearFunction<N extends Comparable<N>> implements MultiaryFu
         return this.factory().makeZero(this.arity(), this.arity());
     }
 
+    @Override
     public MatrixStore<N> getLinearFactors(final boolean negated) {
 
         MatrixStore<N> retVal = myCoefficients;
@@ -175,6 +119,7 @@ public final class LinearFunction<N extends Comparable<N>> implements MultiaryFu
         return preallocated.get(0, 0);
     }
 
+    @Override
     public PhysicalStore<N> linear() {
         return (PhysicalStore<N>) myCoefficients;
     }
