@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -42,12 +42,18 @@ package org.ojalgo.machine;
  */
 public enum JavaType {
 
-    BOOLEAN(boolean.class, 1, 1L), BYTE(byte.class, 8, 1L), CHAR(char.class, 16, 2L), DOUBLE(double.class, 64, 8L), FLOAT(float.class, 32, 4L), INT(int.class,
-            32, 4L), LONG(long.class, 64, 8L),
+    BOOLEAN(boolean.class, 1, 1L),
+    BYTE(byte.class, 8, 1L),
+    CHAR(char.class, 16, 2L),
+    DOUBLE(double.class, 64, 8L),
+    FLOAT(float.class, 32, 4L),
+    INT(int.class, 32, 4L),
+    LONG(long.class, 64, 8L),
     /**
      * 4 bytes with 32-bit JVM or 64-bit JVM with compressed pointers (All JVM:s assigned less than 32GB)
      */
-    REFERENCE(Object.class, 64, 4L), SHORT(short.class, 16, 2L);
+    REFERENCE(Object.class, 64, 4L),
+    SHORT(short.class, 16, 2L);
 
     public static final JavaType match(final Class<?> aClass) {
         for (final JavaType tmpType : JavaType.values()) {
