@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -26,12 +26,13 @@ import org.ojalgo.array.BasicArray;
 import org.ojalgo.function.constant.PrimitiveMath;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
-import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.matrix.store.TransformableRegion;
 import org.ojalgo.matrix.transformation.Householder;
 import org.ojalgo.matrix.transformation.HouseholderReference;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.scalar.ComplexNumber;
+import org.ojalgo.scalar.Quadruple;
 import org.ojalgo.scalar.Quaternion;
 import org.ojalgo.scalar.RationalNumber;
 import org.ojalgo.structure.Access2D;
@@ -39,12 +40,12 @@ import org.ojalgo.structure.Access2D;
 /**
  * @author apete
  */
-abstract class DeferredTridiagonal<N extends Comparable<N>> extends TridiagonalDecomposition<N> {
+abstract class DeferredTridiagonal<N extends Comparable<N>> extends DenseTridiagonal<N> {
 
-    static final class Complex extends DeferredTridiagonal<ComplexNumber> {
+    static final class C128 extends DeferredTridiagonal<ComplexNumber> {
 
-        Complex() {
-            super(GenericStore.COMPLEX);
+        C128() {
+            super(GenericStore.C128);
         }
 
         @Override
@@ -53,7 +54,8 @@ abstract class DeferredTridiagonal<N extends Comparable<N>> extends TridiagonalD
             Array1D<ComplexNumber> retVal = Array1D.C128.make(offDiagonal.count());
             retVal.fillAll(ComplexNumber.ONE);
 
-            BasicArray<ComplexNumber> tmpSubdiagonal = offDiagonal; // superDiagonal should be the conjugate of this but it is set to the same value
+            BasicArray<ComplexNumber> tmpSubdiagonal = offDiagonal; // superDiagonal should be the conjugate
+                                                                    // of this but it is set to the same value
 
             ComplexNumber tmpVal = null;
             for (int i = 0; i < tmpSubdiagonal.count(); i++) {
@@ -77,23 +79,10 @@ abstract class DeferredTridiagonal<N extends Comparable<N>> extends TridiagonalD
 
     }
 
-    static final class Primitive extends DeferredTridiagonal<Double> {
+    static final class H256 extends DeferredTridiagonal<Quaternion> {
 
-        Primitive() {
-            super(Primitive64Store.FACTORY);
-        }
-
-        @Override
-        Array1D<Double> makeReal(final BasicArray<Double> offDiagonal) {
-            return null;
-        }
-
-    }
-
-    static final class Quat extends DeferredTridiagonal<Quaternion> {
-
-        Quat() {
-            super(GenericStore.QUATERNION);
+        H256() {
+            super(GenericStore.H256);
         }
 
         @Override
@@ -102,7 +91,8 @@ abstract class DeferredTridiagonal<N extends Comparable<N>> extends TridiagonalD
             Array1D<Quaternion> retVal = Array1D.H256.make(offDiagonal.count());
             retVal.fillAll(Quaternion.ONE);
 
-            BasicArray<Quaternion> tmpSubdiagonal = offDiagonal; // superDiagonal should be the conjugate of this but it is set to the same value
+            BasicArray<Quaternion> tmpSubdiagonal = offDiagonal; // superDiagonal should be the conjugate of
+                                                                 // this but it is set to the same value
 
             Quaternion tmpVal = null;
             for (int i = 0; i < tmpSubdiagonal.count(); i++) {
@@ -126,10 +116,10 @@ abstract class DeferredTridiagonal<N extends Comparable<N>> extends TridiagonalD
 
     }
 
-    static final class Rational extends DeferredTridiagonal<RationalNumber> {
+    static final class Q128 extends DeferredTridiagonal<RationalNumber> {
 
-        Rational() {
-            super(GenericStore.RATIONAL);
+        Q128() {
+            super(GenericStore.Q128);
         }
 
         @Override
@@ -138,6 +128,31 @@ abstract class DeferredTridiagonal<N extends Comparable<N>> extends TridiagonalD
         }
     }
 
+    static final class R064 extends DeferredTridiagonal<Double> {
+
+        R064() {
+            super(R064Store.FACTORY);
+        }
+
+        @Override
+        Array1D<Double> makeReal(final BasicArray<Double> offDiagonal) {
+            return null;
+        }
+
+    }
+
+    static final class R128 extends DeferredTridiagonal<Quadruple> {
+
+        R128() {
+            super(GenericStore.R128);
+        }
+
+        @Override
+        Array1D<Quadruple> makeReal(final BasicArray<Quadruple> offDiagonal) {
+            return null;
+        }
+    }
+
     private transient BasicArray<N> myDiagD = null;
     private transient BasicArray<N> myDiagE = null;
     private Array1D<N> myInitDiagQ = null;
@@ -146,7 +161,7 @@ abstract class DeferredTridiagonal<N extends Comparable<N>> extends TridiagonalD
         super(factory);
     }
 
-    public boolean decompose(final Access2D.Collectable<N, ? super PhysicalStore<N>> matrix) {
+    public boolean decompose(final Access2D.Collectable<N, ? super TransformableRegion<N>> matrix) {
 
         this.reset();
 
@@ -155,7 +170,7 @@ abstract class DeferredTridiagonal<N extends Comparable<N>> extends TridiagonalD
         try {
 
             MatrixStore<N> logicallyTriangularMatrix = this.collect(matrix).triangular(false, false);
-            //TODO Not optimal code here!
+            // TODO Not optimal code here!
             DecompositionStore<N> inPlace = this.setInPlace(logicallyTriangularMatrix);
 
             int size = this.getMinDim();
