@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -31,10 +31,12 @@ import org.ojalgo.ProgrammingError;
 import org.ojalgo.array.Array1D;
 import org.ojalgo.array.PlainArray;
 import org.ojalgo.matrix.Provider2D;
+import org.ojalgo.matrix.decomposition.function.ExchangeColumns;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
 import org.ojalgo.matrix.store.R064Store;
+import org.ojalgo.matrix.store.TransformableRegion;
 import org.ojalgo.scalar.ComplexNumber;
 import org.ojalgo.scalar.Quadruple;
 import org.ojalgo.scalar.Quaternion;
@@ -66,8 +68,8 @@ import org.ojalgo.type.context.NumberContext;
  *
  * @author apete
  */
-public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition<N>, MatrixDecomposition.Hermitian<N>, MatrixDecomposition.Determinant<N>,
-        MatrixDecomposition.Values<N>, Provider2D.Eigenpairs {
+public interface Eigenvalue<N extends Comparable<N>>
+        extends MatrixDecomposition.Hermitian<N>, MatrixDecomposition.Determinant<N>, MatrixDecomposition.Values<N>, Provider2D.Eigenpairs {
 
     public static class Eigenpair implements Comparable<Eigenpair> {
 
@@ -154,16 +156,23 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         Eigenvalue<N> make(Structure2D typical, boolean hermitian);
 
         /**
-         * [A][V] = [B][V][D]
+         * Generalised: [A][V] = [B][V][D]
+         *
+         * @see #makeGeneralised(Structure2D, Eigenvalue.Generalisation)
+         * @deprecated v56 Use {@link #makeGeneralised(Structure2D, Eigenvalue.Generalisation)} instead, then
+         *             it's more clear what you're actually doing.
          */
+        @Deprecated
         default Eigenvalue.Generalised<N> makeGeneralised(final Structure2D typical) {
             return this.makeGeneralised(typical, Eigenvalue.Generalisation.A_B);
         }
 
         /**
+         * "Generalised" does NOT refer to general (as in not symmetric/hermitian) matrices, but to
+         * generalised eigenvalue problems.
          * <ul>
-         * <li>http://www.cmth.ph.ic.ac.uk/people/a.mackinnon/Lectures/compphys/node72.html</li>
-         * <li>https://www.netlib.org/lapack/lug/node54.html</li>
+         * <li>http://www.cmth.ph.ic.ac.uk/people/a.mackinnon/Lectures/compphys/node72.html
+         * <li>https://www.netlib.org/lapack/lug/node54.html
          * </ul>
          */
         Eigenvalue.Generalised<N> makeGeneralised(Structure2D typical, Eigenvalue.Generalisation type);
@@ -203,8 +212,8 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
          *
          * @see #computeValuesOnly(org.ojalgo.structure.Access2D.Collectable)
          */
-        default boolean computeValuesOnly(final Access2D.Collectable<N, ? super PhysicalStore<N>> matrixA,
-                final Access2D.Collectable<N, ? super PhysicalStore<N>> matrixB) {
+        default boolean computeValuesOnly(final Access2D.Collectable<N, ? super TransformableRegion<N>> matrixA,
+                final Access2D.Collectable<N, ? super TransformableRegion<N>> matrixB) {
             return this.prepare(matrixB) && this.computeValuesOnly(matrixA);
         }
 
@@ -214,12 +223,12 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
          *
          * @see #decompose(org.ojalgo.structure.Access2D.Collectable)
          */
-        default boolean decompose(final Access2D.Collectable<N, ? super PhysicalStore<N>> matrixA,
-                final Access2D.Collectable<N, ? super PhysicalStore<N>> matrixB) {
+        default boolean decompose(final Access2D.Collectable<N, ? super TransformableRegion<N>> matrixA,
+                final Access2D.Collectable<N, ? super TransformableRegion<N>> matrixB) {
             return this.prepare(matrixB) && this.decompose(matrixA);
         }
 
-        boolean prepare(Access2D.Collectable<N, ? super PhysicalStore<N>> matrixB);
+        boolean prepare(Access2D.Collectable<N, ? super TransformableRegion<N>> matrixB);
 
     }
 
@@ -298,8 +307,9 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         public Eigenvalue<Double> make(final Structure2D typical) {
             if (8192L < typical.countColumns() && typical.count() <= PlainArray.MAX_SIZE) {
                 return new DynamicEvD.R064();
+            } else {
+                return new RawEigenvalue.Dynamic();
             }
-            return new RawEigenvalue.Dynamic();
         }
 
         @Override
@@ -307,13 +317,16 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
             if (hermitian) {
                 if (8192L < typical.countColumns() && typical.count() <= PlainArray.MAX_SIZE) {
                     return new HermitianEvD.R064();
+                } else {
+                    return new RawEigenvalue.Symmetric();
+                }
+            } else {
+                if (8192L < typical.countColumns() && typical.count() <= PlainArray.MAX_SIZE) {
+                    return new GeneralEvD.R064();
+                } else {
+                    return new RawEigenvalue.General();
                 }
-                return new RawEigenvalue.Symmetric();
             }
-            if (8192L < typical.countColumns() && typical.count() <= PlainArray.MAX_SIZE) {
-                return new GeneralEvD.R064();
-            }
-            return new RawEigenvalue.General();
         }
 
         @Override
@@ -359,6 +372,38 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         return Access2D.equals(tmpStore1, tmpStore2, context);
     }
 
+    /**
+     * Sort eigenvalues and corresponding vectors.
+     *
+     * @param values         The eigenvalues to sort
+     * @param vectorExchange A function that can exchange the eigenvectors to follow the new order.
+     */
+    static void sort(final double[] values, final ExchangeColumns vectorExchange) {
+
+        int size = values.length;
+
+        for (int i = 0, limit = size - 1; i < limit; i++) {
+
+            int k = i;
+            double p = Math.abs(values[i]);
+
+            for (int j = i + 1; j < size; j++) {
+                double m = Math.abs(values[j]);
+                if (m > p) {
+                    k = j;
+                    p = m;
+                }
+            }
+
+            if (k != i) {
+                p = values[k];
+                values[k] = values[i];
+                values[i] = p;
+                vectorExchange.exchangeColumns(i, k);
+            }
+        }
+    }
+
     private void copyEigenvector(final int index, final Array1D<ComplexNumber> destination) {
 
         final MatrixStore<N> tmpV = this.getV();
@@ -444,10 +489,41 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
      */
     Array1D<ComplexNumber> getEigenvalues();
 
+    // /**
+    // * @return The matrix exponential
+    // */
+    // default MatrixStore<N> getExponential() {
+    //
+    // final MatrixStore<N> mtrxV = this.getV();
+    //
+    // final PhysicalStore<N> tmpD = this.getD().copy();
+    // tmpD.modifyDiagonal(mtrxV.physical().function().exp());
+    // final MatrixStore<N> mtrxD = tmpD.diagonal();
+    //
+    // return mtrxV.multiply(mtrxD).multiply(mtrxV.conjugate());
+    // }
+    //
+    // /**
+    // * @return The matrix power
+    // */
+    // default MatrixStore<N> getPower(final int exponent) {
+    //
+    // final MatrixStore<N> mtrxV = this.getV();
+    // final MatrixStore<N> mtrxD = this.getD();
+    //
+    // MatrixStore<N> retVal = mtrxV;
+    // for (int e = 0; e < exponent; e++) {
+    // retVal = retVal.multiply(mtrxD);
+    // }
+    // retVal = retVal.multiply(mtrxV.conjugate());
+    //
+    // return retVal;
+    // }
+
     /**
-     * @param realParts An array that will receive the real parts of the eigenvalues
+     * @param realParts      An array that will receive the real parts of the eigenvalues
      * @param imaginaryParts An optional array that, if present, will receive the imaginary parts of the
-     *        eigenvalues
+     *                       eigenvalues
      */
     default void getEigenvalues(final double[] realParts, final Optional<double[]> imaginaryParts) {
 
@@ -471,37 +547,6 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         }
     }
 
-    //    /**
-    //     * @return The matrix exponential
-    //     */
-    //    default MatrixStore<N> getExponential() {
-    //
-    //        final MatrixStore<N> mtrxV = this.getV();
-    //
-    //        final PhysicalStore<N> tmpD = this.getD().copy();
-    //        tmpD.modifyDiagonal(mtrxV.physical().function().exp());
-    //        final MatrixStore<N> mtrxD = tmpD.diagonal();
-    //
-    //        return mtrxV.multiply(mtrxD).multiply(mtrxV.conjugate());
-    //    }
-    //
-    //    /**
-    //     * @return The matrix power
-    //     */
-    //    default MatrixStore<N> getPower(final int exponent) {
-    //
-    //        final MatrixStore<N> mtrxV = this.getV();
-    //        final MatrixStore<N> mtrxD = this.getD();
-    //
-    //        MatrixStore<N> retVal = mtrxV;
-    //        for (int e = 0; e < exponent; e++) {
-    //            retVal = retVal.multiply(mtrxD);
-    //        }
-    //        retVal = retVal.multiply(mtrxV.conjugate());
-    //
-    //        return retVal;
-    //    }
-
     /**
      * @return A complex valued alternative to {@link #getV()}.
      */
@@ -549,7 +594,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
 
     @Override
     default MatrixStore<N> reconstruct() {
-        final MatrixStore<N> mtrxV = this.getV();
+        MatrixStore<N> mtrxV = this.getV();
         MatrixStore<N> mtrxD = this.getD();
         return mtrxV.multiply(mtrxD).multiply(mtrxV.conjugate());
     }
