@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -26,6 +26,7 @@ import org.ojalgo.array.Array1D;
 import org.ojalgo.array.PlainArray;
 import org.ojalgo.matrix.Provider2D;
 import org.ojalgo.matrix.store.MatrixStore;
+import org.ojalgo.matrix.store.PhysicalStore;
 import org.ojalgo.scalar.ComplexNumber;
 import org.ojalgo.scalar.Quadruple;
 import org.ojalgo.scalar.Quaternion;
@@ -51,7 +52,7 @@ import org.ojalgo.type.context.NumberContext;
  *
  * @author apete
  */
-public interface SingularValue<N extends Comparable<N>> extends MatrixDecomposition<N>, MatrixDecomposition.Solver<N>, MatrixDecomposition.EconomySize<N>,
+public interface SingularValue<N extends Comparable<N>> extends MatrixDecomposition.Solver<N>, MatrixDecomposition.EconomySize<N>,
         MatrixDecomposition.RankRevealing<N>, MatrixDecomposition.Values<N>, Provider2D.Condition {
 
     interface Factory<N extends Comparable<N>> extends MatrixDecomposition.Factory<SingularValue<N>> {
@@ -69,21 +70,21 @@ public interface SingularValue<N extends Comparable<N>> extends MatrixDecomposit
 
     }
 
-    Factory<ComplexNumber> C128 = (typical, fullSize) -> new SingularValueDecomposition.C128(fullSize);
+    Factory<ComplexNumber> C128 = (typical, fullSize) -> new DenseSingularValue.C128(fullSize);
 
-    Factory<Quaternion> H256 = (typical, fullSize) -> new SingularValueDecomposition.H256(fullSize);
+    Factory<Quaternion> H256 = (typical, fullSize) -> new DenseSingularValue.H256(fullSize);
 
     Factory<Double> R064 = (typical, fullSize) -> {
         if (fullSize || 1024L < typical.countColumns() && typical.count() <= PlainArray.MAX_SIZE) {
-            return new SingularValueDecomposition.R064(fullSize);
+            return new DenseSingularValue.R064(fullSize);
         } else {
             return new RawSingularValue();
         }
     };
 
-    Factory<RationalNumber> Q128 = (typical, fullSize) -> new SingularValueDecomposition.Q128(fullSize);
+    Factory<RationalNumber> Q128 = (typical, fullSize) -> new DenseSingularValue.Q128(fullSize);
 
-    Factory<Quadruple> R128 = (typical, fullSize) -> new SingularValueDecomposition.R128(fullSize);
+    Factory<Quadruple> R128 = (typical, fullSize) -> new DenseSingularValue.R128(fullSize);
 
     static <N extends Comparable<N>> boolean equals(final MatrixStore<N> matrix, final SingularValue<N> decomposition, final NumberContext context) {
 
@@ -149,6 +150,11 @@ public interface SingularValue<N extends Comparable<N>> extends MatrixDecomposit
         return retVal;
     }
 
+    @Override
+    default void ftran(final PhysicalStore<N> arg) {
+        this.getSolution(arg.copy(), arg);
+    }
+
     /**
      * The condition number.
      *
