@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -37,7 +37,7 @@ public final class HouseholderRight implements MatrixOperation {
     public static IntSupplier PARALLELISM = Parallelism.THREADS;
     public static int THRESHOLD = 256;
 
-    private static final DivideAndConquer.Divider DIVIDER = ProcessingService.INSTANCE.divider();
+    private static final DivideAndConquer.Divider DIVIDER = ProcessingService.INSTANCE.newDivider();
 
     public static void call(final double[] data, final int structure, final int first, final Householder.Primitive64 householder, final double[] work) {
 
