@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -36,6 +36,7 @@ import org.ojalgo.scalar.PrimitiveScalar;
 import org.ojalgo.scalar.Scalar;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D;
+import org.ojalgo.structure.Mutate1D;
 import org.ojalgo.structure.Structure1D;
 import org.ojalgo.structure.Structure2D;
 import org.ojalgo.structure.Structure2D.Logical;
@@ -49,7 +50,7 @@ import org.ojalgo.type.context.NumberContext;
  * <p>
  * A {@linkplain MatrixStore} extends {@linkplain Access2D} (as well as
  * {@linkplain org.ojalgo.structure.Access2D.Visitable} and
- * {@linkplain org.ojalgo.structure.Access2D.Elements}) and defines some futher funtionality - mainly matrix
+ * {@linkplain org.ojalgo.structure.Access2D.Elements}) and defines some further functionality - mainly matrix
  * multiplication.
  * </p>
  * <p>
@@ -65,7 +66,7 @@ import org.ojalgo.type.context.NumberContext;
  * @author apete
  */
 public interface MatrixStore<N extends Comparable<N>> extends Matrix2D<N, MatrixStore<N>>, ElementsSupplier<N>, Access2D.Visitable<N>, Access2D.Sliceable<N>,
-        Structure2D.ReducibleTo1D<ElementsSupplier<N>>, Structure2D.Logical<Access2D<N>, MatrixStore<N>> {
+        Structure2D.ReducibleTo1D<ElementsSupplier<N>>, Structure2D.Logical<Access2D<N>, MatrixStore<N>>, Access1D.Collectable<N, Mutate1D> {
 
     @Override
     default MatrixStore<N> above(final Access2D<N>... matrices) {
@@ -438,12 +439,12 @@ public interface MatrixStore<N extends Comparable<N>> extends Matrix2D<N, Matrix
     @Override
     default MatrixStore<N> multiply(final MatrixStore<N> right) {
 
-        long tmpCountRows = this.countRows();
-        long tmpCountColumns = right.countColumns();
+        int nbRows = this.getRowDim();
+        int nbCols = right.getColDim();
 
-        PhysicalStore<N> retVal = this.physical().make(tmpCountRows, tmpCountColumns);
+        PhysicalStore<N> retVal = this.physical().make(nbRows, nbCols);
 
-        this.multiply(right, retVal);
+        retVal.fillByMultiplying(this, right);
 
         return retVal;
     }
@@ -829,6 +830,13 @@ public interface MatrixStore<N extends Comparable<N>> extends Matrix2D<N, Matrix
         return new SuperimposedStore<>(this, row, col, AbstractStore.cast(this.physical(), matrix));
     }
 
+    @Override
+    default void supplyTo(final Mutate1D receiver) {
+        for (long i = 0L, limit = Math.min(this.count(), receiver.count()); i < limit; i++) {
+            receiver.set(i, this.get(i));
+        }
+    }
+
     @Override
     default void supplyTo(final TransformableRegion<N> receiver) {
         if (!receiver.isAcceptable(this)) {
