@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -39,12 +39,14 @@ import org.ojalgo.function.aggregator.PrimitiveAggregator;
 import org.ojalgo.function.constant.PrimitiveMath;
 import org.ojalgo.function.special.MissingMath;
 import org.ojalgo.matrix.operation.MultiplyBoth;
+import org.ojalgo.matrix.operation.MultiplyNeither;
 import org.ojalgo.matrix.transformation.Householder;
 import org.ojalgo.matrix.transformation.Rotation;
 import org.ojalgo.scalar.PrimitiveScalar;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D;
 import org.ojalgo.structure.Factory2D;
+import org.ojalgo.structure.Mutate1D;
 import org.ojalgo.structure.Structure2D;
 import org.ojalgo.type.NumberDefinition;
 import org.ojalgo.type.math.MathType;
@@ -174,29 +176,6 @@ public final class RawStore implements PhysicalStore<Double>, Factory2D.Builder<
         return retVal;
     }
 
-    private static void multiply(final double[][] product, final double[][] left, final double[][] right) {
-
-        int tmpRowsCount = product.length;
-        int tmpComplexity = right.length;
-        int tmpColsCount = right[0].length;
-
-        double[] tmpRow;
-        double[] tmpColumn = new double[tmpComplexity];
-        for (int j = 0; j < tmpColsCount; j++) {
-            for (int k = 0; k < tmpComplexity; k++) {
-                tmpColumn[k] = right[k][j];
-            }
-            for (int i = 0; i < tmpRowsCount; i++) {
-                tmpRow = left[i];
-                double tmpVal = 0.0;
-                for (int k = 0; k < tmpComplexity; k++) {
-                    tmpVal += tmpRow[k] * tmpColumn[k];
-                }
-                product[i][j] = tmpVal;
-            }
-        }
-    }
-
     static Rotation.Primitive cast(final Rotation<Double> aTransf) {
         if (aTransf instanceof Rotation.Primitive) {
             return (Rotation.Primitive) aTransf;
@@ -363,23 +342,16 @@ public final class RawStore implements PhysicalStore<Double>, Factory2D.Builder<
         FillMatchingDual.fillAll(data, supplier);
     }
 
-    @Override
-    public void fillCompatible(final Access2D<Double> left, final BinaryFunction<Double> operator, final Access2D<Double> right) {
-        FillCompatible.invoke(data, left, operator, right);
-    }
-
     @Override
     public void fillByMultiplying(final Access1D<Double> left, final Access1D<Double> right) {
 
-        int complexity = Math.toIntExact(left.count() / this.countRows());
-        if (complexity != Math.toIntExact(right.count() / this.countColumns())) {
+        int cmplxt = Math.toIntExact(left.count() / this.countRows());
+
+        if (cmplxt != Math.toIntExact(right.count() / this.countColumns())) {
             ProgrammingError.throwForMultiplicationNotPossible();
         }
 
-        double[][] rawLeft = RawStore.extract(left, this.getRowDim());
-        double[][] rawRight = RawStore.extract(right, complexity);
-
-        RawStore.multiply(data, rawLeft, rawRight);
+        MultiplyNeither.fill(data, RawStore.extract(left, this.getRowDim()), RawStore.extract(right, cmplxt));
     }
 
     @Override
@@ -392,6 +364,11 @@ public final class RawStore implements PhysicalStore<Double>, Factory2D.Builder<
         FillMatchingDual.fillColumn(data, Math.toIntExact(row), Math.toIntExact(col), supplier);
     }
 
+    @Override
+    public void fillCompatible(final Access2D<Double> left, final BinaryFunction<Double> operator, final Access2D<Double> right) {
+        FillCompatible.invoke(data, left, operator, right);
+    }
+
     @Override
     public void fillDiagonal(final long row, final long col, final Double value) {
         FillMatchingDual.fillDiagonal(data, Math.toIntExact(row), Math.toIntExact(col), value.doubleValue());
@@ -622,15 +599,13 @@ public final class RawStore implements PhysicalStore<Double>, Factory2D.Builder<
     @Override
     public RawStore multiply(final MatrixStore<Double> right) {
 
-        int tmpRowDim = data.length;
-        int tmpComplexity = myNumberOfColumns;
-        int tmpColDim = (int) (right.count() / tmpComplexity);
+        int nbRows = data.length;
+        int cmplxt = myNumberOfColumns;
+        int nbCols = Math.toIntExact(right.count() / cmplxt);
 
-        RawStore retVal = new RawStore(tmpRowDim, tmpColDim);
+        RawStore retVal = new RawStore(nbRows, nbCols);
 
-        double[][] tmpRight = RawStore.extract(right, tmpComplexity);
-
-        RawStore.multiply(retVal.data, data, tmpRight);
+        MultiplyNeither.add(retVal.data, data, RawStore.extract(right, cmplxt));
 
         return retVal;
     }
@@ -709,6 +684,17 @@ public final class RawStore implements PhysicalStore<Double>, Factory2D.Builder<
         SubstituteForwards.invoke(data, body, unitDiagonal, conjugated, identity);
     }
 
+    @Override
+    public void supplyTo(final Mutate1D receiver) {
+        int structure = data.length;
+        for (int i = 0; i < structure; i++) {
+            double[] row = data[i];
+            for (int j = 0; j < myNumberOfColumns; j++) {
+                receiver.set(Structure2D.index(structure, i, j), row[j]);
+            }
+        }
+    }
+
     @Override
     public void supplyTo(final TransformableRegion<Double> receiver) {
         for (int i = 0; i < data.length; i++) {
@@ -861,11 +847,6 @@ public final class RawStore implements PhysicalStore<Double>, Factory2D.Builder<
         }
     }
 
-    @Override
-    public MatrixStore<Double> transpose() {
-        return new TransposedStore<>(this);
-    }
-
     @Override
     public void visitAll(final VoidFunction<Double> visitor) {
         VisitAll.visitAll(data, visitor);
