@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,8 +21,7 @@
  */
 package org.ojalgo.matrix.store;
 
-import static org.ojalgo.function.constant.PrimitiveMath.E;
-import static org.ojalgo.function.constant.PrimitiveMath.ZERO;
+import static org.ojalgo.function.constant.PrimitiveMath.*;
 
 import java.util.Arrays;
 import java.util.Set;
@@ -65,7 +64,7 @@ import org.ojalgo.type.math.MathType;
  * <li>Use the {@link Builder} to build the matrix.
  * </ul>
  */
-public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N> implements TransformableRegion<N> {
+public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N> implements TransformableRegion<N>, SparseStructure2D {
 
     /**
      * May be a preferable way to build a sparse matrix if:
@@ -292,14 +291,13 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
 
         super(factory, nbRows, nbCols);
 
-        myElements = SparseArray.factory(factory.array()).initial(initial.applyAsInt(nbRows, nbCols)).make(this.count());
+        myElements = SparseArray.factory(factory.array()).initial(initial.applyAsInt(nbRows, nbCols)).make(this.size());
         myFirsts = new int[nbRows];
         myLimits = new int[nbRows];
         Arrays.fill(myFirsts, nbCols);
         // Arrays.fill(myLimits, 0); // Behövs inte, redan 0
 
-        Class<? extends Comparable> tmpType = factory.scalar().zero().get().getClass();
-        myMultiplier = Subregion2D.findMultiplier(tmpType, nbRows, nbCols);
+        myMultiplier = Subregion2D.findMultiplier(factory.getMathType(), nbRows, nbCols);
     }
 
     @Override
@@ -314,6 +312,11 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
         this.updateNonZeros(row, col);
     }
 
+    @Override
+    public int countNonzeros() {
+        return myElements.countNonzeros();
+    }
+
     @Override
     public double doubleValue(final int row, final int col) {
         return myElements.doubleValue(Structure2D.index(myFirsts.length, row, col));
@@ -653,7 +656,6 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
     }
 
     @Override
-    @SuppressWarnings("unchecked")
     public void reduceColumns(final Aggregator aggregator, final Mutate1D receiver) {
         if (aggregator == Aggregator.SUM && receiver instanceof Mutate1D.Modifiable) {
             if (this.isPrimitive()) {
@@ -667,7 +669,6 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
     }
 
     @Override
-    @SuppressWarnings("unchecked")
     public void reduceRows(final Aggregator aggregator, final Mutate1D receiver) {
         if (aggregator == Aggregator.SUM && receiver instanceof Mutate1D.Modifiable) {
             if (this.isPrimitive()) {
@@ -732,6 +733,83 @@ public final class SparseStore<N extends Comparable<N>> extends FactoryStore<N>
         myElements.supplyNonZerosTo(receiver);
     }
 
+    @Override
+    public R064CSC toCSC() {
+
+        int nbRows = this.getRowDim();
+        int nbCols = this.getColDim();
+        int nnz = myElements.countNonzeros();
+
+        double[] values = new double[nnz];
+        int[] rowIndices = new int[nnz];
+        int[] colPointers = new int[nbCols + 1];
+
+        int pos = 0;
+        int currentCol = 0;
+        colPointers[0] = 0;
+
+        for (NonzeroView<N> nz : myElements.nonzeros()) {
+            long index = nz.index();
+            int row = Structure2D.row(index, nbRows);
+            int col = Structure2D.column(index, nbRows);
+
+            // If we've moved to a new column, fill colPointers
+            while (currentCol < col) {
+                colPointers[++currentCol] = pos;
+            }
+
+            values[pos] = nz.doubleValue();
+            rowIndices[pos] = row;
+            pos++;
+        }
+
+        // Fill remaining colPointers
+        while (currentCol < nbCols) {
+            colPointers[++currentCol] = pos;
+        }
+
+        return new R064CSC(nbRows, nbCols, values, rowIndices, colPointers);
+    }
+
+    @Override
+    public R064CSR toCSR() {
+
+        int nbRows = this.getRowDim();
+        int nbCols = this.getColDim();
+
+        int nnz = 0;
+        // First pass: count nonzeros per row
+        int[] rowCounts = new int[nbRows];
+        for (ElementView2D<N, ?> element : this.nonzeros()) {
+            int row = Math.toIntExact(element.row());
+            rowCounts[row]++;
+            nnz++;
+        }
+        double[] values = new double[nnz];
+        int[] colIndices = new int[nnz];
+        int[] rowPointers = new int[nbRows + 1];
+        // Compute rowPointers
+        int pos = 0;
+        for (int i = 0; i < nbRows; i++) {
+            rowPointers[i] = pos;
+            pos += rowCounts[i];
+        }
+        rowPointers[nbRows] = nnz;
+        // Second pass: fill values and colIndices
+        int[] next = new int[nbRows];
+        System.arraycopy(rowPointers, 0, next, 0, nbRows);
+        for (ElementView2D<N, ?> element : this.nonzeros()) {
+            int row = Math.toIntExact(element.row());
+            int col = Math.toIntExact(element.column());
+            double value = element.doubleValue();
+            int idx = next[row]++;
+            values[idx] = value;
+            colIndices[idx] = col;
+        }
+
+        return new R064CSR(nbRows, nbCols, values, colIndices, rowPointers);
+    }
+
     @Override
     public void visitColumn(final long row, final long col, final VoidFunction<N> visitor) {
 
