@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -28,12 +28,12 @@ import org.ojalgo.matrix.store.PhysicalStore;
 import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D;
-import org.ojalgo.structure.Structure2D;
 
 abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> FULL_1X1 = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.full1X1(body, rhs, preallocated);
             return preallocated;
@@ -43,6 +43,7 @@ abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> FULL_2X2 = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.full2X2(body, rhs, preallocated);
             return preallocated;
@@ -52,6 +53,7 @@ abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> FULL_3X3 = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.full3X3(body, rhs, preallocated);
             return preallocated;
@@ -61,6 +63,7 @@ abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> FULL_4X4 = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.full4X4(body, rhs, preallocated);
             return preallocated;
@@ -70,6 +73,7 @@ abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> FULL_5X5 = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.full5X5(body, rhs, preallocated);
             return preallocated;
@@ -79,6 +83,7 @@ abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> LEAST_SQUARES = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.leastSquares(body, rhs, preallocated);
             return preallocated;
@@ -88,6 +93,7 @@ abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> SYMMETRIC_2X2 = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.symmetric2X2(body, rhs, preallocated);
             return preallocated;
@@ -97,6 +103,7 @@ abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> SYMMETRIC_3X3 = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.symmetric3X3(body, rhs, preallocated);
             return preallocated;
@@ -106,6 +113,7 @@ abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> SYMMETRIC_4X4 = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.symmetric4X4(body, rhs, preallocated);
             return preallocated;
@@ -115,6 +123,7 @@ abstract class AbstractSolver implements SolverTask<Double> {
 
     static final SolverTask<Double> SYMMETRIC_5X5 = new AbstractSolver() {
 
+        @Override
         public MatrixStore<Double> solve(final Access2D<?> body, final Access2D<?> rhs, final PhysicalStore<Double> preallocated) throws RecoverableCondition {
             AbstractSolver.symmetric5X5(body, rhs, preallocated);
             return preallocated;
@@ -705,8 +714,9 @@ abstract class AbstractSolver implements SolverTask<Double> {
         super();
     }
 
-    public final PhysicalStore<Double> preallocate(final Structure2D templateBody, final Structure2D templateRHS) {
-        return R064Store.FACTORY.make(templateBody.countColumns(), 1L);
+    @Override
+    public final PhysicalStore<Double> preallocate(final int nbEquations, final int nbVariables, final int nbSolutions) {
+        return R064Store.FACTORY.make(nbVariables, nbSolutions);
     }
 
 }
