@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -41,7 +41,6 @@ import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D;
 import org.ojalgo.structure.ElementView2D;
-import org.ojalgo.structure.Structure2D;
 import org.ojalgo.type.context.NumberContext;
 
 /**
@@ -116,7 +115,7 @@ public abstract class IterativeSolverTask implements SolverTask<Double> {
 
     }
 
-    static final NumberContext DEFAULT = NumberContext.ofMath(MathContext.DECIMAL128);
+    static final NumberContext DEFAULT = NumberContext.ofMath(MathContext.DECIMAL64);
 
     static List<Equation> toListOfRows(final Access2D<?> body, final Access2D<?> rhs) {
 
@@ -189,11 +188,12 @@ public abstract class IterativeSolverTask implements SolverTask<Double> {
         return new Configurator(this);
     }
 
-    public final PhysicalStore<Double> preallocate(final Structure2D templateBody, final Structure2D templateRHS) {
-        if (templateRHS.countColumns() != 1L) {
+    @Override
+    public PhysicalStore<Double> preallocate(final int nbEquations, final int nbVariables, final int nbSolutions) {
+        if (nbSolutions != 1) {
             throw new IllegalArgumentException("The RHS must have precisely 1 column!");
         }
-        return R064Store.FACTORY.make(templateBody.countColumns(), 1L);
+        return R064Store.FACTORY.make(nbVariables, nbSolutions);
     }
 
     public final Optional<MatrixStore<Double>> solve(final MatrixStore<Double> body, final MatrixStore<Double> rhs) {
