@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,7 +22,6 @@
 package org.ojalgo.matrix.transformation;
 
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.structure.Access2D.Collectable;
 import org.ojalgo.structure.Structure2D;
 
 /**
@@ -89,11 +88,6 @@ public interface InvertibleFactor<N extends Comparable<N>> extends Structure2D {
         return new IdentityFactor<>(dim);
     }
 
-    default void btran(final Collectable<N, ? super PhysicalStore<N>> lhs, final PhysicalStore<N> solution) {
-        lhs.supplyTo(solution);
-        this.btran(solution);
-    }
-
     /**
      * Backwards-transformation
      * <p>
@@ -104,11 +98,6 @@ public interface InvertibleFactor<N extends Comparable<N>> extends Structure2D {
      */
     void btran(PhysicalStore<N> arg);
 
-    default void ftran(final Collectable<N, ? super PhysicalStore<N>> rhs, final PhysicalStore<N> solution) {
-        rhs.supplyTo(solution);
-        this.ftran(solution);
-    }
-
     /**
      * Forward-transformation
      * <p>
