@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -125,7 +125,7 @@ public final class ServiceClient {
             } else if (!myBuilder.equals(other.myBuilder)) {
                 return false;
             }
-            if (!myForm.equals(other.myForm) || (myMethod != other.myMethod)) {
+            if (!myForm.equals(other.myForm) || myMethod != other.myMethod) {
                 return false;
             }
             if (myResourceSpecification == null) {
@@ -187,12 +187,12 @@ public final class ServiceClient {
         public int hashCode() {
             final int prime = 31;
             int result = 1;
-            result = prime * result + ((myBody == null) ? 0 : myBody.hashCode());
-            result = prime * result + ((myBuilder == null) ? 0 : myBuilder.hashCode());
+            result = prime * result + (myBody == null ? 0 : myBody.hashCode());
+            result = prime * result + (myBuilder == null ? 0 : myBuilder.hashCode());
             result = prime * result + myForm.hashCode();
-            result = prime * result + ((myMethod == null) ? 0 : myMethod.hashCode());
-            result = prime * result + ((myResourceSpecification == null) ? 0 : myResourceSpecification.hashCode());
-            return prime * result + ((mySession == null) ? 0 : mySession.hashCode());
+            result = prime * result + (myMethod == null ? 0 : myMethod.hashCode());
+            result = prime * result + (myResourceSpecification == null ? 0 : myResourceSpecification.hashCode());
+            return prime * result + (mySession == null ? 0 : mySession.hashCode());
         }
 
         public ServiceClient.Request header(final String name, final String value) {
@@ -212,11 +212,6 @@ public final class ServiceClient {
             return this;
         }
 
-        public ServiceClient.Request method(final String method, final BodyPublisher bodyPublisher) {
-            myBuilder.method(method, bodyPublisher);
-            return this;
-        }
-
         public ServiceClient.Request path(final String path) {
             myResourceSpecification.setPath(path);
             myRequest = null;
@@ -232,6 +227,7 @@ public final class ServiceClient {
             return this;
         }
 
+        @Override
         public void print(final BasicLogger receiver) {
             mySession.print(receiver);
             receiver.println("Request URI: {}", this.getURI());
@@ -291,6 +287,7 @@ public final class ServiceClient {
         }
 
         BodyPublisher body() {
+
             if (myBody != null) {
                 Class<? extends Object> bodyType = myBody.getClass();
                 if (byte[].class.isAssignableFrom(bodyType)) {
@@ -314,21 +311,21 @@ public final class ServiceClient {
                 BodyPublisher body = this.body();
 
                 switch (myMethod) {
-                case DELETE:
-                    myBuilder.DELETE();
-                    break;
-                case GET:
-                    myBuilder.GET();
-                    break;
-                case POST:
-                    myBuilder.POST(body);
-                    break;
-                case PUT:
-                    myBuilder.PUT(body);
-                    break;
-                default:
-                    myBuilder.method(myMethod.name(), body);
-                    break;
+                    case DELETE:
+                        myBuilder.DELETE();
+                        break;
+                    case GET:
+                        myBuilder.GET();
+                        break;
+                    case POST:
+                        myBuilder.POST(body);
+                        break;
+                    case PUT:
+                        myBuilder.PUT(body);
+                        break;
+                    default:
+                        myBuilder.method(myMethod.name(), body);
+                        break;
                 }
 
                 myRequest = myBuilder.build();
@@ -428,8 +425,8 @@ public final class ServiceClient {
         public int hashCode() {
             final int prime = 31;
             int result = 1;
-            result = prime * result + ((myFutureResponse == null) ? 0 : myFutureResponse.hashCode());
-            return prime * result + ((mySession == null) ? 0 : mySession.hashCode());
+            result = prime * result + (myFutureResponse == null ? 0 : myFutureResponse.hashCode());
+            return prime * result + (mySession == null ? 0 : mySession.hashCode());
         }
 
         public boolean isDone() {
@@ -441,13 +438,14 @@ public final class ServiceClient {
          */
         public boolean isResponseOK() {
             int statusCode = this.getStatusCode();
-            if ((200 <= statusCode) && (statusCode < 300)) {
+            if (200 <= statusCode && statusCode < 300) {
                 return true;
             } else {
                 return false;
             }
         }
 
+        @Override
         public void print(final BasicLogger receiver) {
             receiver.println("Response body: {}", this.toString());
             receiver.println("Response headers: {}", this.getResponse().headers().map());
@@ -524,6 +522,7 @@ public final class ServiceClient {
             return this;
         }
 
+        @Override
         public void print(final BasicLogger receiver) {
             receiver.println("Session parameters: {}", myParameters);
             receiver.println("Session cookies: {}", myCookieManager.getCookieStore().getCookies());
@@ -626,7 +625,7 @@ public final class ServiceClient {
     public int hashCode() {
         final int prime = 31;
         int result = 1;
-        return prime * result + ((myBuilder == null) ? 0 : myBuilder.hashCode());
+        return prime * result + (myBuilder == null ? 0 : myBuilder.hashCode());
     }
 
     public ServiceClient priority(final int priority) {
