@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -30,7 +30,6 @@ import java.io.Reader;
 import java.io.UnsupportedEncodingException;
 import java.util.function.Predicate;
 
-import org.ojalgo.type.function.AutoSupplier;
 import org.ojalgo.type.function.OperatorWithException;
 
 public final class TextLineReader implements FromFileReader<String> {
@@ -71,6 +70,10 @@ public final class TextLineReader implements FromFileReader<String> {
         return new TextLineReader(filter.apply(file.newInputStream()));
     }
 
+    public static TextLineReader of(final String pathname) {
+        return TextLineReader.of(new File(pathname));
+    }
+
     private final BufferedReader myReader;
 
     public TextLineReader(final InputStream inputStream) {
@@ -104,19 +107,19 @@ public final class TextLineReader implements FromFileReader<String> {
     /**
      * The filter is {@link TextLineReader#isLineOK(String)}
      */
-    public <T> AutoSupplier<T> withFilteredParser(final Parser<T> parser) {
-        return AutoSupplier.mapped(this, TextLineReader::isLineOK, parser::parse);
+    public <T> FromFileReader<T> withFilteredParser(final Parser<T> parser) {
+        return new MappedReader<>(this, TextLineReader::isLineOK, parser::parse);
     }
 
     /**
      * The filter could for instance be {@link TextLineReader#isLineOK(String)}
      */
-    public <T> AutoSupplier<T> withFilteredParser(final Predicate<String> filter, final Parser<T> parser) {
-        return AutoSupplier.mapped(this, filter, parser::parse);
+    public <T> FromFileReader<T> withFilteredParser(final Predicate<String> filter, final Parser<T> parser) {
+        return new MappedReader<>(this, filter, parser::parse);
     }
 
-    public <T> AutoSupplier<T> withParser(final Parser<T> parser) {
-        return AutoSupplier.mapped(this, parser::parse);
+    public <T> FromFileReader<T> withParser(final Parser<T> parser) {
+        return new MappedReader<>(this, parser::parse);
     }
 
 }
