@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -50,6 +50,7 @@ import org.ojalgo.optimisation.linear.LinearSolver;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Structure1D.IntIndex;
 import org.ojalgo.structure.Structure2D.IntRowColumn;
+import org.ojalgo.type.EnumBitSet;
 import org.ojalgo.type.context.NumberContext;
 import org.ojalgo.type.keyvalue.EntryPair;
 import org.ojalgo.type.keyvalue.EntryPair.KeyedPrimitive;
@@ -71,11 +72,12 @@ import org.ojalgo.type.keyvalue.EntryPair.KeyedPrimitive;
  * <p>
  * Basic instructions:
  * <ol>
- * <li>Define (create) a set of variables. Set contribution weights and lower/upper limits as needed.</li>
- * <li>Create a model using that set of variables.</li>
- * <li>Add expressions to the model. The model is the expression factory. Set contribution weights and
- * lower/upper limits as needed.</li>
- * <li>Solve your problem using either minimise() or maximise()</li>
+ * <li>Create a model (new ExpressionsBasedModel()).
+ * <li>Define variables using model.addVariable() and set contribution weights and lower/upper limits as
+ * needed.
+ * <li>Add expressions to the model using model.addExpression() and set contribution weights and lower/upper
+ * limits as needed.
+ * <li>Solve your problem using model.minimise() or model.maximise()
  * </ol>
  * <p>
  * When using this class you do not need to worry about which solver will actually be used. The docs of the
@@ -93,8 +95,8 @@ import org.ojalgo.type.keyvalue.EntryPair.KeyedPrimitive;
  * <li>It's the only way to access the integer solver.</li>
  * </ol>
  * <p>
- * Different solvers can be used, and ojAlgo comes with collection built in. The default built-in solvers can
- * handle anything you can model with a couple of restrictions:
+ * Different solvers can be used, and ojAlgo comes with a collection built in. The default built-in solvers
+ * can handle anything you can model with a couple of restrictions:
  * </p>
  * <ul>
  * <li>No quadratic constraints (The plan is that future versions should not have this limitation.)</li>
@@ -187,7 +189,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
      * {@link ExpressionsBasedModel.Integration#toModelState(org.ojalgo.optimisation.Optimisation.Result, ExpressionsBasedModel)}.
      * </ol>
      */
-    public static interface EntityMap extends ProblemStructure {
+    public interface EntityMap extends ProblemStructure {
 
         /**
          * The number of variables, in the solver, that directly correspond to a model variable. (Not slack or
@@ -212,7 +214,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
          * supplied index.
          *
          * @param ids Index of solver slack variable (If there are 3 slack variables this input argument
-         *        should be in the range [0.2].)
+         *            should be in the range [0.2].)
          */
         EntryPair<ModelEntity<?>, ConstraintType> getSlack(int ids);
 
@@ -316,20 +318,62 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
             return model.indexOfFreeVariable(variable);
         }
 
-        protected final boolean isSwitch(final ExpressionsBasedModel model) {
-            return model.isIntegrationSwitch();
+        protected final boolean isSwitch(final ExpressionsBasedModel model, final IntegrationProperty property) {
+            return model.isIntegrationSwitch(property);
         }
 
         protected final ExpressionsBasedModel.Validator newValidator(final ExpressionsBasedModel model) {
             return new ExpressionsBasedModel.Validator(model, this, model.getKnownSolution(), model.getValidationFailureHandler());
         }
 
-        protected final void setSwitch(final ExpressionsBasedModel model, final boolean value) {
-            model.setIntegrationSwitch(value);
+        protected final void setSwitch(final ExpressionsBasedModel model, final IntegrationProperty property, final boolean value) {
+            model.setIntegrationSwitch(property, value);
         }
 
     }
 
+    /**
+     * Various switches that can be set by solver integrations to control its own behaviour. Typically used
+     * when a single integration is a facade delegating to a set of (switching between a pair of) other
+     * integrations.
+     * <p>
+     * The various properties are here are for very specific use cases, but have been given generic names to
+     * encourage reuse.
+     * <p>
+     * Solver integrations are (absolutely have to be) stateless. If they contain logic that cause them to
+     * take different paths, information about that needs to be stored in the model (or solver) instance.
+     * That's what these properties are for.
+     *
+     * @see ExpressionsBasedModel.Integration#setSwitch(ExpressionsBasedModel, IntegrationProperty, boolean)
+     * @see ExpressionsBasedModel.Integration#isSwitch(ExpressionsBasedModel, IntegrationProperty)
+     */
+    public enum IntegrationProperty {
+
+        /**
+         * Any integration that can switch between Java and native code solvers.
+         * <p>
+         * JAVA==false, NATIVE==true
+         */
+        JAVA_OR_NATIVE_CODE,
+        /**
+         * Any integration that can handle both LP and QP models.
+         * <p>
+         * LP==false, QP==true
+         */
+        LP_OR_QP,
+        /**
+         * Any LP solver integration that can switch between primal and dual algorithm implementations.
+         * <p>
+         * PRIMAL==false, DUAL==true
+         */
+        PRIMAL_OR_DUAL_LP,
+        /**
+         * Something temporary or experimental that does not yet have a specific constant.
+         */
+        TEMPORARY;
+
+    }
+
     public static abstract class Presolver extends Simplifier<Expression, Presolver> {
 
         protected Presolver(final int executionOrder) {
@@ -337,9 +381,6 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         }
 
         /**
-         * @param remaining TODO
-         * @param lower TODO
-         * @param upper TODO
          * @return True if any model entity was modified so that a re-run of the presolvers is necessary -
          *         typically when/if a variable was fixed.
          */
@@ -401,7 +442,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
 
         /**
          * @param originalModel Baseline model.
-         * @param integration The integration used to translate between model and solver state.
+         * @param integration   The integration used to translate between model and solver state.
          * @param knownSolution Not just any feasible solution. It needs to be the optimal solution.
          */
         Validator(final ExpressionsBasedModel originalModel, final Optimisation.Integration<ExpressionsBasedModel, ?> integration, final Result knownSolution,
@@ -442,6 +483,37 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
 
     }
 
+    static final class IntegrationWrapper extends ExpressionsBasedModel.Integration<Optimisation.Solver> {
+
+        private final Optimisation.Integration<ExpressionsBasedModel, ?> myDelegate;
+
+        IntegrationWrapper(final Optimisation.Integration<ExpressionsBasedModel, ?> delegate) {
+            super();
+            myDelegate = delegate;
+        }
+
+        @Override
+        public Solver build(final ExpressionsBasedModel model) {
+            return myDelegate.build(model);
+        }
+
+        @Override
+        public boolean isCapable(final ExpressionsBasedModel model) {
+            return myDelegate.isCapable(model);
+        }
+
+        @Override
+        public Result toModelState(final Result solverState, final ExpressionsBasedModel model) {
+            return myDelegate.toModelState(solverState, model);
+        }
+
+        @Override
+        public Result toSolverState(final Result modelState, final ExpressionsBasedModel model) {
+            return myDelegate.toSolverState(modelState, model);
+        }
+
+    }
+
     static abstract class Simplifier<ME extends ModelEntity<?>, S extends Simplifier<?, ?>> implements Comparable<S> {
 
         private final int myExecutionOrder;
@@ -645,6 +717,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
     }
 
     private static final List<ExpressionsBasedModel.Integration<?>> INTEGRATIONS = new ArrayList<>();
+
     private static final String NEW_LINE = "\n";
     private static final String OBJ_FUNC_AS_CONSTR_KEY = UUID.randomUUID().toString();
     private static final String OBJECTIVE = "Generated/Aggregated Objective";
@@ -658,8 +731,12 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
     /**
      * Add an integration for a solver that will be used rather than the built-in solvers
      */
-    public static boolean addIntegration(final Integration<?> integration) {
-        return INTEGRATIONS.add(integration);
+    public static boolean addIntegration(final Optimisation.Integration<ExpressionsBasedModel, ?> integration) {
+        if (integration instanceof ExpressionsBasedModel.Integration<?>) {
+            return INTEGRATIONS.add((ExpressionsBasedModel.Integration<?>) integration);
+        } else {
+            return INTEGRATIONS.add(new IntegrationWrapper(integration));
+        }
     }
 
     public static boolean addPresolver(final Presolver presolver) {
@@ -674,6 +751,28 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         PRESOLVERS.clear();
     }
 
+    /**
+     * Don't you worry about this! It's for internal use.
+     */
+    public static boolean isNative(final ExpressionsBasedModel model) {
+
+        boolean mip = model.isAnyVariableInteger();
+
+        boolean qp = model.isAnyExpressionQuadratic();
+
+        if (mip) {
+            if (qp) {
+                return false;
+            } else {
+                return model.countVariables() > 50 || model.countExpressions() > 40;
+            }
+        } else if (qp) {
+            return model.countVariables() > 200 || model.countExpressions() > 200;
+        } else {
+            return model.countVariables() > 500 || model.countExpressions() > 400;
+        }
+    }
+
     /**
      * Apart from the "native" EBM file format, currently only supports the MPS file format, but with some of
      * the various extensions. In particular it is possible to parse QP models using QUADOBJ or QMATRIX file
@@ -720,7 +819,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
     private final Map<String, Expression> myExpressions = new HashMap<>();
     private final Set<IntIndex> myFixedVariables = new HashSet<>();
     private transient boolean myInfeasible = false;
-    private boolean myIntegrationSwitch = false;
+    private final EnumBitSet<IntegrationProperty> myIntegrationProperties = new EnumBitSet<>();
     private Optimisation.Result myKnownSolution = null;
     private BigDecimal myObjectiveConstant = BigMath.ZERO;
     private Optimisation.Sense myOptimisationSense = null;
@@ -843,9 +942,9 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
      * </ol>
      *
      * @param orderedSet The set members in correct order. Each of these variables must be binary.
-     * @param min The minimum number of binary varibales in the set that must be "ON" (Set this to 0 if there
-     *        is no minimum.)
-     * @param max The SOS type or maximum number of binary varibales in the set that may be "ON"
+     * @param min        The minimum number of binary varibales in the set that must be "ON" (Set this to 0 if
+     *                   there is no minimum.)
+     * @param max        The SOS type or maximum number of binary varibales in the set that may be "ON"
      */
     public void addSpecialOrderedSet(final Collection<Variable> orderedSet, final int min, final int max) {
 
@@ -1327,7 +1426,8 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
             if (tmpExpression.isObjective()) {
 
                 BigDecimal tmpContributionWeight = tmpExpression.getContributionWeight();
-                boolean tmpNotOne = tmpContributionWeight.compareTo(ONE) != 0; // To avoid multiplication by 1.0
+                boolean tmpNotOne = tmpContributionWeight.compareTo(ONE) != 0; // To avoid multiplication by
+                                                                               // 1.0
 
                 if (tmpExpression.isAnyLinearFactorNonZero()) {
                     for (IntIndex tmpKey : tmpExpression.getLinearKeySet()) {
@@ -1392,9 +1492,9 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
 
     /**
      * @param soft If true the integer variables are still identified as such, but the model is flagged as
-     *        non-integer (will not use the {@link IntegerSolver}, but presolve and validation may still
-     *        recognise the variables' integer property). If false the integer property of any/all variables
-     *        are removed.
+     *             non-integer (will not use the {@link IntegerSolver}, but presolve and validation may still
+     *             recognise the variables' integer property). If false the integer property of any/all
+     *             variables are removed.
      */
     public void relax(final boolean soft) {
         if (soft) {
@@ -1420,9 +1520,9 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
 
     /**
      * For test/validation during solver development.
-     * 
+     *
      * @param knownSolution The optimal solution
-     * @param handler What to do if validation fails
+     * @param handler       What to do if validation fails
      */
     public void setKnownSolution(final Optimisation.Result knownSolution, final BiConsumer<ExpressionsBasedModel, Access1D<BigDecimal>> handler) {
         Objects.requireNonNull(knownSolution);
@@ -1599,16 +1699,20 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
 
         Optimisation.Result result = prepared.solve(null);
 
-        for (int i = 0, limit = myVariables.size(); i < limit; i++) {
-            Variable tmpVariable = myVariables.get(i);
-            if (!tmpVariable.isFixed()) {
-                tmpVariable.setValue(options.solution.toBigDecimal(result.doubleValue(i)));
+        Optimisation.State retState = result.getState();
+
+        if (retState.isApproximate()) {
+            for (int i = 0, limit = myVariables.size(); i < limit; i++) {
+                Variable tmpVariable = myVariables.get(i);
+                if (!tmpVariable.isFixed()) {
+                    tmpVariable.setValue(options.solution.enforce(result.get(i)));
+                }
             }
         }
-
         Result retSolution = this.getVariableValues();
+
         double retValue = this.objective().evaluate(retSolution).doubleValue();
-        Optimisation.State retState = result.getState();
+
         List<KeyedPrimitive<EntryPair<ModelEntity<?>, ConstraintType>>> matchedMultipliers = result.getMatchedMultipliers();
 
         prepared.dispose();
@@ -1758,8 +1862,8 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         return true;
     }
 
-    boolean isIntegrationSwitch() {
-        return myIntegrationSwitch;
+    boolean isIntegrationSwitch(final IntegrationProperty property) {
+        return myIntegrationProperties.get(property);
     }
 
     boolean isReferenced(final Variable variable) {
@@ -1780,7 +1884,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
 
     void presolve() {
 
-        //  myExpressions.values().forEach(expr -> expr.reset());
+        // myExpressions.values().forEach(expr -> expr.reset());
 
         boolean needToRepeat = false;
 
@@ -1847,8 +1951,8 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         myInfeasible = true;
     }
 
-    void setIntegrationSwitch(final boolean value) {
-        myIntegrationSwitch = value;
+    void setIntegrationSwitch(final IntegrationProperty property, final boolean value) {
+        myIntegrationProperties.set(property, value);
     }
 
     void setOptimisationSense(final Optimisation.Sense optimisationSense) {
