@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -306,6 +306,10 @@ public interface Optimisation {
             super();
         }
 
+        /**
+         * Set the {@link #time_abort} to the given duration. A duration may be constructed this way:
+         * <code>CalendarDateUnit.HOUR.newDuration(0.5)</code>.
+         */
         public Options abort(final CalendarDateDuration duration) {
             ProgrammingError.throwIfNull(duration);
             time_abort = duration.toDurationInMillis();
@@ -340,8 +344,9 @@ public interface Optimisation {
             ProgrammingError.throwIfNull(type);
             if (myConfigurator != null && type.isInstance(myConfigurator)) {
                 return Optional.of((T) myConfigurator);
+            } else {
+                return Optional.empty();
             }
-            return Optional.empty();
         }
 
         public IntegerStrategy integer() {
@@ -390,6 +395,10 @@ public interface Optimisation {
             myConfigurator = configurator;
         }
 
+        /**
+         * Set the {@link #time_suffice} to the given duration. A duration may be constructed this way:
+         * <code>CalendarDateUnit.HOUR.newDuration(0.5)</code>.
+         */
         public Options suffice(final CalendarDateDuration duration) {
             ProgrammingError.throwIfNull(duration);
             time_suffice = duration.toDurationInMillis();
