@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -126,7 +126,7 @@ public abstract class Presolvers {
                                 min = null;
                             }
                         }
-                    } else {
+                    } else if (coefficient.signum() > 0) {
                         if (max != null) {
                             if (variable.isUpperLimitSet()) {
                                 max = max.add(coefficient.multiply(variable.getUpperLimit()));
@@ -195,15 +195,15 @@ public abstract class Presolvers {
                 if (variable.isObjective()) {
                     int weightSignum = variable.getContributionWeight().signum();
 
-                    if ((model.getOptimisationSense() == Optimisation.Sense.MAX && weightSignum == -1)
-                            || ((model.getOptimisationSense() != Optimisation.Sense.MAX) && weightSignum == 1)) {
+                    Optimisation.Sense sense = model.getOptimisationSense();
+
+                    if (sense == Optimisation.Sense.MAX && weightSignum == -1 || sense == Optimisation.Sense.MIN && weightSignum == 1) {
                         if (variable.isLowerLimitSet()) {
                             variable.setFixed(variable.getLowerLimit());
                         } else {
                             variable.setUnbounded(true);
                         }
-                    } else if ((model.getOptimisationSense() == Optimisation.Sense.MAX && weightSignum == 1)
-                            || ((model.getOptimisationSense() != Optimisation.Sense.MAX) && weightSignum == -1)) {
+                    } else if (sense == Optimisation.Sense.MAX && weightSignum == 1 || sense == Optimisation.Sense.MIN && weightSignum == -1) {
                         if (variable.isUpperLimitSet()) {
                             variable.setFixed(variable.getUpperLimit());
                         } else {
@@ -233,14 +233,14 @@ public abstract class Presolvers {
                 final NumberContext precision) {
 
             switch (remaining.size()) {
-            case 0:
-                return Presolvers.doCase0(expression, remaining, lower, upper, precision);
-            case 1:
-                return Presolvers.doCase1(expression, remaining, lower, upper, precision);
-            case 2:
-                return Presolvers.doCase2(expression, remaining, lower, upper, precision);
-            default: // 3 or more
-                return Presolvers.doCaseN(expression, remaining, lower, upper, precision);
+                case 0:
+                    return Presolvers.doCase0(expression, remaining, lower, upper, precision);
+                case 1:
+                    return Presolvers.doCase1(expression, remaining, lower, upper, precision);
+                case 2:
+                    return Presolvers.doCase2(expression, remaining, lower, upper, precision);
+                default: // 3 or more
+                    return Presolvers.doCaseN(expression, remaining, lower, upper, precision);
             }
         }
     };
@@ -715,15 +715,19 @@ public abstract class Presolvers {
     }
 
     static BigDecimal findCommonLevel(final BigDecimal a, final BigDecimal b) {
+
         if (a.compareTo(b) == 0) {
             return a;
         }
+
         BigDecimal levelledA = LEVEL.enforce(a);
         BigDecimal levelledB = LEVEL.enforce(b);
+
         if (levelledA.compareTo(levelledB) == 0) {
             return DIVIDE.invoke(a.add(a), TWO);
+        } else {
+            return null;
         }
-        return null;
     }
 
 }
