@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -104,10 +104,11 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
 
             if (excluded.length > 0) {
 
-                MatrixStore<Double> slack = this.getSlackI(excluded);
+                MatrixStore<Double> allIneqSlack = this.getSlackI();
 
                 if (this.isLogDebug()) {
 
+                    MatrixStore<Double> slack = allIneqSlack.rows(excluded);
                     MatrixStore<Double> change = this.getMatrixAI(excluded).get().multiply(iterX);
 
                     if (slack.count() != change.count()) {
@@ -122,15 +123,23 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
                     this.log("Looking for the largest possible step length (smallest positive scalar) among these: {}).", steps.toRawCopy1D());
                 }
 
-                for (int i = 0; i < excluded.length; i++) {
+                int nbIneqs = this.countInequalityConstraints();
+                int testThisLast = Math.min(this.getLastIncluded(), this.getLastExcluded());
+                int base = Math.max(0, testThisLast + 1);
+                for (int ii = 0; ii < nbIneqs; ii++) {
+                    int i = (base + ii) % nbIneqs; // Wrap around to handle cyclically
 
-                    SparseArray<Double> excludedInequalityRow = this.getMatrixAI(excluded[i]);
+                    if (myActivator.isIncluded(i)) {
+                        continue; // Skip currently included rows
+                    }
 
-                    double currentSlack = slack.doubleValue(i);
+                    SparseArray<Double> excludedInequalityRow = this.getMatrixAI(i);
+
+                    double currentSlack = allIneqSlack.doubleValue(i);
                     double slackChange = excludedInequalityRow.dot(iterX);
-                    double fraction = Math.abs(currentSlack) / slackChange;
+                    double fraction = Math.max(currentSlack, ZERO) / slackChange;
                     // If the current slack is negative something has already gone wrong.
-                    // Taking the abs value is to handle small negative values due to rounding errors
+                    // Taking the max value is to handle small negative values due to rounding errors
                     if (slackChange > ZERO && !SLACK.isZero(slackChange) && SLACK.isSmall(slackChange, currentSlack)) {
                         fraction = ZERO;
                     } else if (slackChange <= ZERO || SLACK.isZero(slackChange)) {
@@ -139,9 +148,15 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
 
                     if (ZERO <= fraction && fraction < stepLength) {
                         stepLength = fraction;
-                        this.setConstraintToInclude(excluded[i]);
+                        this.setConstraintToInclude(i);
                         if (this.isLogDebug()) {
-                            this.log(1, "Best so far: {} @ {} ({}) ––– {} / {}.", stepLength, i, excluded[i], currentSlack, slackChange);
+                            this.log(1, "Best so far: {} @ {} ––– {} / {}.", stepLength, i, currentSlack, slackChange);
+                        }
+                        if (stepLength == ZERO) {
+                            break;
+                        }
+                        if (stepLength == ZERO) {
+                            break;
                         }
                     }
                 }
@@ -160,7 +175,7 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
             } else if (this.isLogProgress()) {
                 this.log("Do nothing because step length {} and size {} but add constraint {}", stepLength, normStepX, this.getConstraintToInclude());
             }
-            //  this.setConstraintToInclude(-1);
+            // this.setConstraintToInclude(-1);
 
         } else {
             // Zero solution
@@ -188,10 +203,10 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
         int toExclude = this.suggestConstraintToExclude();
 
         if (toExclude < 0) {
-            if (myShrinkSwitch) {
-                toExclude = this.suggestUsingLagrangeMagnitude();
-            } else {
+            if (myShrinkSwitch && this.getLastIncluded() >= 0) {
                 toExclude = this.suggestUsingVectorProjection();
+            } else {
+                toExclude = this.suggestUsingLagrangeMagnitude();
             }
             myShrinkSwitch = !myShrinkSwitch;
         }
@@ -236,7 +251,8 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
 
         int toExclude = lastIncluded;
         double maxWeight = ZERO;
-        // The weight is the absolute value of the cosine of the angle between the vectors (the constraint rows).
+        // The weight is the absolute value of the cosine of the angle between the vectors (the constraint
+        // rows).
         for (int i = 0; i < incl.length; i++) {
             aggregator.reset();
             SparseArray<Double> inclRow = this.getMatrixAI(incl[i]);
@@ -278,10 +294,6 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
         return myExcluded;
     }
 
-    protected int getExcluded(final int indexAmongExcluded) {
-        return this.getExcluded()[indexAmongExcluded];
-    }
-
     protected final int[] getIncluded() {
         if (myIncluded == null) {
             myIncluded = myActivator.getIncluded();
@@ -289,10 +301,6 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
         return myIncluded;
     }
 
-    protected final int getIncluded(final int indexAmongIncluded) {
-        return this.getIncluded()[indexAmongIncluded];
-    }
-
     protected final int getLastExcluded() {
         return myActivator.getLastExcluded();
     }
@@ -481,31 +489,40 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
 
         boolean retVal = true;
 
+        MatrixStore<Double> mtrxBE = this.getMatrixBE();
+        MatrixStore<Double> mtrxBI = this.getMatrixBI();
+
         PhysicalStore<Double> slackE = this.getSlackE();
         PhysicalStore<Double> slackI = this.getSlackI();
 
-        if (retVal && slackE.count() > 0) {
+        int nbE = slackE.size();
+        if (retVal && nbE > 0) {
             if (this.isLogDebug()) {
                 this.log("E-slack: {}", slackE.asList());
             }
-            double largestE = slackE.aggregateAll(Aggregator.LARGEST);
-            if (!FEASIBILITY.isZero(largestE)) {
-                retVal = false;
-                if (this.isLogDebug()) {
-                    this.log("Nonzero E-slack! {}", largestE);
+            for (int i = 0; i < nbE; i++) {
+                double slack = slackE.doubleValue(i);
+                if (!FEASIBILITY.isSmall(mtrxBE.doubleValue(i), slack)) {
+                    retVal = false;
+                    if (this.isLogDebug()) {
+                        this.log("Nonzero E-slack! {}", slack);
+                    }
                 }
             }
         }
 
-        if (retVal && slackI.count() > 0) {
+        int nbI = slackI.size();
+        if (retVal && nbI > 0) {
             if (this.isLogDebug()) {
                 this.log("I-slack: {}", slackI.asList());
             }
-            double minimumI = slackI.aggregateAll(Aggregator.MINIMUM);
-            if (minimumI < ZERO && !FEASIBILITY.isZero(minimumI)) {
-                retVal = false;
-                if (this.isLogDebug()) {
-                    this.log("Negative I-slack! {}", minimumI);
+            for (int i = 0; i < nbI; i++) {
+                double slack = slackI.doubleValue(i);
+                if (slack < ZERO && !FEASIBILITY.isSmall(mtrxBI.doubleValue(i), slack)) {
+                    retVal = false;
+                    if (this.isLogDebug()) {
+                        this.log("Negative I-slack! {}", slack);
+                    }
                 }
             }
         }
@@ -567,12 +584,12 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
     @Override
     MatrixStore<Double> getIterationC() {
 
-        //          MatrixStore<Double> tmpQ = this.getQ();
-        //          MatrixStore<Double> tmpC = this.getC();
+        // MatrixStore<Double> tmpQ = this.getQ();
+        // MatrixStore<Double> tmpC = this.getC();
         //
-        //          PhysicalStore<Double> tmpX = this.getX();
+        // PhysicalStore<Double> tmpX = this.getX();
         //
-        //        return tmpC.subtract(tmpQ.multiply(tmpX));
+        // return tmpC.subtract(tmpQ.multiply(tmpX));
 
         return this.getMatrixC();
     }
@@ -673,6 +690,8 @@ abstract class ActiveSetSolver extends ConstrainedSolver {
                 }
             }
         }
+
+        myActivator.resetHistory();
     }
 
     void setConstraintToInclude(final int constraintToInclude) {
