@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -32,6 +32,8 @@ import java.util.function.Function;
 import java.util.stream.Collectors;
 
 import org.ojalgo.array.ArrayR064;
+import org.ojalgo.array.ArrayR256;
+import org.ojalgo.array.BasicArray;
 import org.ojalgo.array.SparseArray.NonzeroView;
 import org.ojalgo.function.constant.BigMath;
 import org.ojalgo.matrix.decomposition.Cholesky;
@@ -299,8 +301,13 @@ public abstract class ConvexSolver extends GenericSolver {
 
             if (options.convex().isExtendedPrecision()) {
 
-                ConvexData<Quadruple> data = this.getConvexData(GenericStore.R128);
-                return new IterativeRefinementSolver(options, data);
+                if (options.experimental) {
+                    ConvexData<Double> data = this.getConvexData(R064Store.FACTORY);
+                    return new IterativeRefinementSolverDouble(options, data);
+                } else {
+                    ConvexData<Quadruple> data = this.getConvexData(GenericStore.R128);
+                    return new IterativeRefinementSolver(options, data);
+                }
 
             } else {
 
@@ -356,12 +363,30 @@ public abstract class ConvexSolver extends GenericSolver {
 
     public static final class Configuration {
 
+        private boolean myCombinedScaleFactor = true;
         private boolean myExtendedPrecision = false;
         private NumberContext myIterative = NumberContext.of(10, 14).withMode(RoundingMode.HALF_DOWN);
         private double mySmallDiagonal = RELATIVELY_SMALL + MACHINE_EPSILON;
         private Function<Structure2D, MatrixDecomposition.Solver<Double>> mySolverGeneral = LU.R064::make;
         private Function<Structure2D, MatrixDecomposition.Solver<Double>> mySolverSPD = Cholesky.R064::make;
 
+        /**
+         * Only relevant with extended precision. With the extended precision solver the primal and dual
+         * variables are scaled (shift and zoom) to iteratively generate subproblems. In theory there are
+         * different scaling factors for the primal and dual variables, but forcing them to be the same
+         * enables simplifications resulting in significant performance gains.
+         * <p>
+         * The default is to use the same scaling factor for both primal and dual variables. By setting this
+         * to false, you switch to a slower more complex, but theoretically more accurate and flexible
+         * algorithm.
+         *
+         * @see #extendedPrecision(boolean)
+         */
+        public Configuration combinedScaleFactor(final boolean combinedScaleFactor) {
+            myCombinedScaleFactor = combinedScaleFactor;
+            return this;
+        }
+
         /**
          * With extended precision the usual solver is wrapped by a master algorithm, implemented in
          * {@link Quadruple} precision, that iteratively refines (zoom and shift) the problem to be solved by
@@ -371,12 +396,19 @@ public abstract class ConvexSolver extends GenericSolver {
          * bounds (modelled as inequality constraints).
          * <p>
          * This is an experimental feature!
+         * <p>
+         * Setting this to true you should most likely also set the {@link Optimisation.Options#solution} to
+         * something matching that allows for higher precision.
          */
         public Configuration extendedPrecision(final boolean extendedPrecision) {
             myExtendedPrecision = extendedPrecision;
             return this;
         }
 
+        public boolean isCombinedScaleFactor() {
+            return myCombinedScaleFactor;
+        }
+
         public boolean isExtendedPrecision() {
             return myExtendedPrecision;
         }
@@ -488,12 +520,18 @@ public abstract class ConvexSolver extends GenericSolver {
             int nbFreeVars = freeVariables.size();
             int nbModelVars = model.countVariables();
 
-            ArrayR064 modelSolution = ArrayR064.make(nbModelVars);
-
-            for (int i = 0; i < nbFreeVars; i++) {
-                modelSolution.set(model.indexOf(freeVariables.get(i)), solverState.doubleValue(i));
+            BasicArray<?> modelSolution;
+            if (model.options.convex().isExtendedPrecision()) {
+                modelSolution = ArrayR256.make(nbModelVars);
+                for (int i = 0; i < nbFreeVars; i++) {
+                    modelSolution.set(model.indexOf(freeVariables.get(i)), solverState.get(i));
+                }
+            } else {
+                modelSolution = ArrayR064.make(nbModelVars);
+                for (int i = 0; i < nbFreeVars; i++) {
+                    modelSolution.set(model.indexOf(freeVariables.get(i)), solverState.doubleValue(i));
+                }
             }
-
             for (IntIndex fixed : fixedVariables) {
                 modelSolution.set(fixed.index, model.getVariable(fixed.index).getValue());
             }
