@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,11 +21,12 @@
  */
 package org.ojalgo.optimisation.convex;
 
-import static org.ojalgo.function.constant.PrimitiveMath.*;
+import static org.ojalgo.function.constant.PrimitiveMath.ADD;
+import static org.ojalgo.function.constant.PrimitiveMath.ZERO;
 
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
-import org.ojalgo.matrix.store.Primitive64Store;
+import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.optimisation.Optimisation;
 
 /**
@@ -40,11 +41,11 @@ import org.ojalgo.optimisation.Optimisation;
 final class QPESolver extends ConstrainedSolver {
 
     private boolean myFeasible = false;
-    private final Primitive64Store myIterationX;
+    private final R064Store myIterationX;
 
-    QPESolver(final ConvexData<Double> convexSolverBuilder, final Optimisation.Options optimisationOptions) {
+    QPESolver(final ConvexData<Double> convexData, final Optimisation.Options optimisationOptions) {
 
-        super(convexSolverBuilder, optimisationOptions);
+        super(convexData, optimisationOptions);
 
         myIterationX = MATRIX_FACTORY.make(this.countVariables(), 1L);
     }
@@ -84,8 +85,8 @@ final class QPESolver extends ConstrainedSolver {
 
         boolean solved = false;
 
-        Primitive64Store iterX = myIterationX;
-        Primitive64Store iterL = this.getSolutionL();
+        R064Store iterX = myIterationX;
+        R064Store iterL = this.getSolutionL();
 
         if (iterA.countRows() < iterA.countColumns() && (solved = this.isSolvableQ())) {
             // Q is SPD
@@ -109,7 +110,7 @@ final class QPESolver extends ConstrainedSolver {
         if (!solved) {
             // The above failed, try solving the full KKT system instaed
 
-            Primitive64Store tmpXL = MATRIX_FACTORY.make(this.countVariables() + this.countIterationConstraints(), 1L);
+            R064Store tmpXL = MATRIX_FACTORY.make(this.countVariables() + this.countIterationConstraints(), 1L);
 
             if (solved = this.solveFullKKT(tmpXL)) {
                 iterX.fillMatching(tmpXL.limits(this.countVariables(), 1));
