@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,11 +21,12 @@
  */
 package org.ojalgo.optimisation.integer;
 
-import static org.ojalgo.function.constant.PrimitiveMath.ZERO;
+import static org.ojalgo.function.constant.PrimitiveMath.*;
 
 import java.math.BigDecimal;
 import java.util.Arrays;
 import java.util.Comparator;
+import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicBoolean;
@@ -43,6 +44,7 @@ import org.ojalgo.optimisation.ExpressionsBasedModel;
 import org.ojalgo.optimisation.GenericSolver;
 import org.ojalgo.optimisation.Optimisation;
 import org.ojalgo.structure.Access1D;
+import org.ojalgo.structure.Primitive1D;
 import org.ojalgo.type.CalendarDateDuration;
 import org.ojalgo.type.TypeUtils;
 
@@ -204,13 +206,6 @@ public final class IntegerSolver extends GenericSolver {
 
         this.resetIterationsCount();
 
-        if (strategy.cutting) {
-            ExpressionsBasedModel cutModel = myIntegerModel.snapshot();
-            NodeSolver cutSolver = cutModel.prepare(NodeSolver::new);
-            Result cutResult = cutSolver.solve();
-            cutSolver.generateCuts(strategy, myIntegerModel);
-        }
-
         NodeKey rootNode = new NodeKey(myIntegerModel);
         ExpressionsBasedModel rootModel = myIntegerModel.snapshot();
         rootNode.setNodeState(rootModel, strategy);
@@ -222,11 +217,16 @@ public final class IntegerSolver extends GenericSolver {
 
         Map<Comparator<NodeKey>, MultiviewSet<NodeKey>.PrioritisedView> views = new ConcurrentHashMap<>();
 
-        ProcessingService.INSTANCE.process(strategy.getWorkerPriorities(), workerStrategy -> {
+        List<Comparator<NodeKey>> workerPriorities = strategy.getWorkerPriorities();
+        for (Comparator<NodeKey> workerPriority : workerPriorities) {
+            views.computeIfAbsent(workerPriority, myDeferredNodes::newView);
+        }
+
+        ProcessingService.INSTANCE.process(workerPriorities, workerPriority -> {
 
             boolean workerNormalExit = solverNormalExit.get();
 
-            MultiviewSet<NodeKey>.PrioritisedView view = views.computeIfAbsent(workerStrategy, myDeferredNodes::newView);
+            MultiviewSet<NodeKey>.PrioritisedView view = views.computeIfAbsent(workerPriority, myDeferredNodes::newView);
 
             RingLogger nodePrinter = this.newPrinter();
 
@@ -297,7 +297,7 @@ public final class IntegerSolver extends GenericSolver {
 
     protected double evaluateFunction(final Access1D<?> solution) {
         if (myFunction != null && solution != null && myFunction.arity() == solution.count()) {
-            return myFunction.invoke(Access1D.asPrimitive1D(solution)).doubleValue();
+            return myFunction.invoke(Primitive1D.wrap(solution)).doubleValue();
         }
         return Double.NaN;
     }
@@ -379,12 +379,13 @@ public final class IntegerSolver extends GenericSolver {
 
         strategy.markInteger(key, result);
 
-        BigDecimal bestIntegerSolutionValue = BigDecimal.valueOf(myBestResultSoFar.getValue());
+        double bestIntegerSolutionValue = myBestResultSoFar.getValue();
+        double nudge = strategy.getGapTolerance().error(bestIntegerSolutionValue);
 
         if (myIntegerModel.getOptimisationSense() != Optimisation.Sense.MAX) {
-            myIntegerModel.limitObjective(null, bestIntegerSolutionValue);
+            myIntegerModel.limitObjective(null, BigDecimal.valueOf(bestIntegerSolutionValue - nudge));
         } else {
-            myIntegerModel.limitObjective(bestIntegerSolutionValue, null);
+            myIntegerModel.limitObjective(BigDecimal.valueOf(bestIntegerSolutionValue + nudge), null);
         }
     }
 
@@ -455,7 +456,8 @@ public final class IntegerSolver extends GenericSolver {
                 return myNodeStatistics.failed();
             }
             // return true;
-            strategy.markInfeasible(nodeKey, myBestResultSoFar != null);
+            double incumbentValue = myBestResultSoFar != null ? myBestResultSoFar.getValue() : Double.NaN;
+            strategy.markInfeasible(nodeKey, myBestResultSoFar != null, incumbentValue);
             return myNodeStatistics.infeasible();
         }
 
@@ -472,19 +474,42 @@ public final class IntegerSolver extends GenericSolver {
 
             IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
 
-            // return false;
-            return myNodeStatistics.failed();
+            /*
+             * Used to mark this as a failure since it happened because of problems with the linear solver,
+             * but now could be just that the updated solver instance did not recognise that it had become
+             * infeasible due to integer rounding on the constraints. (The LP solver simply doesn't know it's
+             * actually solving a MIP.) Something model pre-solving would probably have caught. Marking as
+             * failure will stop the overall solver process, which is not what we want (if this is just an
+             * infeasible node). Therefore we'll mark it as infeasible.
+             */
+            return myNodeStatistics.infeasible();
         }
 
+        double nodeValue = this.evaluateFunction(nodeResult);
+        // Update pseudo-costs based on this child outcome (relative to its parent)
+        strategy.onNodeSolved(nodeKey, nodeResult, nodeValue, myMinimisation);
+
         int branchIntegerIndex = this.identifyNonIntegerVariable(nodeResult, nodeKey, strategy);
-        double tmpSolutionValue = this.evaluateFunction(nodeResult);
 
         if (branchIntegerIndex == -1) {
             if (this.isLogDebug()) {
                 nodePrinter.println("Integer solution! Store it among the others, and stop this branch!");
             }
 
-            Optimisation.Result tmpIntegerSolutionResult = new Optimisation.Result(Optimisation.State.FEASIBLE, tmpSolutionValue, nodeResult);
+            // Extra guard: validate candidate integer solution against the original model
+            // This catches rare cases where numerical issues produce an apparently better but infeasible point.
+            if (!myIntegerModel.validate(nodeResult)) {
+                if (this.isLogDebug()) {
+                    nodePrinter.println("Candidate integer solution is infeasible for the original model. Discarding.");
+                    IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
+                }
+                double incumbentValue = myBestResultSoFar != null ? myBestResultSoFar.getValue() : Double.NaN;
+                strategy.markInfeasible(nodeKey, myBestResultSoFar != null, incumbentValue);
+                nodeSolver.dispose();
+                return myNodeStatistics.infeasible();
+            }
+
+            Optimisation.Result tmpIntegerSolutionResult = new Optimisation.Result(Optimisation.State.FEASIBLE, nodeValue, nodeResult);
 
             this.markInteger(nodeKey, tmpIntegerSolutionResult, strategy);
 
@@ -501,12 +526,12 @@ public final class IntegerSolver extends GenericSolver {
 
         }
         if (this.isLogDebug()) {
-            nodePrinter.println("Not an Integer Solution: " + tmpSolutionValue);
+            nodePrinter.println("Not an Integer Solution: " + nodeValue);
         }
 
         double variableValue = nodeResult.doubleValue(strategy.getIndex(branchIntegerIndex));
 
-        if (!strategy.isGoodEnough(myBestResultSoFar, tmpSolutionValue)) {
+        if (!strategy.isGoodEnough(myBestResultSoFar, nodeValue)) {
             if (this.isLogDebug()) {
                 nodePrinter.println("Can't find better integer solutions - stop this branch!");
                 IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
@@ -522,77 +547,64 @@ public final class IntegerSolver extends GenericSolver {
             IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
         }
 
-        if (strategy.cutting && nodeKey.sequence % 100L == 0L) {
-            double displacement = nodeKey.getMinimumDisplacement(branchIntegerIndex, variableValue);
-            if (strategy.isCutRatherThanBranch(displacement, myBestResultSoFar != null)) {
-                if (nodeSolver.generateCuts(strategy, nodeKey)) {
-                    return this.compute(nodeKey, nodeSolver, nodePrinter, strategy);
-                }
-                strategy.cutting = false;
+        if (strategy.isCutRatherThanBranch(nodeKey, branchIntegerIndex, variableValue, nodeValue, myBestResultSoFar)) {
+            if (nodeSolver.generateCuts(strategy, nodeKey)) {
+                strategy.onCutSuccess(nodeKey);
+                return this.compute(nodeKey, nodeSolver, nodePrinter, strategy);
+            } else {
+                strategy.onCutFailure();
             }
         }
 
-        NodeKey lowerBranch = nodeKey.createLowerBranch(branchIntegerIndex, variableValue, tmpSolutionValue);
-        NodeKey upperBranch = nodeKey.createUpperBranch(branchIntegerIndex, variableValue, tmpSolutionValue);
+        NodeKey lowerBranch = nodeKey.createLowerBranch(branchIntegerIndex, variableValue, nodeValue);
+        NodeKey upperBranch = nodeKey.createUpperBranch(branchIntegerIndex, variableValue, nodeValue);
 
-        if (!strategy.isDirect(lowerBranch, myBestResultSoFar != null)) {
-            myDeferredNodes.add(lowerBranch);
-            lowerBranch = null;
-        }
-        if (lowerBranch != null || !strategy.isDirect(upperBranch, myBestResultSoFar != null)) {
+        if (lowerBranch.score(strategy, myBestResultSoFar != null) > upperBranch.score(strategy, myBestResultSoFar != null)) {
             myDeferredNodes.add(upperBranch);
-            upperBranch = null;
+            boolean ok = this.compute(lowerBranch, nodeSolver, nodePrinter, strategy);
+            lowerBranch.dispose();
+            return ok;
+        } else {
+            myDeferredNodes.add(lowerBranch);
+            boolean ok = this.compute(upperBranch, nodeSolver, nodePrinter, strategy);
+            upperBranch.dispose();
+            return ok;
         }
-
-        if (lowerBranch != null && upperBranch != null) {
-            // Node model data is reused when continuing down in the same thread.
-            // Can't do 2 branches in the same thread, using the same parent model.
-            throw new IllegalStateException();
-        }
-
-        boolean retVal = true;
-        if (lowerBranch != null) {
-            retVal = retVal && this.compute(lowerBranch, nodeSolver, nodePrinter, strategy);
-        }
-        if (upperBranch != null) {
-            retVal = retVal && this.compute(upperBranch, nodeSolver, nodePrinter, strategy);
-        }
-        return retVal;
     }
 
     /**
      * Should return the index of the (best) integer variable to branch on. Returning a negative index means
      * an integer solution has been found (no further branching). Does NOT return a global variable index -
-     * it's the index among the ineteger variable.
+     * it's the index among the integer variable.
      */
     int identifyNonIntegerVariable(final Optimisation.Result nodeResult, final NodeKey nodeKey, final ModelStrategy strategy) {
 
         int retVal = -1;
 
-        double displacement;
-        double comparableDisplacement = ZERO;
+        double comparableScore = ZERO;
         double maxComparable = ZERO;
 
         for (int i = 0, limit = strategy.countIntegerVariables(); i < limit; i++) {
 
             int globalIndex = strategy.getIndex(i);
 
-            displacement = nodeKey.getMinimumDisplacement(i, nodeResult.doubleValue(globalIndex));
-            // [0, 0.5]
+            double value = nodeResult.doubleValue(globalIndex);
+
+            double distanceDown = value - Math.floor(value); // in [0,1)
+            double distanceUp = ONE - distanceDown; // in [0,1)
+            double displacement = Math.min(distanceDown, distanceUp); // [0,0.5]
 
             if (!strategy.getIntegralityTolerance().isZero(displacement)) {
                 // This variable not integer
+                comparableScore = strategy.scoreBranch(i, distanceDown, distanceUp, myBestResultSoFar != null);
 
-                comparableDisplacement = strategy.toComparable(i, displacement, myBestResultSoFar != null);
-
-                if (comparableDisplacement > maxComparable) {
+                if (comparableScore > maxComparable) {
                     retVal = i;
-                    maxComparable = comparableDisplacement;
+                    maxComparable = comparableScore;
                 }
             }
         }
 
         return retVal;
     }
-
 }
