@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -37,6 +37,10 @@ import org.ojalgo.type.context.NumberContext;
 
 public interface IntegerStrategy {
 
+    /**
+     * Apart from being able to configure various standard properties, you can also provide your own
+     * {@link ModelStrategy} factory.
+     */
     final class ConfigurableStrategy implements IntegerStrategy {
 
         private final BiFunction<ExpressionsBasedModel, IntegerStrategy, ModelStrategy> myFactory;
@@ -78,27 +82,42 @@ public interface IntegerStrategy {
             return new ConfigurableStrategy(myParallelism, totalDefinitions, myIntegralityTolerance, myGapTolerance, myFactory, myGMICutConfiguration);
         }
 
+        @Override
+        public int countUniqueStrategies() {
+            return myPriorityDefinitions.length;
+        }
+
+        @Override
         public NumberContext getGapTolerance() {
             return myGapTolerance;
         }
 
+        @Override
         public GMICutConfiguration getGMICutConfiguration() {
             return myGMICutConfiguration;
         }
 
+        @Override
         public NumberContext getIntegralityTolerance() {
             return myIntegralityTolerance;
         }
 
+        @Override
         public List<Comparator<NodeKey>> getWorkerPriorities() {
-            int parallelism = myParallelism.getAsInt();
-            List<Comparator<NodeKey>> retVal = new ArrayList<>(parallelism);
-            for (int i = 0; i < parallelism; i++) {
-                retVal.add(myPriorityDefinitions[i % myPriorityDefinitions.length]);
+
+            int nbWorkers = myParallelism.getAsInt();
+            int nbDefinitions = myPriorityDefinitions.length;
+
+            List<Comparator<NodeKey>> retVal = new ArrayList<>(nbWorkers);
+
+            for (int w = 0; w < nbWorkers; w++) {
+                retVal.add(myPriorityDefinitions[w % nbDefinitions]);
             }
+
             return retVal;
         }
 
+        @Override
         public ModelStrategy newModelStrategy(final ExpressionsBasedModel model) {
             return myFactory.apply(model, this);
         }
@@ -114,6 +133,9 @@ public interface IntegerStrategy {
             return new ConfigurableStrategy(myParallelism, myPriorityDefinitions, myIntegralityTolerance, myGapTolerance, myFactory, newConfiguration);
         }
 
+        /**
+         * Create a sub-class of {@link ModelStrategy} and provide a factory method for it here.
+         */
         public ConfigurableStrategy withModelStrategyFactory(final BiFunction<ExpressionsBasedModel, IntegerStrategy, ModelStrategy> newFactory) {
             return new ConfigurableStrategy(myParallelism, myPriorityDefinitions, myIntegralityTolerance, myGapTolerance, newFactory, myGMICutConfiguration);
         }
@@ -182,15 +204,18 @@ public interface IntegerStrategy {
 
     static ConfigurableStrategy newConfigurable() {
 
-        Comparator<NodeKey>[] definitions = (Comparator<NodeKey>[]) new Comparator<?>[] { NodeKey.EARLIEST_SEQUENCE, NodeKey.LARGEST_DISPLACEMENT,
-                NodeKey.SMALLEST_DISPLACEMENT, NodeKey.LATEST_SEQUENCE };
+        Comparator<NodeKey>[] definitions = (Comparator<NodeKey>[]) new Comparator<?>[] { NodeKey.MIN_OBJECTIVE, NodeKey.DEPTH_FIRST_SEARCH,
+                NodeKey.BREADTH_FIRST_SEARCH, NodeKey.LARGE_DISPLACEMENT, NodeKey.SMALL_DISPLACEMENT };
 
         NumberContext integrality = NumberContext.of(12, 8);
         NumberContext gap = NumberContext.of(7, 8);
 
-        return new ConfigurableStrategy(Parallelism.CORES.require(4), definitions, integrality, gap, DefaultStrategy::new, new GMICutConfiguration());
+        return new ConfigurableStrategy(Parallelism.CORES.require(definitions.length), definitions, integrality, gap, DefaultStrategy::new,
+                new GMICutConfiguration());
     }
 
+    int countUniqueStrategies();
+
     /**
      * The MIP gap is the difference between the best integer solution found so far and a node's relaxed
      * non-integer solution. The relative MIP gap is that difference divided by the optimal value
