@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -84,7 +84,7 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
         }
 
         @Override
-        public final LinearFunction<Double> getObjective() {
+        public LinearFunction<Double> getObjective() {
             LinearFunction<Double> retVal = this.getObjective(LinearFunction.class);
             if (retVal == null) {
                 retVal = LinearFunction.factory(this.getFactory()).make(this.countVariables());
@@ -111,7 +111,7 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
             return this;
         }
 
-        public final LinearSolver.Builder lower(final double bound) {
+        public LinearSolver.Builder lower(final double bound) {
             double[] lowerBounds = this.getLowerBounds(ZERO).data;
             Arrays.fill(lowerBounds, bound);
             return this;
@@ -123,12 +123,12 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
             return this;
         }
 
-        public final LinearSolver.Builder objective(final int index, final double value) {
+        public LinearSolver.Builder objective(final int index, final double value) {
             this.getObjective().linear().set(index, value);
             return this;
         }
 
-        public final LinearSolver.Builder objective(final MatrixStore<Double> mtrxC) {
+        public LinearSolver.Builder objective(final MatrixStore<Double> mtrxC) {
             this.setObjective(LinearSolver.toObjectiveFunction(mtrxC));
             return this;
         }
@@ -229,7 +229,7 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
             return this;
         }
 
-        public final LinearSolver.Builder upper(final double bound) {
+        public LinearSolver.Builder upper(final double bound) {
             double[] upperBounds = this.getUpperBounds(POSITIVE_INFINITY).data;
             Arrays.fill(upperBounds, bound);
             return this;
@@ -328,15 +328,15 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
             return new SimplexTableauSolver(tableau, options);
         }
 
-        protected final double[] getLowerBounds() {
+        protected double[] getLowerBounds() {
             return super.getLowerBounds(ZERO).data;
         }
 
-        protected final double[] getUpperBounds() {
+        protected double[] getUpperBounds() {
             return super.getUpperBounds(POSITIVE_INFINITY).data;
         }
 
-        SimplexStore newSimplexStore(final Function<LinearStructure, SimplexStore> storeFactory, final int... basis) {
+        <S extends SimplexStore> S newSimplexStore(final Function<LinearStructure, S> storeFactory, final int... basis) {
 
             MatrixStore<Double> builderC = this.getObjective().getLinearFactors(false);
             MatrixStore<Double> builderAE = this.getAE();
@@ -357,7 +357,7 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
 
             LinearStructure structure = new LinearStructure(false, nbUpConstr + nbLoConstr, nbEqConstr, nbProbVars, 0, 0, nbSlckVars);
 
-            SimplexStore simplex = storeFactory.apply(structure);
+            S simplex = storeFactory.apply(structure);
 
             double[] lowerBounds = simplex.getLowerBounds();
             double[] upperBounds = simplex.getUpperBounds();
@@ -493,6 +493,34 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
 
     public static final class Configuration {
 
+        private Boolean myDualOrPrimal = null;
+
+        /**
+         * Force use of the newer (mainly) dual simplex implementation. If you don't specify which to use,
+         * there is internal logic that switches implementation based on problem size.
+         */
+        public Configuration dual() {
+            myDualOrPrimal = Boolean.TRUE;
+            return this;
+        }
+
+        /**
+         * Force use of ojAlgo's original (classic 2-phase primal) simplex implementation.
+         *
+         * @see #dual()
+         */
+        public Configuration primal() {
+            myDualOrPrimal = Boolean.FALSE;
+            return this;
+        }
+
+        /**
+         * TRUE for dual, FALSE for primal and null means "let the solver decide".
+         */
+        Boolean getDualOrPrimal() {
+            return myDualOrPrimal;
+        }
+
     }
 
     public static final class ModelIntegration extends ExpressionsBasedModel.Integration<LinearSolver> {
@@ -500,46 +528,52 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
         @Override
         public LinearSolver build(final ExpressionsBasedModel model) {
 
-            boolean alternative = !model.options.experimental;
+            Boolean dualOrPrimal = model.options.linear().getDualOrPrimal();
 
-            this.setSwitch(model, alternative);
+            boolean newerDualImpl = true;
 
-            if (alternative) {
-                return NEW_INTEGRATION.build(model);
+            if (Boolean.FALSE.equals(dualOrPrimal)) {
+                newerDualImpl = false;
+            }
+
+            this.setSwitch(model, ExpressionsBasedModel.IntegrationProperty.PRIMAL_OR_DUAL_LP, newerDualImpl);
+
+            if (newerDualImpl) {
+                return NEWER_DUAL_SOLVER.build(model);
             } else {
-                return OLD_INTEGRATION.build(model);
+                return OLDER_PRIMAL_SOLVER.build(model);
             }
         }
 
         @Override
         public boolean isCapable(final ExpressionsBasedModel model) {
-            return OLD_INTEGRATION.isCapable(model) || NEW_INTEGRATION.isCapable(model);
+            return OLDER_PRIMAL_SOLVER.isCapable(model) || NEWER_DUAL_SOLVER.isCapable(model);
         }
 
         @Override
         public Result toModelState(final Result solverState, final ExpressionsBasedModel model) {
-            if (this.isSwitch(model)) {
-                return NEW_INTEGRATION.toModelState(solverState, model);
+            if (this.isSwitch(model, ExpressionsBasedModel.IntegrationProperty.PRIMAL_OR_DUAL_LP)) {
+                return NEWER_DUAL_SOLVER.toModelState(solverState, model);
             } else {
-                return OLD_INTEGRATION.toModelState(solverState, model);
+                return OLDER_PRIMAL_SOLVER.toModelState(solverState, model);
             }
         }
 
         @Override
         public Result toSolverState(final Result modelState, final ExpressionsBasedModel model) {
-            if (this.isSwitch(model)) {
-                return NEW_INTEGRATION.toSolverState(modelState, model);
+            if (this.isSwitch(model, ExpressionsBasedModel.IntegrationProperty.PRIMAL_OR_DUAL_LP)) {
+                return NEWER_DUAL_SOLVER.toSolverState(modelState, model);
             } else {
-                return OLD_INTEGRATION.toSolverState(modelState, model);
+                return OLDER_PRIMAL_SOLVER.toSolverState(modelState, model);
             }
         }
 
         @Override
         protected int getIndexInSolver(final ExpressionsBasedModel model, final Variable variable) {
-            if (this.isSwitch(model)) {
-                return NEW_INTEGRATION.getIndexInSolver(model, variable);
+            if (this.isSwitch(model, ExpressionsBasedModel.IntegrationProperty.PRIMAL_OR_DUAL_LP)) {
+                return NEWER_DUAL_SOLVER.getIndexInSolver(model, variable);
             } else {
-                return OLD_INTEGRATION.getIndexInSolver(model, variable);
+                return OLDER_PRIMAL_SOLVER.getIndexInSolver(model, variable);
             }
         }
 
@@ -640,21 +674,18 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
             return modelVariableValues;
         }
 
-        public SimplexTableauSolver build(final ConvexData convexBuilder, final Optimisation.Options options) {
-
-            SimplexTableau tableau = SimplexTableauSolver.buildPrimal(convexBuilder, options, false);
-
-            return new SimplexTableauSolver(tableau, options);
-        }
-
         @Override
         public SimplexTableauSolver build(final ExpressionsBasedModel model) {
 
-            SimplexTableau tableau = SimplexTableauSolver.build(model, SimplexTableau.newTableauFactory(model.options));
+            Options options = model.options;
 
-            SimplexTableauSolver solver = new SimplexTableauSolver(tableau, model.options);
+            Function<LinearStructure, SimplexTableau> tableauFactory = SimplexTableau.newTableauFactory(options);
 
-            if (model.options.validate) {
+            SimplexTableau tableau = SimplexTableauSolver.build(model, tableauFactory);
+
+            SimplexTableauSolver solver = new SimplexTableauSolver(tableau, options);
+
+            if (options.validate) {
                 solver.setValidator(this.newValidator(model));
             }
 
@@ -729,17 +760,12 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
 
     public static final ExpressionsBasedModel.Integration<LinearSolver> INTEGRATION = new ModelIntegration();
 
-    /**
-     * An integration to a new/alternative/experimental LP-solver. This solver is intended to replace the
-     * current (old) solver, but is not yet ready to do that. You're welcome to try it - just add this
-     * integration by calling {@link ExpressionsBasedModel#addIntegration(ExpressionsBasedModel.Integration)}.
-     */
-    static final NewIntegration NEW_INTEGRATION = new NewIntegration();
+    static final NewIntegration NEWER_DUAL_SOLVER = new NewIntegration();
 
     /**
-     * An integration to a old/traditional/default LP-solver.
+     * An integration to a old/classic/primal LP-solver.
      */
-    static final OldIntegration OLD_INTEGRATION = new OldIntegration();
+    static final OldIntegration OLDER_PRIMAL_SOLVER = new OldIntegration();
 
     public static LinearSolver.Builder newBuilder() {
         return new LinearSolver.Builder();
@@ -787,11 +813,24 @@ public abstract class LinearSolver extends GenericSolver implements UpdatableSol
 
     public static Optimisation.Result solve(final ConvexData convex, final Optimisation.Options options, final boolean zeroC) {
 
-        int dualSize = SimplexTableauSolver.sizeOfDual(convex);
-        int primSize = SimplexTableauSolver.sizeOfPrimal(convex);
-        boolean dual = dualSize <= primSize;
+        boolean store = false;
 
-        return dual ? SimplexTableauSolver.doSolveDual(convex, options, zeroC) : SimplexTableauSolver.doSolvePrimal(convex, options, zeroC);
+        if (store) {
+
+            int dualSize = SimplexSolver.sizeOfDual(convex);
+            int primSize = SimplexSolver.sizeOfPrimal(convex);
+            boolean dual = dualSize <= primSize;
+
+            return dual ? SimplexSolver.doSolveConvexAsDual(convex, options, zeroC) : SimplexSolver.doSolveConvexAsPrimal(convex, options, zeroC);
+
+        } else {
+
+            int dualSize = SimplexTableauSolver.sizeOfDual(convex);
+            int primSize = SimplexTableauSolver.sizeOfPrimal(convex);
+            boolean dual = dualSize <= primSize;
+
+            return dual ? SimplexTableauSolver.doSolveConvexAsDual(convex, options, zeroC) : SimplexTableauSolver.doSolveConvexAsPrimal(convex, options, zeroC);
+        }
     }
 
     static LinearFunction<Double> toObjectiveFunction(final MatrixStore<Double> mtrxC) {
