@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -82,6 +82,10 @@ final class LinearStructure implements ExpressionsBasedModel.EntityMap {
         nbSlck = varsSlk;
         nbIdty = varsEye;
         nbArti = constrIn + constrEq - varsEye;
+
+        if (this.countConstraints() != this.countVariablesIncluded()) {
+            throw new IllegalStateException();
+        }
     }
 
     LinearStructure(final int nbConstraints, final int nbVariables) {
@@ -123,6 +127,20 @@ final class LinearStructure implements ExpressionsBasedModel.EntityMap {
         return nbVars + nbNegs + nbSlck + nbIdty;
     }
 
+    @Override
+    public boolean equals(final Object obj) {
+        if (this == obj) {
+            return true;
+        }
+        if (!(obj instanceof LinearStructure)) {
+            return false;
+        }
+        LinearStructure other = (LinearStructure) obj;
+        return Objects.equals(constraints, other.constraints) && nbArti == other.nbArti && nbEqus == other.nbEqus && nbIdty == other.nbIdty
+                && nbInes == other.nbInes && nbNegs == other.nbNegs && nbSlck == other.nbSlck && nbVars == other.nbVars
+                && Arrays.equals(negativePartVariables, other.negativePartVariables) && Arrays.equals(positivePartVariables, other.positivePartVariables);
+    }
+
     @Override
     public EntryPair<ModelEntity<?>, ConstraintType> getConstraint(final int idc) {
         return constraints.getEntry(idc);
@@ -138,6 +156,15 @@ final class LinearStructure implements ExpressionsBasedModel.EntityMap {
         }
     }
 
+    @Override
+    public int hashCode() {
+        final int prime = 31;
+        int result = 1;
+        result = prime * result + Arrays.hashCode(negativePartVariables);
+        result = prime * result + Arrays.hashCode(positivePartVariables);
+        return prime * result + Objects.hash(constraints, nbArti, nbEqus, nbIdty, nbInes, nbNegs, nbSlck, nbVars);
+    }
+
     @Override
     public int indexOf(final int j) {
 
@@ -199,10 +226,41 @@ final class LinearStructure implements ExpressionsBasedModel.EntityMap {
         constraints.negated[i] = negated;
     }
 
+    @Override
+    public String toString() {
+        return this.countConstraints() + " x " + this.countVariables();
+    }
+
+    /**
+     * The number of non-basic variables.
+     */
+    int countVariablesExcluded() {
+        return nbVars + nbNegs + nbSlck;
+    }
+
+    /**
+     * The number of basic variables.
+     */
+    int countVariablesIncluded() {
+        return nbIdty + nbArti;
+    }
+
     int countVariablesTotally() {
         return nbVars + nbNegs + nbSlck + nbIdty + nbArti;
     }
 
+    double getProblemRatio() {
+        double m = this.countConstraints();
+        double n = this.countVariablesTotally();
+        return n / m;
+    }
+
+    long getProblemSize() {
+        long m = this.countConstraints();
+        long n = this.countVariablesTotally();
+        return m * n;
+    }
+
     boolean isAnyArtificials() {
         return nbArti > 0;
     }
@@ -223,33 +281,4 @@ final class LinearStructure implements ExpressionsBasedModel.EntityMap {
         constraints.setMultiplierScale(multiplierScale);
     }
 
-    @Override
-    public int hashCode() {
-        final int prime = 31;
-        int result = 1;
-        result = prime * result + Arrays.hashCode(negativePartVariables);
-        result = prime * result + Arrays.hashCode(positivePartVariables);
-        result = prime * result + Objects.hash(constraints, nbArti, nbEqus, nbIdty, nbInes, nbNegs, nbSlck, nbVars);
-        return result;
-    }
-
-    @Override
-    public boolean equals(final Object obj) {
-        if (this == obj) {
-            return true;
-        }
-        if (!(obj instanceof LinearStructure)) {
-            return false;
-        }
-        LinearStructure other = (LinearStructure) obj;
-        return Objects.equals(constraints, other.constraints) && nbArti == other.nbArti && nbEqus == other.nbEqus && nbIdty == other.nbIdty
-                && nbInes == other.nbInes && nbNegs == other.nbNegs && nbSlck == other.nbSlck && nbVars == other.nbVars
-                && Arrays.equals(negativePartVariables, other.negativePartVariables) && Arrays.equals(positivePartVariables, other.positivePartVariables);
-    }
-
-    @Override
-    public String toString() {
-        return this.countConstraints() + " x " + this.countVariables();
-    }
-
 }
