@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -30,6 +30,7 @@ import org.ojalgo.array.ArrayR064;
 import org.ojalgo.array.SparseArray;
 import org.ojalgo.array.SparseArray.NonzeroView;
 import org.ojalgo.array.SparseArray.SparseFactory;
+import org.ojalgo.function.aggregator.Aggregator;
 import org.ojalgo.matrix.decomposition.LU;
 import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.matrix.store.PhysicalStore;
@@ -37,7 +38,7 @@ import org.ojalgo.matrix.store.R064Store;
 import org.ojalgo.matrix.transformation.InvertibleFactor;
 import org.ojalgo.type.ObjectPool;
 
-final class ProductFormInverse implements InvertibleFactor<Double> {
+final class ProductFormInverse implements BasisRepresentation {
 
     static final class ArrayPool extends ObjectPool<SparseArray<Double>> {
 
@@ -151,17 +152,19 @@ final class ProductFormInverse implements InvertibleFactor<Double> {
 
     @Override
     public void btran(final PhysicalStore<Double> arg) {
+
         for (int i = myFactors.size() - 1; i >= 0; i--) {
             myFactors.get(i).btran(arg);
         }
-        if (myRoot.isSolvable()) {
+        if (myRoot.isComputed()) {
             myRoot.ftran(arg);
         }
     }
 
     @Override
     public void ftran(final PhysicalStore<Double> arg) {
-        if (myRoot.isSolvable()) {
+
+        if (myRoot.isComputed()) {
             myRoot.btran(arg);
         }
         for (InvertibleFactor<Double> factor : myFactors) {
@@ -179,6 +182,45 @@ final class ProductFormInverse implements InvertibleFactor<Double> {
         return myDim;
     }
 
+    /**
+     * Update the product form inverse to reflect a replaced column.
+     *
+     * @param basis Full basis, with the column already exchanged.
+     */
+    @Override
+    public void reset(final MatrixStore<Double> basis) {
+
+        this.clearFactors();
+        myRoot.decompose(basis.transpose());
+    }
+
+    /**
+     * Update the inverse to reflect a replaced column in the basis.
+     *
+     * @param basis  Full basis, with the column already exchanged.
+     * @param col    The index, of the column, that was exchanged.
+     * @param values The (non zero) values of that column.
+     */
+    @Override
+    public void update(final MatrixStore<Double> basis, final int col, final SparseArray<Double> values) {
+
+        values.supplyTo(myWork);
+
+        this.ftran(myWork);
+
+        double diagonalElement = myWork.doubleValue(col);
+
+        if (Math.abs(diagonalElement) >= myScalingThreshold
+                && (Math.abs(diagonalElement) / myWork.aggregateAll(Aggregator.LARGEST).doubleValue()) >= myScalingThreshold) {
+
+            myFactors.add(this.newFactor(myWork, col, diagonalElement));
+
+        } else {
+
+            this.reset(basis);
+        }
+    }
+
     private void clearFactors() {
         for (ElementaryFactor factor : myFactors) {
             myArrayPool.giveBack(factor.getColumn());
@@ -200,59 +242,4 @@ final class ProductFormInverse implements InvertibleFactor<Double> {
         return new ElementaryFactor(sparse, col, diagonalElement);
     }
 
-    void reset() {
-        this.clearFactors();
-        myRoot.reset();
-    }
-
-    /**
-     * Update the product form inverse to reflect a replaced column.
-     *
-     * @param basis Full basis, with the column already exchanged.
-     */
-    void reset(final MatrixStore<Double> basis) {
-        this.clearFactors();
-        myRoot.decompose(basis.transpose());
-    }
-
-    /**
-     * Update the product form inverse to reflect a replaced column.
-     *
-     * @param col The column, of the basis, that was exchanged.
-     * @param values The (non zero) values of that column.
-     */
-    void update(final int col, final SparseArray<Double> values) {
-
-        values.supplyTo(myWork);
-
-        this.ftran(myWork);
-
-        double diagonalElement = myWork.doubleValue(col);
-
-        myFactors.add(this.newFactor(myWork, col, diagonalElement));
-    }
-
-    /**
-     * Update the inverse to reflect a replaced column in the basis.
-     *
-     * @param basis Full basis, with the column already exchanged.
-     * @param index The index, of the column, that was exchanged.
-     * @param values The (non zero) values of that column.
-     */
-    void update(final MatrixStore<Double> basis, final int index, final SparseArray<Double> values) {
-
-        values.supplyTo(myWork);
-
-        this.ftran(myWork);
-
-        double diagonalElement = myWork.doubleValue(index);
-
-        if (Math.abs(diagonalElement) >= myScalingThreshold) {
-            myFactors.add(this.newFactor(myWork, index, diagonalElement));
-        } else {
-            this.clearFactors();
-            myRoot.decompose(basis.transpose());
-        }
-    }
-
 }
