@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -38,6 +38,12 @@ import org.ojalgo.structure.Primitive1D;
 
 final class RevisedStore extends SimplexStore {
 
+    private static BasisRepresentation newBasisRepresentation(final int nbConstraints) {
+        // return new ProductFormInverse(nbConstraints, Prefix.MICRO); // 0 + 0
+        // return new DecomposedInverse(false, nbConstraints); // 1 + 0
+        return new DecomposedInverse(true, nbConstraints); // 0 + 0
+    }
+
     private static R064Store newColumn(final int nbRows) {
         return R064Store.FACTORY.make(nbRows, 1);
     }
@@ -53,34 +59,82 @@ final class RevisedStore extends SimplexStore {
     }
 
     /**
-     * a(N) in Gurobi presentation - delta – reduced costs
+     * Pivot row for dual simplex. Contains coefficients of non-basic variables in the tableau row for the
+     * exiting basic variable. Updated incrementally with each dual simplex iteration.
      */
     private final PhysicalStore<Double> a;
+
     /**
-     * Reduced costs / dual slack
+     * Reduced costs for non-basic variables. Shows objective change per unit increase in a non-basic
+     * variable. Updated incrementally with each iteration and pivot.
+     */
+    private final R064Store d;
+
+    /**
+     * Dual variables (Lagrange multipliers) for constraints. Computed as π = B^(-T) * c_B. Updated as needed
+     * for reporting or solution extraction.
+     */
+    private final R064Store l;
+
+    /**
+     * Current basis matrix B (columns of constraint matrix for basic variables). Not explicitly stored;
+     * computed from constraint matrix and current basis indices. Updated when the basis changes.
      */
-    private final PhysicalStore<Double> d;
-    private final PhysicalStore<Double> l;
-    private R064Store myAlternativeObjective = null;
     private final MatrixStore<Double> myBasis;
+
+    /**
+     * Complete constraint matrix A (all variables). Static during solve. Used for column access and basis
+     * updates.
+     */
     private final ColumnsSupplier<Double> myConstraintsBody;
-    private final ColumnsSupplier.SingleView<Double> myConstraintsColumn;
+
+    /**
+     * Right-hand side vector b of Ax = b. Updated when bounds are shifted. Used to compute the current basic
+     * solution.
+     */
     private final R064Store myConstraintsRHS;
-    private final ProductFormInverse myInvBasis;
+
+    /**
+     * Inverse of the current basis matrix B^(-1). Maintained and updated using factorization techniques.
+     * Updated when the basis changes or is reset.
+     */
+    private final BasisRepresentation myInvBasis;
+
+    /**
+     * Objective function coefficients c for all variables. Static during solve. Used to compute duals and
+     * objective value.
+     */
     private final R064Store myObjective;
+
     /**
-     * cost reducer
+     * Phase-1 objective function (sum of artificial variables). Used only during phase-1. Created and set up
+     * at the start of phase-1, and set to null after phase-1.
      */
-    private final PhysicalStore<Double> r;
+    private R064Store myPhase1Objective = null;
+
     /**
-     * primal basic solution
+     * Temporary storage for reduced cost calculations. Used as intermediate storage during iterations and
+     * dual variable updates.
      */
-    private final PhysicalStore<Double> x;
+    private final R064Store r;
+
     /**
-     * delta – primal basic solution
+     * Current basic solution x_B. Values of basic variables in the current iteration. Updated incrementally
+     * with each iteration and pivot.
      */
-    private final PhysicalStore<Double> y;
-    private final PhysicalStore<Double> z;
+    private final R064Store x;
+
+    /**
+     * Direction vector for entering variable in primal simplex. Shows how basic variables change when
+     * entering variable increases. Updated incrementally with each iteration.
+     */
+    private final R064Store y;
+
+    /**
+     * Temporary storage vector for various computations, especially rows of the inverse basis matrix. Reused
+     * to avoid memory allocation. Updated as needed for intermediate calculations.
+     */
+    private final R064Store z;
 
     RevisedStore(final int mm, final int nn) {
         this(new LinearStructure(mm, nn));
@@ -94,8 +148,6 @@ final class RevisedStore extends SimplexStore {
         myConstraintsBody = RevisedStore.newMatrix(m, n);
         myConstraintsRHS = RevisedStore.newColumn(m);
 
-        myConstraintsColumn = myConstraintsBody.columns();
-
         x = RevisedStore.newColumn(m);
         y = RevisedStore.newColumn(m);
         z = RevisedStore.newColumn(m);
@@ -106,7 +158,7 @@ final class RevisedStore extends SimplexStore {
         r = RevisedStore.newColumn(n - m);
 
         myBasis = myConstraintsBody.columns(included);
-        myInvBasis = new ProductFormInverse(m, TWO_THIRDS); // TODO The scaling threshold should be much smaller
+        myInvBasis = RevisedStore.newBasisRepresentation(m);
     }
 
     private void doBodyRow(final int i, final PhysicalStore<Double> destination) {
@@ -120,11 +172,24 @@ final class RevisedStore extends SimplexStore {
 
     private void doExclTranspMult(final MatrixStore<Double> lambda, final PhysicalStore<Double> results) {
         for (int je = 0; je < excluded.length; je++) {
-            myConstraintsColumn.goToColumn(excluded[je]);
-            results.set(je, myConstraintsColumn.dot(lambda));
+            int column = excluded[je];
+
+            // Skip artificial variables - they don't need correct/updated pivot row coefficients
+            if (!this.isArtificial(column)) {
+                results.set(je, myConstraintsBody.getColumn(column).dot(lambda));
+            }
+
         }
     }
 
+    private void updateDualsAndReducedCosts() {
+        R064Store objective = myPhase1Objective != null ? myPhase1Objective : myObjective;
+        objective.rows(included).supplyTo(l);
+        myInvBasis.btran(l);
+        this.doExclTranspMult(l, r);
+        d.fillMatching(objective.rows(excluded), SUBTRACT, r);
+    }
+
     @Override
     protected void pivot(final IterDescr iteration) {
 
@@ -140,7 +205,8 @@ final class RevisedStore extends SimplexStore {
     protected void shiftColumn(final int col, final double shift) {
         super.shiftColumn(col, shift);
         myConstraintsBody.column(col).axpy(-shift, myConstraintsRHS);
-        myInvBasis.ftran(myConstraintsRHS, x);
+        myConstraintsRHS.supplyTo(x);
+        myInvBasis.ftran(x);
     }
 
     @Override
@@ -149,46 +215,39 @@ final class RevisedStore extends SimplexStore {
     }
 
     @Override
-    void calculateIteration() {
+    void calculateIteration(final SimplexSolver.IterDescr iteration, final double shift) {
 
-        //        PhysicalStore<Double> x0 = x.copy();
-        //        PhysicalStore<Double> d0 = d.copy();
+        int exit = iteration.exit.index;
+        int enter = iteration.enter.index;
 
-        // Should be able to do something like
-        // x += y
-        // d += a
-        // ...and then move the setup/prepare/update outside of the loop
+        if (iteration.isBasisUpdate()) {
+            // For basis updates, we need to update both x and d
 
-        myInvBasis.btran(myObjective.rows(included), l);
+            // Update reduced costs
+            double stepD = d.doubleValue(enter) / a.doubleValue(enter);
+            a.axpy(-stepD, d);
+            d.set(enter, -stepD);
+        }
 
-        this.doExclTranspMult(l, r);
+        if (shift == ZERO) {
 
-        d.fillMatching(myObjective.rows(excluded), SUBTRACT, r);
+            double exitX = x.doubleValue(exit);
+            double enterY = y.doubleValue(exit);
+            double stepX = exitX / enterY;
+            y.axpy(-stepX, x);
+            x.set(exit, stepX);
 
-        myInvBasis.ftran(myConstraintsRHS, x);
+        } else {
 
-        //        BasicLogger.debug();
-        //
-        //        BasicLogger.debug();
-        //        BasicLogger.debug("x before: {}", x0.asList());
-        //        BasicLogger.debug("Ratio primal: {} exit={}", iteration.ratioPrimal, iteration.exit.index);
-        //        BasicLogger.debug("y step: {}", y.asList());
-        //        BasicLogger.debug("z step: {}", z.asList());
-        //        BasicLogger.debug("l step: {}", l.asList());
-        //        BasicLogger.debug("x after: {}", x.asList());
-        //
-        //        BasicLogger.debug();
-        //        BasicLogger.debug("d before: {}", d0.asList());
-        //        BasicLogger.debug("Ratio dual: {} enter={}", iteration.ratioDual, iteration.enter.index);
-        //        BasicLogger.debug("a step: {}", a.asList());
-        //        BasicLogger.debug("r step: {}", r.asList());
-        //        BasicLogger.debug("d after: {}", d.asList());
+            myConstraintsRHS.supplyTo(x);
+            myInvBasis.ftran(x);
+        }
     }
 
     @Override
     void calculatePrimalDirection(final EnterInfo enter) {
-        myConstraintsColumn.goToColumn(enter.column());
-        myInvBasis.ftran(myConstraintsColumn, y);
+        myConstraintsBody.getColumn(enter.column()).supplyTo(y);
+        myInvBasis.ftran(y);
     }
 
     @Override
@@ -209,15 +268,6 @@ final class RevisedStore extends SimplexStore {
         }
     }
 
-    @Override
-    void copyObjective() {
-        if (myAlternativeObjective == null) {
-            myAlternativeObjective = myObjective.copy();
-        } else {
-            myAlternativeObjective.fillMatching(myObjective);
-        }
-    }
-
     @Override
     double extractValue() {
 
@@ -282,6 +332,30 @@ final class RevisedStore extends SimplexStore {
         return myObjective;
     }
 
+    @Override
+    R064Store phase1() {
+
+        if (myPhase1Objective == null) {
+            myPhase1Objective = RevisedStore.newColumn(n);
+        }
+
+        return myPhase1Objective;
+    }
+
+    @Override
+    void prepareToIterate() {
+        myInvBasis.reset(myBasis);
+        this.updateDualsAndReducedCosts();
+        myConstraintsRHS.supplyTo(x);
+        myInvBasis.ftran(x);
+    }
+
+    @Override
+    void removePhase1() {
+        myPhase1Objective = null;
+        this.updateDualsAndReducedCosts();
+    }
+
     @Override
     void resetBasis(final int[] basis) {
 
@@ -290,30 +364,24 @@ final class RevisedStore extends SimplexStore {
         myInvBasis.reset(myBasis);
     }
 
-    @Override
-    void restoreObjective() {
-        myObjective.fillMatching(myAlternativeObjective);
-        myAlternativeObjective = null;
-    }
-
     @Override
     void setupClassicPhase1Objective() {
 
         int base = structure.nbIdty;
 
-        if (myAlternativeObjective == null) {
-            myAlternativeObjective = RevisedStore.newRow(myObjective.size());
+        if (myPhase1Objective == null) {
+            myPhase1Objective = RevisedStore.newRow(myObjective.size());
         }
 
         int nbVariables = structure.countVariables();
 
         for (int j = 0; j < nbVariables; j++) {
             double sum = myConstraintsBody.aggregateColumn(base, j, Aggregator.SUM).doubleValue();
-            myAlternativeObjective.set(j, -sum);
+            myPhase1Objective.set(j, -sum);
         }
 
-        //        double sum = myConstraintsRHS.aggregateRange(structure.nbIdty, m, Aggregator.SUM).doubleValue();
-        //        myAlternativeValue = -sum;
+        // double sum = myConstraintsRHS.aggregateRange(structure.nbIdty, m, Aggregator.SUM).doubleValue();
+        // myAlternativeValue = -sum;
     }
 
     @Override
@@ -332,6 +400,9 @@ final class RevisedStore extends SimplexStore {
 
     @Override
     Primitive1D sliceDualVariables() {
+
+        this.updateDualsAndReducedCosts();
+
         return new Primitive1D() {
 
             @Override
@@ -353,16 +424,55 @@ final class RevisedStore extends SimplexStore {
     }
 
     @Override
-    void switchObjective() {
+    void updateDualEdgeWeights(final IterDescr iteration) {
 
-        if (myAlternativeObjective != null) {
+        int p = iteration.exit.index;
+        int je = iteration.enter.index;
 
-            R064Store copy = myObjective.copy();
+        double pivotElement = a.doubleValue(je);
 
-            myObjective.fillMatching(myAlternativeObjective);
+        if (Math.abs(pivotElement) > 1e-9) {
 
-            myAlternativeObjective = copy;
+            double w_p = edgeWeights[p];
+
+            for (int i = 0; i < included.length; i++) {
+
+                if (i != p) {
+                    double ratio = y.doubleValue(i) / pivotElement;
+                    edgeWeights[i] += ratio * ratio * w_p;
+                }
+            }
+
+            edgeWeights[p] = ONE;
         }
     }
 
-}
+    @Override
+    void updatePrimalEdgeWeights(final IterDescr iteration) {
+
+        int p = iteration.enter.index;
+
+        double pivotElement = a.doubleValue(p);
+
+        if (Math.abs(pivotElement) > 1e-9) {
+
+            double w_p = edgeWeights[p];
+
+            for (int je = 0; je < excluded.length; je++) {
+
+                if (je != p) {
+                    int column = excluded[je];
+                    // Skip artificial variables in edge weight updates to match doExclTranspMult optimization
+                    if (!this.isArtificial(column)) {
+                        double ratio = a.doubleValue(je) / pivotElement;
+                        edgeWeights[je] += ratio * ratio * w_p;
+                    }
+                    // Artificial variables keep their current edge weight (typically 1.0)
+                }
+            }
+
+            edgeWeights[p] = ONE;
+        }
+    }
+
+}
\ No newline at end of file
