@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,16 +33,20 @@ import java.util.function.Function;
 
 import org.ojalgo.array.operation.IndexOf;
 import org.ojalgo.equation.Equation;
+import org.ojalgo.matrix.store.MatrixStore;
 import org.ojalgo.optimisation.ConstraintsMetaData;
 import org.ojalgo.optimisation.Expression;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
 import org.ojalgo.optimisation.Optimisation;
 import org.ojalgo.optimisation.Variable;
+import org.ojalgo.optimisation.convex.ConvexData;
 import org.ojalgo.optimisation.linear.SimplexStore.ColumnState;
 import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Access2D;
+import org.ojalgo.structure.Access2D.RowView;
 import org.ojalgo.structure.Mutate1D;
 import org.ojalgo.structure.Mutate2D;
+import org.ojalgo.structure.Primitive1D;
 import org.ojalgo.structure.Structure1D.IntIndex;
 import org.ojalgo.type.context.NumberContext;
 
@@ -210,8 +214,6 @@ abstract class SimplexSolver extends LinearSolver {
 
         final EnterInfo enter;
         final ExitInfo exit;
-        double ratioDual = MACHINE_LARGEST;
-        double ratioPrimal = MACHINE_LARGEST;
 
         IterDescr(final SimplexStore simplex) {
             super();
@@ -257,7 +259,7 @@ abstract class SimplexSolver extends LinearSolver {
         public String toString() {
             if (this.isBasisUpdate()) {
                 return exit.toString() + " -> " + enter.toString();
-            } else if (this.isBoundSwitch()) {
+            } else if (this.isBoundFlip()) {
                 return enter.toString() + " -> " + exit.to;
             } else {
                 return "-";
@@ -279,15 +281,15 @@ abstract class SimplexSolver extends LinearSolver {
          * Change from {@link ColumnState#LOWER} to {@link ColumnState#UPPER} or vice versa. (No change in
          * basis.)
          */
-        boolean isBoundSwitch() {
+        boolean isBoundFlip() {
             return enter.index >= 0 && enter.direction != Direction.STAY && enter.direction == exit.direction;
         }
 
         boolean isNoOperation() {
-            return !this.isBasisUpdate() && !this.isBoundSwitch();
+            return !this.isBasisUpdate() && !this.isBoundFlip();
         }
 
-        void markAsBoundSwitch() {
+        void markAsBoundFlip() {
             exit.reset();
             if (enter.direction == Direction.INCREASE) {
                 exit.direction = Direction.INCREASE;
@@ -301,8 +303,6 @@ abstract class SimplexSolver extends LinearSolver {
         void reset() {
             exit.reset();
             enter.reset();
-            ratioPrimal = MACHINE_LARGEST;
-            ratioDual = MACHINE_LARGEST;
         }
 
         int row() {
@@ -319,13 +319,13 @@ abstract class SimplexSolver extends LinearSolver {
         Set<IntIndex> fixedVariables = model.getFixedVariables();
         List<Variable> freeVariables = model.getFreeVariables();
 
-        List<Expression> equalityConstraints = new ArrayList<>();
+        List<Expression> equalConstraints = new ArrayList<>();
         List<Expression> lowerConstraints = new ArrayList<>();
         List<Expression> upperConstraints = new ArrayList<>();
 
-        model.constraints().map(c -> c.compensate(fixedVariables)).forEach(constraint -> {
+        model.constraints().map(constraint -> constraint.compensate(fixedVariables)).forEach(constraint -> {
             if (constraint.isEqualityConstraint()) {
-                equalityConstraints.add(constraint);
+                equalConstraints.add(constraint);
             } else {
                 if (constraint.isLowerConstraint()) {
                     lowerConstraints.add(constraint);
@@ -340,7 +340,7 @@ abstract class SimplexSolver extends LinearSolver {
 
         int nbUpConstr = upperConstraints.size();
         int nbLoConstr = lowerConstraints.size();
-        int nbEqConstr = equalityConstraints.size();
+        int nbEqConstr = equalConstraints.size();
 
         int nbProbVars = freeVariables.size();
         int nbSlckVars = nbUpConstr + nbLoConstr;
@@ -384,7 +384,7 @@ abstract class SimplexSolver extends LinearSolver {
         }
 
         for (int i = 0; i < nbEqConstr; i++) {
-            Expression expression = equalityConstraints.get(i);
+            Expression expression = equalConstraints.get(i);
             for (IntIndex key : expression.getLinearKeySet()) {
                 int column = model.indexOfFreeVariable(key);
                 double factor = expression.doubleValue(key, true);
@@ -414,6 +414,238 @@ abstract class SimplexSolver extends LinearSolver {
         return simplex;
     }
 
+    static Optimisation.Result doSolveConvexAsDual(final ConvexData<Double> convex, final Optimisation.Options options, final boolean zeroC) {
+
+        int nbCvxVars = convex.countVariables();
+        int nbCvxEqus = convex.countEqualityConstraints();
+        int nbCvxInes = convex.countInequalityConstraints();
+
+        MatrixStore<Double> cvxC = convex.getObjective().getLinearFactors(true);
+        MatrixStore<Double> cvxBE = convex.getBE();
+        MatrixStore<Double> cvxBI = convex.getBI();
+
+        LinearStructure structure = new LinearStructure(false, 0, nbCvxVars, nbCvxEqus + nbCvxInes, 0, 0, 0);
+
+        SimplexStore store = SimplexStore.newStoreFactory(options).apply(structure);
+
+        double[] lb = store.getLowerBounds();
+        double[] ub = store.getUpperBounds();
+        for (int j = 0; j < nbCvxEqus; j++) {
+            lb[j] = NEGATIVE_INFINITY;
+            ub[j] = POSITIVE_INFINITY;
+        }
+        for (int j = 0; j < nbCvxInes; j++) {
+            lb[nbCvxEqus + j] = ZERO;
+            ub[nbCvxEqus + j] = POSITIVE_INFINITY;
+        }
+
+        Mutate2D constrBody = store.constraintsBody();
+        Mutate1D constrRHS = store.constraintsRHS();
+        Mutate1D objective = store.objective();
+
+        for (int i = 0; i < nbCvxVars; i++) {
+            constrRHS.set(i, zeroC ? ZERO : cvxC.doubleValue(i));
+        }
+
+        for (RowView<Double> rowAE : convex.getRowsAE()) {
+            objective.set(rowAE.row(), cvxBE.doubleValue(rowAE.row()));
+            rowAE.nonzeros().forEach(nz -> constrBody.set(nz.index(), rowAE.row(), nz.doubleValue()));
+        }
+
+        for (RowView<Double> rowAI : convex.getRowsAI()) {
+            objective.set(nbCvxEqus + rowAI.row(), cvxBI.doubleValue(rowAI.row()));
+            rowAI.nonzeros().forEach(nz -> constrBody.set(nz.index(), nbCvxEqus + rowAI.row(), nz.doubleValue()));
+        }
+
+        LinearSolver solver = store.newPhasedSimplexSolver(options);
+
+        Result result = solver.solve();
+        Access1D<?> multiplierNumbers = result.getMultipliers().get();
+
+        State retState = result.getState();
+        if (retState == State.UNBOUNDED) {
+            retState = State.INFEASIBLE;
+        } else if (!retState.isFeasible()) {
+            retState = State.UNBOUNDED;
+        }
+
+        double retValue = -result.getValue();
+
+        Primitive1D retSolution = new Primitive1D() {
+
+            @Override
+            public double doubleValue(final int index) {
+                return -multiplierNumbers.doubleValue(index);
+            }
+
+            @Override
+            public void set(final int index, final double value) {
+                throw new IllegalArgumentException();
+            }
+
+            @Override
+            public int size() {
+                return multiplierNumbers.size();
+            }
+
+        };
+
+        Primitive1D retMultipliers = new Primitive1D() {
+
+            @Override
+            public double doubleValue(final int index) {
+
+                return result.doubleValue(index);
+
+            }
+
+            @Override
+            public void set(final int index, final double value) {
+                throw new IllegalArgumentException();
+            }
+
+            @Override
+            public int size() {
+                return nbCvxEqus + nbCvxInes;
+            }
+
+        };
+
+        Optimisation.Result retVal = new Optimisation.Result(retState, retValue, retSolution);
+        retVal.multipliers(retMultipliers);
+        return retVal;
+    }
+
+    static Optimisation.Result doSolveConvexAsPrimal(final ConvexData<Double> convex, final Optimisation.Options options, final boolean zeroC) {
+
+        int nbCvxVars = convex.countVariables();
+        int nbCvxEqus = convex.countEqualityConstraints();
+        int nbCvxInes = convex.countInequalityConstraints();
+
+        MatrixStore<Double> cvxC = convex.getObjective().getLinearFactors(true);
+        MatrixStore<Double> cvxBE = convex.getBE();
+        MatrixStore<Double> cvxBI = convex.getBI();
+
+        LinearStructure structure = new LinearStructure(false, nbCvxInes, nbCvxEqus, nbCvxVars, 0, 0, nbCvxInes);
+
+        SimplexStore store = SimplexStore.newStoreFactory(options).apply(structure);
+
+        double[] lb = store.getLowerBounds();
+        double[] ub = store.getUpperBounds();
+        for (int j = 0; j < nbCvxVars; j++) {
+            lb[j] = NEGATIVE_INFINITY;
+            ub[j] = POSITIVE_INFINITY;
+        }
+        for (int j = 0; j < nbCvxInes; j++) {
+            lb[nbCvxVars + j] = ZERO;
+            ub[nbCvxVars + j] = POSITIVE_INFINITY;
+        }
+        for (int j = 0; j < structure.nbArti; j++) {
+            lb[nbCvxVars + nbCvxInes + j] = ZERO;
+            ub[nbCvxVars + nbCvxInes + j] = ZERO;
+        }
+
+        Mutate2D constrBody = store.constraintsBody();
+        Mutate1D constrRHS = store.constraintsRHS();
+        Mutate1D objective = store.objective();
+
+        if (!zeroC) {
+            for (int j = 0; j < nbCvxVars; j++) {
+                objective.set(j, -cvxC.doubleValue(j));
+            }
+        }
+
+        for (RowView<Double> rowAI : convex.getRowsAI()) {
+            rowAI.nonzeros().forEach(nz -> constrBody.set(rowAI.row(), nz.index(), nz.doubleValue()));
+            constrBody.set(rowAI.row(), nbCvxVars + rowAI.row(), ONE);
+            constrRHS.set(rowAI.row(), cvxBI.doubleValue(rowAI.row()));
+        }
+
+        for (RowView<Double> rowAE : convex.getRowsAE()) {
+            rowAE.nonzeros().forEach(nz -> constrBody.set(nbCvxInes + rowAE.row(), nz.index(), nz.doubleValue()));
+            constrRHS.set(nbCvxInes + rowAE.row(), cvxBE.doubleValue(rowAE.row()));
+        }
+
+        LinearSolver solver = store.newPhasedSimplexSolver(options);
+
+        Result result = solver.solve();
+        Access1D<?> multiplierNumbers = result.getMultipliers().get();
+
+        State retState = result.getState();
+
+        double retValue = result.getValue();
+
+        Primitive1D retSolution = new Primitive1D() {
+
+            @Override
+            public double doubleValue(final int index) {
+                return result.doubleValue(index);
+            }
+
+            @Override
+            public void set(final int index, final double value) {
+                throw new IllegalArgumentException();
+            }
+
+            @Override
+            public int size() {
+                return nbCvxVars;
+            }
+
+        };
+
+        Primitive1D retMultipliers = new Primitive1D() {
+
+            @Override
+            public double doubleValue(final int index) {
+                if (index < nbCvxEqus) {
+                    return multiplierNumbers.doubleValue(nbCvxInes + index);
+                } else {
+                    return multiplierNumbers.doubleValue(index - nbCvxEqus);
+                }
+            }
+
+            @Override
+            public void set(final int index, final double value) {
+                throw new IllegalArgumentException();
+            }
+
+            @Override
+            public int size() {
+                return nbCvxEqus + nbCvxInes;
+            }
+
+        };
+
+        Optimisation.Result retVal = new Optimisation.Result(retState, retValue, retSolution);
+        retVal.multipliers(retMultipliers);
+        return retVal;
+    }
+
+    static int sizeOfDual(final ConvexData<?> convex) {
+
+        int nbCvxVars = convex.countVariables();
+        int nbCvxEqus = convex.countEqualityConstraints();
+        int nbCvxInes = convex.countInequalityConstraints();
+
+        int nbLinEqus = nbCvxVars;
+        int nbLinVars = nbCvxEqus + nbCvxInes + nbLinEqus;
+
+        return (nbLinEqus + 2) * (nbLinVars + 1);
+    }
+
+    static int sizeOfPrimal(final ConvexData<?> convex) {
+
+        int nbCvxVars = convex.countVariables();
+        int nbCvxEqus = convex.countEqualityConstraints();
+        int nbCvxInes = convex.countInequalityConstraints();
+
+        int nbLinEqus = nbCvxEqus + nbCvxInes;
+        int nbLinVars = nbCvxVars + nbLinEqus;
+
+        return (nbLinEqus + 2) * (nbLinVars + 1);
+    }
+
     private final SimplexStore mySimplex;
     private final double[] mySolutionShift;
     private double myValueShift = ZERO;
@@ -511,19 +743,21 @@ abstract class SimplexSolver extends LinearSolver {
             exit = iteration.exit;
         }
 
-        double largest = 1E-10;
+        double largest = MACHINE_SMALLEST;
         int[] included = mySimplex.included;
         for (int ji = included.length - 1; ji >= 0; ji--) {
             int j = included[ji];
 
             double candidate = mySimplex.getInfeasibility(ji);
             double magnitude = Math.abs(candidate);
+            double weight = mySimplex.edgeWeights[ji];
+            double score = (magnitude * magnitude) / weight;
 
             if (printable && this.isLogDebug()) {
                 this.log(1, "{}({}) {}", j, ji, candidate);
             }
 
-            if (magnitude > largest) {
+            if (magnitude > 1e-10 && score > largest) {
 
                 if (exit != null) {
 
@@ -538,11 +772,11 @@ abstract class SimplexSolver extends LinearSolver {
                     }
 
                     if (this.isLogDebug()) {
-                        this.log(2, "{} => {}", magnitude, exit);
+                        this.log(2, "{}/{}={} => {}", candidate, weight, score, exit);
                     }
                 }
 
-                largest = magnitude;
+                largest = score;
                 retVal = true;
             }
         }
@@ -586,7 +820,7 @@ abstract class SimplexSolver extends LinearSolver {
         }
 
         int n = mySimplex.structure.countVariables();
-        double largest = 1E-10;
+        double largest = MACHINE_SMALLEST;
         int[] excluded = mySimplex.excluded;
         for (int je = 0; je < excluded.length; je++) {
             int j = excluded[je];
@@ -595,12 +829,14 @@ abstract class SimplexSolver extends LinearSolver {
                 ColumnState columnState = mySimplex.getColumnState(j);
                 double candidate = mySimplex.getReducedCost(je);
                 double magnitude = Math.abs(candidate);
+                double weight = mySimplex.edgeWeights[je];
+                double score = (magnitude * magnitude) / weight;
 
                 if (printable && this.isLogDebug()) {
                     this.log(1, "{}({}) {} @ {}", j, je, candidate, columnState);
                 }
 
-                if (magnitude > largest) {
+                if (magnitude > 1e-10 && score > largest) {
 
                     if (candidate <= ZERO && columnState != ColumnState.UPPER) {
 
@@ -611,11 +847,11 @@ abstract class SimplexSolver extends LinearSolver {
                             enter.direction = Direction.INCREASE;
 
                             if (this.isLogDebug()) {
-                                this.log(2, "{} => {}", magnitude, enter);
+                                this.log(2, "{}/{}={} => {}", candidate, weight, score, enter);
                             }
                         }
 
-                        largest = magnitude;
+                        largest = score;
                         retVal = true;
 
                     } else if (candidate >= ZERO && columnState != ColumnState.LOWER) {
@@ -627,11 +863,11 @@ abstract class SimplexSolver extends LinearSolver {
                             enter.direction = Direction.DECREASE;
 
                             if (this.isLogDebug()) {
-                                this.log(2, "{} => {}", magnitude, enter);
+                                this.log(2, "{}/{}={} => {}", candidate, weight, score, enter);
                             }
                         }
 
-                        largest = magnitude;
+                        largest = score;
                         retVal = true;
                     }
                 }
@@ -685,7 +921,7 @@ abstract class SimplexSolver extends LinearSolver {
         }
     }
 
-    private void shift(final int column, final ColumnState state) {
+    private double shift(final int column, final ColumnState state) {
 
         double shift = ZERO;
         if (state == ColumnState.LOWER) {
@@ -699,6 +935,8 @@ abstract class SimplexSolver extends LinearSolver {
             mySolutionShift[column] += shift;
             myValueShift += mySimplex.getCost(column) * shift;
         }
+
+        return shift;
     }
 
     private Optimisation.Result solveUnconstrained() {
@@ -759,7 +997,7 @@ abstract class SimplexSolver extends LinearSolver {
         double ratio = ZERO;
         double scale = ONE;
 
-        iteration.ratioDual = Double.MAX_VALUE;
+        double iterationRatio = Double.MAX_VALUE;
         double iterationScale = MACHINE_LARGEST;
 
         int n = mySimplex.structure.countVariables();
@@ -787,25 +1025,25 @@ abstract class SimplexSolver extends LinearSolver {
 
                         if (exitDirection == Direction.INCREASE) {
                             if (columnState == ColumnState.LOWER && denom < ZERO) {
-                                ratio = numer / -denom;
+                                ratio = Math.max(ZERO, numer) / -denom;
                             } else if (columnState == ColumnState.UPPER && denom > ZERO) {
-                                ratio = -numer / denom;
+                                ratio = Math.max(ZERO, -numer) / denom;
                             }
                         } else if (exitDirection == Direction.DECREASE) {
                             if (columnState == ColumnState.LOWER && denom > ZERO) {
-                                ratio = numer / denom;
+                                ratio = Math.max(ZERO, numer) / denom;
                             } else if (columnState == ColumnState.UPPER && denom < ZERO) {
-                                ratio = -numer / -denom;
+                                ratio = Math.max(ZERO, -numer) / -denom;
                             }
                         }
                     }
 
-                    if (printable && this.isLogDebug()) {
+                    if (ratio < ZERO || printable && this.isLogDebug()) {
                         this.log(1, "{}({}) {} / {} = {}", j, je, numer, denom, ratio);
                     }
 
-                    if (ratio < iteration.ratioDual
-                            || scale > iterationScale && PIVOT.isDifferent(iterationScale, scale) && !RATIO.isDifferent(iteration.ratioDual, ratio)) {
+                    if (ratio < iterationRatio
+                            || scale > iterationScale && PIVOT.isDifferent(iterationScale, scale) && !RATIO.isDifferent(iterationRatio, ratio)) {
 
                         enter.index = je;
                         enter.from = columnState;
@@ -815,7 +1053,7 @@ abstract class SimplexSolver extends LinearSolver {
                             this.log(2, "{} => {}", ratio, enter);
                         }
 
-                        iteration.ratioDual = ratio;
+                        iterationRatio = ratio;
                         iterationScale = scale;
                     }
                 }
@@ -849,7 +1087,7 @@ abstract class SimplexSolver extends LinearSolver {
         double ratio = ZERO;
         double scale = ONE;
 
-        iteration.ratioPrimal = range;
+        double iterationRatio = range;
         double iterationScale = MACHINE_LARGEST;
 
         int[] included = mySimplex.included;
@@ -874,12 +1112,12 @@ abstract class SimplexSolver extends LinearSolver {
                         ratio = numer / denom;
                     }
 
-                    if (printable && this.isLogDebug()) {
+                    if (ratio < ZERO || printable && this.isLogDebug()) {
                         this.log(1, "{}({}) {} / {} = {}", j, ji, numer, denom, ratio);
                     }
 
-                    if (ratio < iteration.ratioPrimal
-                            || scale > iterationScale && PIVOT.isDifferent(iterationScale, scale) && !RATIO.isDifferent(iteration.ratioPrimal, ratio)) {
+                    if (ratio < iterationRatio
+                            || scale > iterationScale && PIVOT.isDifferent(iterationScale, scale) && !RATIO.isDifferent(iterationRatio, ratio)) {
 
                         exit.index = ji;
                         if (denom < ZERO) {
@@ -894,7 +1132,7 @@ abstract class SimplexSolver extends LinearSolver {
                             this.log(2, "{} => {}", ratio, exit);
                         }
 
-                        iteration.ratioPrimal = ratio;
+                        iterationRatio = ratio;
                         iterationScale = scale;
                     }
 
@@ -911,12 +1149,12 @@ abstract class SimplexSolver extends LinearSolver {
                         ratio = numer / denom;
                     }
 
-                    if (printable && this.isLogDebug()) {
+                    if (ratio < ZERO || printable && this.isLogDebug()) {
                         this.log(1, "{}({}) {} / {} = {}", j, ji, numer, denom, ratio);
                     }
 
-                    if (ratio < iteration.ratioPrimal
-                            || scale > iterationScale && PIVOT.isDifferent(iterationScale, scale) && !RATIO.isDifferent(iteration.ratioPrimal, ratio)) {
+                    if (ratio < iterationRatio
+                            || scale > iterationScale && PIVOT.isDifferent(iterationScale, scale) && !RATIO.isDifferent(iterationRatio, ratio)) {
 
                         exit.index = ji;
                         if (denom > ZERO) {
@@ -931,7 +1169,7 @@ abstract class SimplexSolver extends LinearSolver {
                             this.log(2, "{} => {}", ratio, exit);
                         }
 
-                        iteration.ratioPrimal = ratio;
+                        iterationRatio = ratio;
                         iterationScale = scale;
                     }
 
@@ -942,20 +1180,20 @@ abstract class SimplexSolver extends LinearSolver {
             }
         }
 
-        if (iteration.ratioPrimal >= range) {
+        if (iterationRatio >= range && Double.isFinite(iterationRatio)) {
 
             if (this.isLogDebug()) {
                 this.log("Bound switch!");
             }
 
-            iteration.markAsBoundSwitch();
+            iteration.markAsBoundFlip();
         }
 
         if (this.isLogDebug()) {
             this.log("==>> {}", exit);
         }
 
-        return exit.index >= 0 || iteration.isBoundSwitch();
+        return exit.index >= 0 || iteration.isBoundFlip();
     }
 
     private void update(final IterDescr iteration) {
@@ -972,13 +1210,19 @@ abstract class SimplexSolver extends LinearSolver {
                 this.log("Shift Exit: {}, Enter: {}", mySolutionShift[iteration.exit.column()], mySolutionShift[iteration.enter.column()]);
             }
 
+            int exitCol = iteration.exit.column();
+            int enterCol = iteration.enter.column();
+
             mySimplex.pivot(iteration);
 
-            this.shift(iteration.enter.column(), iteration.exit.to);
+            double shift = this.shift(iteration.enter.column(), iteration.exit.to);
 
-            mySimplex.calculateIteration();
+            // mySimplex.calculateIteration();
 
-        } else if (iteration.isBoundSwitch()) {
+            // mySimplex.calculateIterationOld(iteration, exitCol, enterCol, shift);
+            mySimplex.calculateIteration(iteration, shift);
+
+        } else if (iteration.isBoundFlip()) {
 
             if (this.isLogDebug()) {
                 this.log();
@@ -1001,14 +1245,81 @@ abstract class SimplexSolver extends LinearSolver {
                 throw new IllegalStateException();
             }
 
-        } else {
+        } else if (this.isLogDebug()) {
+            this.log();
+            this.log("No update operation!");
+        }
 
-            if (this.isLogDebug()) {
-                this.log();
-                this.log("No update operation!");
+    }
+
+    private boolean verifyDualFeasibility() {
+
+        boolean retVal = true;
+
+        double epsilon = options.feasibility.epsilon();
+
+        for (int je = 0, limit = mySimplex.excluded.length; je < limit; je++) {
+            int j = mySimplex.excluded[je];
+
+            if (mySimplex.isArtificial(j)) {
+                continue;
+            }
+
+            ColumnState state = mySimplex.getColumnState(j);
+
+            double rc = mySimplex.getReducedCost(je);
+            double lb = mySimplex.getLowerBound(j);
+            double ub = mySimplex.getUpperBound(j);
+
+            switch (state) {
+            case LOWER:
+                if (rc < -epsilon) {
+                    this.log("!DF {}({}) {}, but {} and [{},{}]", j, je, state, rc, lb, ub);
+                    retVal = false;
+                }
+                break;
+
+            case UPPER:
+                if (rc > epsilon) {
+                    this.log("!DF {}({}) {}, but {} and [{},{}]", j, je, state, rc, lb, ub);
+                    retVal = false;
+                }
+                break;
+
+            case UNBOUNDED:
+                // No reduced cost constraints for unbounded variables
+                break;
+
+            default:
+                throw new IllegalStateException("Unexpected ColumnState for variable " + j + ": " + state);
             }
         }
 
+        return retVal;
+    }
+
+    private boolean verifyPrimalFeasibility() {
+
+        boolean retVal = true;
+
+        double epsilon = options.feasibility.epsilon();
+
+        for (int i = 0, limit = mySimplex.included.length; i < limit; i++) {
+            int j = mySimplex.included[i];
+
+            double value = mySimplex.getCurrentRHS(i);
+
+            double lb = mySimplex.getLowerBound(j);
+            double ub = mySimplex.getUpperBound(j);
+
+            // Check if the value lies within the bounds
+            if (value < lb - epsilon || value > ub + epsilon) {
+                this.log("!PF {}({}) {}, but [{},{}]", j, i, value, lb, ub);
+                retVal = false;
+            }
+        }
+
+        return retVal;
     }
 
     final SimplexSolver basis(final int[] basis) {
@@ -1018,6 +1329,12 @@ abstract class SimplexSolver extends LinearSolver {
 
     final void doDualIterations(final IterDescr iteration) {
 
+        if (options.validate) {
+            this.verifyDualFeasibility();
+        }
+
+        mySimplex.resetEdgeWeights();
+
         boolean done = false;
         while (this.isIterationAllowed() && !done) {
 
@@ -1031,6 +1348,7 @@ abstract class SimplexSolver extends LinearSolver {
 
                     if (iteration.isBasisUpdate()) {
                         mySimplex.calculatePrimalDirection(iteration.enter);
+                        mySimplex.updateDualEdgeWeights(iteration);
                     }
 
                     this.update(iteration);
@@ -1051,15 +1369,20 @@ abstract class SimplexSolver extends LinearSolver {
             if (this.isLogDebug() && mySimplex.isPrintable()) {
                 this.logCurrentState();
             }
+
+            if (options.validate) {
+                this.verifyDualFeasibility();
+            }
         }
     }
 
     final void doPrimalIterations(final IterDescr iteration) {
 
-        // TODO Re-enable validation here
-        //        if (options.validate) {
-        //            this.validate(this.extractResult());
-        //        }
+        if (options.validate) {
+            this.verifyPrimalFeasibility();
+        }
+
+        mySimplex.resetEdgeWeights();
 
         boolean done = false;
         while (this.isIterationAllowed() && !done) {
@@ -1074,6 +1397,7 @@ abstract class SimplexSolver extends LinearSolver {
 
                     if (iteration.isBasisUpdate()) {
                         mySimplex.calculateDualDirection(iteration.exit);
+                        mySimplex.updatePrimalEdgeWeights(iteration);
                     }
 
                     this.update(iteration);
@@ -1095,10 +1419,9 @@ abstract class SimplexSolver extends LinearSolver {
                 this.logCurrentState();
             }
 
-            // TODO Re-enable validation here
-            //            if (options.validate) {
-            //                this.validate(this.extractResult());
-            //            }
+            if (options.validate) {
+                this.verifyPrimalFeasibility();
+            }
         }
     }
 
@@ -1128,10 +1451,6 @@ abstract class SimplexSolver extends LinearSolver {
         }
     }
 
-    final void initiatePhase1() {
-        mySimplex.copyObjective();
-    }
-
     final boolean isDualFeasible() {
         return !this.getPrimalEnterCandidate(null);
     }
@@ -1148,7 +1467,7 @@ abstract class SimplexSolver extends LinearSolver {
             this.solveUnconstrained(); // TODO return?
         }
 
-        mySimplex.calculateIteration();
+        mySimplex.prepareToIterate();
 
         this.resetIterationsCount();
 
@@ -1169,14 +1488,15 @@ abstract class SimplexSolver extends LinearSolver {
     abstract void setup(SimplexStore simplex);
 
     final void shift(final int index, final double shift, final double weight) {
-        mySimplex.shiftColumn(index, shift);
-        mySolutionShift[index] += shift;
-        myValueShift += weight * shift;
+        if (shift != ZERO) {
+            mySimplex.shiftColumn(index, shift);
+            mySolutionShift[index] += shift;
+            myValueShift += weight * shift;
+        }
     }
 
     void switchToPhase2() {
-        mySimplex.restoreObjective();
-        mySimplex.calculateIteration();
+        mySimplex.removePhase1();
     }
 
 }
