@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,9 +21,10 @@
  */
 package org.ojalgo.optimisation.linear;
 
-import static org.ojalgo.function.constant.PrimitiveMath.ZERO;
+import static org.ojalgo.function.constant.PrimitiveMath.*;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
@@ -34,8 +35,11 @@ import org.ojalgo.equation.Equation;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.optimisation.Optimisation;
 import org.ojalgo.optimisation.Optimisation.Options;
+import org.ojalgo.optimisation.integer.IntegerSolver;
 import org.ojalgo.optimisation.linear.SimplexSolver.EnterInfo;
 import org.ojalgo.optimisation.linear.SimplexSolver.ExitInfo;
+import org.ojalgo.optimisation.linear.SimplexSolver.IterDescr;
+import org.ojalgo.structure.Access1D;
 import org.ojalgo.structure.Mutate1D;
 import org.ojalgo.structure.Mutate2D;
 import org.ojalgo.structure.Primitive1D;
@@ -80,24 +84,34 @@ abstract class SimplexStore {
 
         return structure -> {
 
-            if (Boolean.TRUE.equals(options.sparse)
-                    || !Boolean.FALSE.equals(options.sparse) && Math.max(structure.countModelVariables(), structure.countConstraints()) > 500_000) {
+            long size = structure.getProblemSize();
+            double ratio = structure.getProblemRatio();
+
+            if (Boolean.TRUE.equals(options.sparse)) {
                 return new RevisedStore(structure);
-            } else {
+            } else if (Boolean.FALSE.equals(options.sparse)) {
                 return new DenseTableau(structure);
+            } else {
+                if ((size > 2_400_000L && ratio > 2.6) || size >= 100_000_000L || ratio >= 10.0) {
+                    return new RevisedStore(structure);
+                } else {
+                    return new DenseTableau(structure);
+                }
             }
         };
     }
 
-    private transient int[] myExcludedLower = null;
-    private transient int[] myExcludedUnbounded = null;
-    private transient int[] myExcludedUpper = null;
     private final double[] myLowerBounds;
     private final EnumPartition<SimplexStore.ColumnState> myPartition;
     private int myRemainingArtificials;
     private final List<String> myToStringList = new ArrayList<>();
     private final double[] myUpperBounds;
 
+    /**
+     * Either the primal or dual devex edge weights, depending on the algorithm used. Sized so that it can
+     * hold either.
+     */
+    final double[] edgeWeights;
     /**
      * excluded == not in the basis
      */
@@ -131,12 +145,11 @@ abstract class SimplexStore {
         excluded = Structure1D.newIncreasingRange(0, n - m);
         included = Structure1D.newIncreasingRange(n - m, m);
 
-        myPartition = new EnumPartition<>(n, ColumnState.LOWER);
-        for (int j = 0; j < m; j++) {
-            myPartition.update(included[j], ColumnState.BASIS);
-        }
+        myPartition = new EnumPartition<>(n, ColumnState.BASIS);
 
         myRemainingArtificials = linearStructure.nbArti;
+
+        edgeWeights = new double[Math.max(m, n - m)];
     }
 
     @Override
@@ -184,7 +197,7 @@ abstract class SimplexStore {
 
     abstract void calculateDualDirection(ExitInfo exit);
 
-    abstract void calculateIteration();
+    abstract void calculateIteration(IterDescr iteration, double shift);
 
     abstract void calculatePrimalDirection(EnterInfo enter);
 
@@ -200,10 +213,6 @@ abstract class SimplexStore {
 
     abstract void copyBasicSolution(double[] solution);
 
-    abstract void copyObjective();
-
-    abstract void switchObjective();
-
     /**
      * The number of artificial variables in the basis.
      */
@@ -215,25 +224,27 @@ abstract class SimplexStore {
 
         double[] retVal = new double[n];
 
-        int[] lower = this.getExcludedLower();
-        for (int i = 0; i < lower.length; i++) {
-            int j = lower[i];
-            double value = this.getLowerBound(j);
-            if (Double.isFinite(value)) {
-                retVal[j] = value;
-            } else {
-                retVal[j] = ZERO;
-            }
-        }
+        for (int je = 0; je < excluded.length; je++) {
+            int j = excluded[je];
+            ColumnState columnState = myPartition.get(j);
 
-        int[] upper = this.getExcludedUpper();
-        for (int i = 0; i < upper.length; i++) {
-            int j = upper[i];
-            double value = this.getUpperBound(j);
-            if (Double.isFinite(value)) {
-                retVal[j] = value;
-            } else {
-                retVal[j] = ZERO;
+            if (columnState == ColumnState.LOWER) {
+
+                double lowerBound = this.getLowerBound(j);
+                if (Double.isFinite(lowerBound)) {
+                    retVal[j] = lowerBound;
+                } else {
+                    retVal[j] = ZERO;
+                }
+
+            } else if (columnState == ColumnState.UPPER) {
+
+                double upperBound = this.getUpperBound(j);
+                if (Double.isFinite(upperBound)) {
+                    retVal[j] = upperBound;
+                } else {
+                    retVal[j] = ZERO;
+                }
             }
         }
 
@@ -244,6 +255,10 @@ abstract class SimplexStore {
 
     abstract double extractValue();
 
+    /**
+     * When {@link SimplexSolver} is used as node solver for {@link IntegerSolver} this method generates cut
+     * candidates.
+     */
     final Collection<Equation> generateCutCandidates(final boolean[] integer, final NumberContext accuracy, final double fractionality, final double[] shift) {
 
         if (myRemainingArtificials > 0) {
@@ -298,42 +313,6 @@ abstract class SimplexStore {
      */
     abstract double getCurrentRHS(int i);
 
-    /**
-     * Indices of columns/variables at their lower bounds.
-     */
-    final int[] getExcludedLower() {
-        int count = myPartition.count(ColumnState.LOWER);
-        if (myExcludedLower == null || myExcludedLower.length != count) {
-            myExcludedLower = new int[count];
-        }
-        myPartition.extract(ColumnState.LOWER, false, myExcludedLower);
-        return myExcludedLower;
-    }
-
-    /**
-     * Indices of unbounded columns/variables.
-     */
-    final int[] getExcludedUnbounded() {
-        int count = myPartition.count(ColumnState.UNBOUNDED);
-        if (myExcludedUnbounded == null || myExcludedUnbounded.length != count) {
-            myExcludedUnbounded = new int[count];
-        }
-        myPartition.extract(ColumnState.UNBOUNDED, false, myExcludedUnbounded);
-        return myExcludedUnbounded;
-    }
-
-    /**
-     * Indices of columns/variables at their upper bounds.
-     */
-    final int[] getExcludedUpper() {
-        int count = myPartition.count(ColumnState.UPPER);
-        if (myExcludedUpper == null || myExcludedUpper.length != count) {
-            myExcludedUpper = new int[count];
-        }
-        myPartition.extract(ColumnState.UPPER, false, myExcludedUpper);
-        return myExcludedUpper;
-    }
-
     abstract double getInfeasibility(int i);
 
     final double getLowerBound(final int index) {
@@ -404,11 +383,7 @@ abstract class SimplexStore {
     }
 
     final boolean isNegated(final int j) {
-        if (myUpperBounds[j] <= ZERO && myLowerBounds[j] < ZERO) {
-            return true;
-        } else {
-            return false;
-        }
+        return myUpperBounds[j] <= ZERO && myLowerBounds[j] < ZERO;
     }
 
     /**
@@ -446,10 +421,19 @@ abstract class SimplexStore {
     }
 
     /**
-     * The simplex' objective function.
+     * The objective function.
      */
     abstract Mutate1D objective();
 
+    /**
+     * The phase-1 objective function.
+     */
+    abstract <T extends Mutate1D & Access1D<Double>> T phase1();
+
+    abstract void prepareToIterate();
+
+    abstract void removePhase1();
+
     /**
      * Everything that is not in the basis is set to be in at lower bound.
      */
@@ -459,7 +443,7 @@ abstract class SimplexStore {
             throw new IllegalStateException();
         }
 
-        myPartition.fill(ColumnState.LOWER);
+        myPartition.reset(ColumnState.LOWER);
 
         for (int i = 0; i < newBasis.length; i++) {
             myPartition.update(newBasis[i], ColumnState.BASIS);
@@ -469,7 +453,11 @@ abstract class SimplexStore {
         myPartition.extract(ColumnState.BASIS, true, excluded);
     }
 
-    abstract void restoreObjective();
+    void resetEdgeWeights() {
+        Arrays.fill(edgeWeights, ONE);
+    }
+
+    abstract void setupClassicPhase1Objective();
 
     abstract Primitive1D sliceBodyRow(final int row);
 
@@ -517,6 +505,16 @@ abstract class SimplexStore {
         excluded[enter] = inclExit;
     }
 
+    /**
+     * Update edge weights for basic (included) variables.
+     */
+    abstract void updateDualEdgeWeights(final IterDescr iteration);
+
+    /**
+     * Update edge weights for non-basic (excluded) variables.
+     */
+    abstract void updatePrimalEdgeWeights(final IterDescr iteration);
+
     boolean updateRange(final int index, final double lower, final double upper) {
         myLowerBounds[index] = lower;
         myUpperBounds[index] = upper;
@@ -528,6 +526,4 @@ abstract class SimplexStore {
         return this;
     }
 
-    abstract void setupClassicPhase1Objective();
-
 }
