@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -223,6 +223,11 @@ public final class PrimitiveScalar implements Scalar<Double>, Enforceable<Primit
         return PrimitiveScalar.isSmall(comparedTo, myValue);
     }
 
+    @Override
+    public boolean isZero() {
+        return myValue == PrimitiveMath.ZERO;
+    }
+
     @Override
     public long longValue() {
         return (long) myValue;
