@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -135,7 +135,7 @@ public final class Quaternion implements SelfDeclaringScalar<Quaternion>, Access
             tmpAngle += PrimitiveMath.TWO_PI;
         }
 
-        //  BasicLogger.debug("Koordinater: {} {} {}", norm, Arrays.toString(unitVector), phase);
+        // BasicLogger.debug("Koordinater: {} {} {}", norm, Arrays.toString(unitVector), phase);
 
         if (tmpAngle <= ARGUMENT_TOLERANCE) {
 
@@ -171,9 +171,43 @@ public final class Quaternion implements SelfDeclaringScalar<Quaternion>, Access
 
     }
 
+    /**
+     * Create a {@link Quaternion} that captures a rotation about the provided axis by the provided angle.
+     * <p>
+     * The quaternion representation of the rotation may be expressed as:
+     *
+     * <pre>
+     * q = cos(θ / 2) + sin(θ / 2) * (ub * i + uc * j + ud * k)
+     * </pre>
+     *
+     * where θ is the angle of rotation and
+     *
+     * <pre>
+     * [ub, uc, ud]
+     * </pre>
+     *
+     * is the axis of rotation. This method accepts a single axis, so only a single imaginary component is
+     * populated.
+     * <p>
+     * To rotate in multiple axes, multiply multiple quaternions:
+     *
+     * <pre>{@code
+     * Quaternion xRotation = Quaternion.makeRotation(RotationAxis.X, Math.toRadians(-3));
+     * Quaternion yRotation = Quaternion.makeRotation(RotationAxis.Y, Math.toRadians(2));
+     * Quaternion zRotation = Quaternion.makeRotation(RotationAxis.Z, Math.toRadians(45));
+     * Quaternion zyxRotation = zRotation.multiply(yRotation).multiply(xRotation);
+     * }</pre>
+     *
+     * This creates a rotation in ZYX order.
+     *
+     * @param axis  the axis to rotate about, non-null
+     * @param angle the angle, in radians to rotate about the axis
+     * @return the quaternion
+     */
     public static Quaternion makeRotation(final RotationAxis axis, final double angle) {
 
-        final double tmpScalar = PrimitiveMath.COS.invoke(angle);
+        final double tmpHalfAngle = PrimitiveMath.DIVIDE.invoke(angle, 2);
+        final double tmpScalar = PrimitiveMath.COS.invoke(tmpHalfAngle);
 
         double tmpI = PrimitiveMath.ZERO;
         double tmpJ = PrimitiveMath.ZERO;
@@ -183,17 +217,17 @@ public final class Quaternion implements SelfDeclaringScalar<Quaternion>, Access
 
         case X:
 
-            tmpI = PrimitiveMath.SIN.invoke(angle);
+            tmpI = PrimitiveMath.SIN.invoke(tmpHalfAngle);
             break;
 
         case Y:
 
-            tmpJ = PrimitiveMath.SIN.invoke(angle);
+            tmpJ = PrimitiveMath.SIN.invoke(tmpHalfAngle);
             break;
 
         case Z:
 
-            tmpK = PrimitiveMath.SIN.invoke(angle);
+            tmpK = PrimitiveMath.SIN.invoke(tmpHalfAngle);
             break;
 
         default:
@@ -631,6 +665,11 @@ public final class Quaternion implements SelfDeclaringScalar<Quaternion>, Access
         return PrimitiveScalar.CONTEXT.isSmall(comparedTo, this.norm());
     }
 
+    @Override
+    public boolean isZero() {
+        return myScalar == PrimitiveMath.ZERO && i == PrimitiveMath.ZERO && j == PrimitiveMath.ZERO && k == PrimitiveMath.ZERO;
+    }
+
     @Override
     public long longValue() {
         return (long) myScalar;
