@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -119,6 +119,12 @@ public final class RationalNumber implements SelfDeclaringScalar<RationalNumber>
         }
     }
 
+    public static RationalNumber parse(final CharSequence plainNumberString) {
+        String string = plainNumberString.toString();
+        BigDecimal number = new BigDecimal(string);
+        return RationalNumber.valueOf(number);
+    }
+
     public static RationalNumber rational(final double d) {
         if (d < 0) {
             return RationalNumber.rational(-d, 1.0, 39).negate();
@@ -171,10 +177,12 @@ public final class RationalNumber implements SelfDeclaringScalar<RationalNumber>
                 retDenom = retDenom.shiftRight(shift);
             }
 
-            //                final BigDecimal recreated = BigFunction.DIVIDE.invoke(new BigDecimal(retNumer), new BigDecimal(retDenom));
-            //                if (recreated.plus(MathContext.DECIMAL32).compareTo(tmpBigDecimal.plus(MathContext.DECIMAL32)) != 0) {
-            //                    BasicLogger.debug("{} != {}", tmpBigDecimal, recreated);
-            //                }
+            // final BigDecimal recreated = BigFunction.DIVIDE.invoke(new BigDecimal(retNumer), new
+            // BigDecimal(retDenom));
+            // if (recreated.plus(MathContext.DECIMAL32).compareTo(tmpBigDecimal.plus(MathContext.DECIMAL32))
+            // != 0) {
+            // BasicLogger.debug("{} != {}", tmpBigDecimal, recreated);
+            // }
 
             return new RationalNumber(retNumer.longValue(), retDenom.longValue());
         }
@@ -196,7 +204,8 @@ public final class RationalNumber implements SelfDeclaringScalar<RationalNumber>
         final int s = ((bits >> 63) == 0) ? 1 : -1;
         final int e = (int) ((bits >> 52) & 0x7ffL);
         long m = (e == 0) ? (bits & 0xfffffffffffffL) << 1 : (bits & 0xfffffffffffffL) | 0x10000000000000L;
-        // Now we're looking for s * m * 2^{e - 1075}, 1075 being bias of 1023 plus 52 positions of binary fraction
+        // Now we're looking for s * m * 2^{e - 1075}, 1075 being bias of 1023 plus 52 positions of binary
+        // fraction
 
         int exponent = e - 1075;
 
@@ -208,7 +217,8 @@ public final class RationalNumber implements SelfDeclaringScalar<RationalNumber>
             return new RationalNumber(s * numerator, 1L);
         }
 
-        // Since denominator is a power of 2, GCD can only be power of two, so we simplify by dividing by 2 repeatedly
+        // Since denominator is a power of 2, GCD can only be power of two, so we simplify by dividing by 2
+        // repeatedly
         while (((m & 1) == 0) && (exponent < 0)) {
             m >>= 1;
             exponent++;
@@ -390,11 +400,6 @@ public final class RationalNumber implements SelfDeclaringScalar<RationalNumber>
         return this.add(RationalNumber.valueOf(arg));
     }
 
-    @Override
-    public RationalNumber add(final float scalarAddend) {
-        return this.add((double) scalarAddend);
-    }
-
     @Override
     public RationalNumber add(final RationalNumber arg) {
         if (this.isNaN() || arg.isNaN()) {
@@ -464,11 +469,6 @@ public final class RationalNumber implements SelfDeclaringScalar<RationalNumber>
         return this.divide(RationalNumber.valueOf(arg));
     }
 
-    @Override
-    public RationalNumber divide(final float scalarDivisor) {
-        return this.divide((double) scalarDivisor);
-    }
-
     @Override
     public RationalNumber divide(final RationalNumber arg) {
         if (this.isNaN() || arg.isNaN()) {
@@ -569,6 +569,11 @@ public final class RationalNumber implements SelfDeclaringScalar<RationalNumber>
         return BigScalar.CONTEXT.isSmall(comparedTo, this.doubleValue());
     }
 
+    @Override
+    public boolean isZero() {
+        return myNumerator == 0L && myDenominator != 0L;
+    }
+
     @Override
     public long longValue() {
         return this.toBigDecimal().longValue();
@@ -579,11 +584,6 @@ public final class RationalNumber implements SelfDeclaringScalar<RationalNumber>
         return this.multiply(RationalNumber.valueOf(arg));
     }
 
-    @Override
-    public RationalNumber multiply(final float scalarMultiplicand) {
-        return this.multiply((double) scalarMultiplicand);
-    }
-
     @Override
     public RationalNumber multiply(final RationalNumber arg) {
         if (this.isNaN() || arg.isNaN()) {
@@ -645,11 +645,6 @@ public final class RationalNumber implements SelfDeclaringScalar<RationalNumber>
         return this.subtract(RationalNumber.valueOf(arg));
     }
 
-    @Override
-    public RationalNumber subtract(final float scalarSubtrahend) {
-        return this.subtract((double) scalarSubtrahend);
-    }
-
     @Override
     public RationalNumber subtract(final RationalNumber arg) {
         if (this.isNaN() || arg.isNaN()) {
