@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -34,9 +34,9 @@ abstract class ArrayBasedTensor<N extends Comparable<N>, T extends ArrayBasedTen
 
     public static abstract class Factory<N extends Comparable<N>> {
 
-        private final DenseArray.Factory<N> myArrayFactory;
+        private final DenseArray.Factory<N, ?> myArrayFactory;
 
-        Factory(final DenseArray.Factory<N> arrayFactory) {
+        Factory(final DenseArray.Factory<N, ?> arrayFactory) {
             super();
             myArrayFactory = arrayFactory;
         }
@@ -76,7 +76,7 @@ abstract class ArrayBasedTensor<N extends Comparable<N>, T extends ArrayBasedTen
             return myArrayFactory.scalar();
         }
 
-        DenseArray.Factory<N> getArrayFactory() {
+        DenseArray.Factory<N, ?> getArrayFactory() {
             return myArrayFactory;
         }
 
@@ -173,12 +173,12 @@ abstract class ArrayBasedTensor<N extends Comparable<N>, T extends ArrayBasedTen
         double frobeniusNorm = NumberDefinition.doubleValue(array.aggregateAll(Aggregator.NORM2));
 
         switch (this.rank()) {
-        case 1:
-            return frobeniusNorm;
-        case 2:
-            return frobeniusNorm / PrimitiveMath.SQRT.invoke(this.dimensions());
-        default:
-            return frobeniusNorm / PrimitiveMath.ROOT.invoke(this.dimensions(), this.rank());
+            case 1:
+                return frobeniusNorm;
+            case 2:
+                return frobeniusNorm / PrimitiveMath.SQRT.invoke(this.dimensions());
+            default:
+                return frobeniusNorm / PrimitiveMath.ROOT.invoke(this.dimensions(), this.rank());
         }
     }
 
