@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -44,7 +44,10 @@ public final class EnumPartition<E extends Enum<E>> {
         myConstants = initialValue.getDeclaringClass().getEnumConstants();
         myCounts = new int[myConstants.length];
 
-        this.fill(initialValue);
+        int ordinal = initialValue.ordinal();
+
+        Arrays.fill(myValues, (byte) ordinal);
+        myCounts[ordinal] = size;
     }
 
     /**
@@ -97,21 +100,19 @@ public final class EnumPartition<E extends Enum<E>> {
         byte key = (byte) value.ordinal();
 
         for (int i = 0, j = 0; i < myValues.length && j < receiver.length; i++) {
-            if ((myValues[i] == key) != negate) {
+            if (myValues[i] == key != negate) {
                 receiver[j] = i;
                 j++;
             }
         }
     }
 
+    /**
+     * @deprecated v56 Use {@link #reset(E)} instead
+     */
+    @Deprecated
     public void fill(final E value) {
-
-        int index = value.ordinal();
-        byte key = (byte) index;
-
-        Arrays.fill(myValues, key);
-        Arrays.fill(myCounts, 0);
-        myCounts[index] = myValues.length;
+        this.reset(value);
     }
 
     public E get(final int index) {
@@ -122,6 +123,15 @@ public final class EnumPartition<E extends Enum<E>> {
         return myValues[index] == value.ordinal();
     }
 
+    public void reset(final E value) {
+
+        int ordinal = value.ordinal();
+
+        Arrays.fill(myValues, (byte) ordinal);
+        Arrays.fill(myCounts, 0);
+        myCounts[ordinal] = myValues.length;
+    }
+
     public int size() {
         return myValues.length;
     }
