@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2022 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -23,6 +23,7 @@ package org.ojalgo.type;
 
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.LinkedTransferQueue;
 
 import org.ojalgo.ProgrammingError;
 
@@ -33,7 +34,7 @@ public abstract class ObjectPool<T> {
 
     public ObjectPool() {
         super();
-        myObjects = new LinkedBlockingQueue<>();
+        myObjects = new LinkedTransferQueue<>();
         myLimited = false;
     }
 
@@ -51,8 +52,8 @@ public abstract class ObjectPool<T> {
         if (myLimited) {
             try {
                 retVal = myObjects.take();
-            } catch (InterruptedException exception) {
-                throw new RuntimeException(exception);
+            } catch (InterruptedException cause) {
+                throw new RuntimeException(cause);
             }
         } else if ((retVal = myObjects.poll()) == null) {
             retVal = this.newObject();
@@ -66,8 +67,8 @@ public abstract class ObjectPool<T> {
         if (myLimited) {
             try {
                 myObjects.put(object);
-            } catch (InterruptedException exception) {
-                throw new RuntimeException(exception);
+            } catch (InterruptedException cause) {
+                throw new RuntimeException(cause);
             }
         } else {
             myObjects.offer(object);
