@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,11 +24,17 @@ package org.ojalgo.type;
 import java.util.Timer;
 import java.util.TimerTask;
 
-public abstract class TypeCache<T> {
+/**
+ * A supplier that most of the time returns a cached value, and only recomputes it when necessary
+ * (periodically).
+ *
+ * @deprecated v56 Use {@link ForgetfulMap#newValueCache(Object, java.util.function.Function)} instead.
+ */
+@Deprecated
+public abstract class TypeCache<T> implements ForgetfulMap.ValueCache<T> {
 
     private static final Timer TIMER = new Timer("TypeCache-Daemon", true);
     private transient volatile T myCachedObject;
-
     private volatile boolean myDirty;
 
     public TypeCache(final long aPurgeIntervalMeassure, final CalendarDateUnit aPurgeIntervalUnit) {
@@ -54,13 +60,15 @@ public abstract class TypeCache<T> {
         this(8L, CalendarDateUnit.HOUR);
     }
 
+    @Override
     public synchronized final void flushCache() {
         myCachedObject = null;
     }
 
+    @Override
     public synchronized final T getCachedObject() {
 
-        if ((myCachedObject == null) || myDirty) {
+        if (myCachedObject == null || myDirty) {
 
             myCachedObject = this.recreateCache();
 
@@ -70,14 +78,17 @@ public abstract class TypeCache<T> {
         return myCachedObject;
     }
 
+    @Override
     public synchronized final boolean isCacheSet() {
         return myCachedObject != null;
     }
 
+    @Override
     public synchronized final boolean isDirty() {
         return myDirty;
     }
 
+    @Override
     public synchronized final void makeDirty() {
         myDirty = true;
     }
