@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,8 +33,8 @@ import org.openjdk.jmh.runner.options.TimeValue;
 public abstract class BenchmarkUtils {
 
     public static ChainedOptionsBuilder options() {
-        return new OptionsBuilder().forks(1).measurementIterations(3).warmupIterations(7).mode(Mode.Throughput).timeUnit(TimeUnit.MINUTES)
-                .timeout(new TimeValue(1L, TimeUnit.HOURS)).jvmArgs("-Xmx8g");
+        return new OptionsBuilder().forks(1).measurementIterations(3).warmupIterations(7).mode(Mode.Throughput).timeUnit(TimeUnit.SECONDS)
+                .timeout(new TimeValue(1L, TimeUnit.MINUTES)).jvmArgs("-Xmx8g");
     }
 
     public static void run(final ChainedOptionsBuilder options, final Class<?> clazz) throws RunnerException {
