@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,6 +29,7 @@ import java.util.Arrays;
 import java.util.function.IntSupplier;
 
 import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.function.Executable;
 import org.ojalgo.array.Array1D;
 import org.ojalgo.array.ArrayR064;
 import org.ojalgo.function.constant.PrimitiveMath;
@@ -48,6 +49,7 @@ import org.ojalgo.matrix.store.PhysicalStore;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.optimisation.ExpressionsBasedModel;
 import org.ojalgo.optimisation.Optimisation;
+import org.ojalgo.optimisation.Optimisation.Result;
 import org.ojalgo.optimisation.Optimisation.State;
 import org.ojalgo.random.Uniform;
 import org.ojalgo.scalar.ComplexNumber;
@@ -72,7 +74,20 @@ import org.ojalgo.type.context.NumberContext;
  */
 public abstract class TestUtils /* extends Assertions */ {
 
-    private static final NumberContext EQUALS = NumberContext.of(12);
+    private static final NumberContext EQUALS = NumberContext.of(10);
+
+    public static void assertArrayEquals(final byte[] expected, final byte[] actual) {
+        Assertions.assertArrayEquals(expected, actual);
+    }
+
+    public static void assertArrayEquals(final double[] expected, final double[] actual) {
+        Assertions.assertArrayEquals(expected, actual);
+
+    }
+
+    public static void assertArrayEquals(final long[] expected, final long[] actual) {
+        Assertions.assertArrayEquals(expected, actual);
+    }
 
     public static void assertBounds(final Comparable<?> lower, final Access1D<?> values, final Comparable<?> upper, final NumberContext precision) {
         for (ElementView1D<?, ?> tmpValue : values.elements()) {
@@ -518,6 +533,10 @@ public abstract class TestUtils /* extends Assertions */ {
         TestUtils.assertOptimisationResult(message, expected, actual, context, true, false, true, false);
     }
 
+    public static void assertStateInfeasible(final Result actual) {
+        Assertions.assertEquals(Optimisation.State.INFEASIBLE, actual.getState(), actual.toString());
+    }
+
     public static void assertStateLessThanFeasible(final Optimisation.Result actual) {
         Assertions.assertFalse(actual.getState().isFeasible(), actual.toString());
     }
@@ -530,6 +549,14 @@ public abstract class TestUtils /* extends Assertions */ {
         Assertions.assertTrue(actual.getState().isOptimal(), actual.toString());
     }
 
+    public static void assertStateUnbounded(final Result actual) {
+        Assertions.assertEquals(Optimisation.State.UNBOUNDED, actual.getState(), actual.toString());
+    }
+
+    public static void assertStateUnboundedOrLessThanFeasible(final Result actual) {
+        Assertions.assertTrue(!actual.getState().isFeasible() || Optimisation.State.UNBOUNDED.equals(actual.getState()), actual.toString());
+    }
+
     public static void assertTensorEquals(final Tensor<?, ?> expected, final Tensor<?, ?> actual) {
 
         TestUtils.assertEquals(expected.rank(), actual.rank());
@@ -542,6 +569,10 @@ public abstract class TestUtils /* extends Assertions */ {
         }
     }
 
+    public static <T extends Throwable> T assertThrows(final Class<T> expectedType, final Executable executable) {
+        return Assertions.assertThrows(expectedType, executable);
+    }
+
     public static void assertTrue(final boolean condition) {
         Assertions.assertTrue(condition);
     }
