@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -116,12 +116,12 @@ public abstract class PrimitiveBasicArrayTest extends ArrayTests {
 
     @Test
     public void testSegmentedPrimitive() {
-        this.doTest(ArrayR064.FACTORY.makeSegmented(COUNT));
+        this.doTest(new BasicArray.Factory<>(ArrayR064.FACTORY).makeToBeFilled(COUNT));
     }
 
     @Test
     public void testSegmentedSparse() {
-        this.doTest(new BasicArray.Factory<>(ArrayR064.FACTORY).makeSegmented(COUNT));
+        this.doTest(new BasicArray.Factory<>(ArrayR064.FACTORY).makeStructuredZero(COUNT));
     }
 
     @Test
