@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -38,7 +38,7 @@ public class SparsePerformance {
 
     long DIM = 10_000L;
 
-    SparseArray<Double> array;
+    BasicArray<Double> array;
 
     @Benchmark
     public double doTest() {
