@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -199,7 +199,7 @@ public class CaseQR extends MatrixDecompositionTests {
         final int tmpDim = 3;
         final MatrixStore<Double> tmpA = R064Store.FACTORY.makeSPD(tmpDim).below(R064Store.FACTORY.makeIdentity(tmpDim));
 
-        final QR<Double> tmpDenseQR = new QRDecomposition.R064();
+        final QR<Double> tmpDenseQR = new DenseQR.R064();
         final QR<Double> tmpRawQR = new RawQR();
 
         final PhysicalStore<Double> tmpDenseAlloc = tmpDenseQR.preallocate(tmpA);
@@ -283,8 +283,8 @@ public class CaseQR extends MatrixDecompositionTests {
                 BasicLogger.debugMatrix("Q", decomp.getQ());
                 BasicLogger.debugMatrix("R", decomp.getR());
             }
-
-            decomp.ftran(rhs, actual);
+            rhs.supplyTo(actual);
+            decomp.ftran(actual);
 
             TestUtils.assertEquals(solution, actual);
 
@@ -294,8 +294,8 @@ public class CaseQR extends MatrixDecompositionTests {
                 BasicLogger.debugMatrix("Q", decomp.getQ());
                 BasicLogger.debugMatrix("R", decomp.getR());
             }
-
-            decomp.ftran(rhs, expected);
+            rhs.supplyTo(expected);
+            decomp.ftran(expected);
 
             decomp.decompose(body);
 
@@ -303,8 +303,8 @@ public class CaseQR extends MatrixDecompositionTests {
                 BasicLogger.debugMatrix("Q", decomp.getQ());
                 BasicLogger.debugMatrix("R", decomp.getR());
             }
-
-            decomp.btran(rhs, actual);
+            rhs.supplyTo(actual);
+            decomp.btran(actual);
 
             TestUtils.assertEquals(expected, actual);
         }
@@ -335,9 +335,10 @@ public class CaseQR extends MatrixDecompositionTests {
                 BasicLogger.debugMatrix("Q", mtrxQ);
                 BasicLogger.debugMatrix("R", mtrxR);
             }
-
-            decomp.ftran(rhs, expected);
-            decomp.btran(rhs, actual);
+            rhs.supplyTo(expected);
+            decomp.ftran(expected);
+            rhs.supplyTo(actual);
+            decomp.btran(actual);
 
             TestUtils.assertEquals(expected, actual);
         }
