@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -130,8 +130,11 @@ public class TestSolveAndInvert extends MatrixDecompositionTests {
                 BasicLogger.debugMatrix("inverse", decomp.getInverse());
             }
 
-            decomp.ftran(rhs, expected);
-            decomp.btran(rhs, actual);
+            rhs.supplyTo(expected);
+            decomp.ftran(expected);
+
+            rhs.supplyTo(actual);
+            decomp.btran(actual);
 
             TestUtils.assertEquals(name, expected, actual);
         }
@@ -159,18 +162,18 @@ public class TestSolveAndInvert extends MatrixDecompositionTests {
             }
 
             decomp.decompose(body);
-
-            decomp.ftran(rhs, actual);
+            rhs.supplyTo(actual);
+            decomp.ftran(actual);
 
             TestUtils.assertEquals(name, solution, actual);
 
             decomp.decompose(body.transpose());
-
-            decomp.ftran(rhs, expected);
+            rhs.supplyTo(expected);
+            decomp.ftran(expected);
 
             decomp.decompose(body);
-
-            decomp.btran(rhs, actual);
+            rhs.supplyTo(actual);
+            decomp.btran(actual);
 
             TestUtils.assertEquals(name, expected, actual);
         }
