@@ -6,6 +6,8 @@ import org.ojalgo.optimisation.Optimisation.Sense;
 
 public final class OptimisationCase {
 
+    private static final boolean DEBUG = false;
+
     public static OptimisationCase of(final ExpressionsBasedModel model, final Sense sense, final Result result) {
         return new OptimisationCase(model, sense, result);
     }
@@ -22,6 +24,11 @@ public final class OptimisationCase {
     }
 
     public Optimisation.Result assertResult() {
+
+        if (DEBUG) {
+            model.options.debug(Optimisation.Solver.class);
+        }
+
         Optimisation.Result actual = sense.solve(model);
         TestUtils.assertResult(result, actual);
         return actual;
