@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,13 +21,19 @@
  */
 package org.ojalgo.optimisation.integer;
 
+import org.ojalgo.concurrent.Parallelism;
+import org.ojalgo.optimisation.integer.IntegerStrategy.ConfigurableStrategy;
+
 /**
  * OptimisationIntegerPackageTests
  *
  * @author apete
  */
-public abstract class OptimisationIntegerTests {
+abstract class OptimisationIntegerTests {
 
     static final boolean DEBUG = false;
 
+    static final ConfigurableStrategy SIMPLE_FIFO_STRATEGY = IntegerStrategy.DEFAULT.withPriorityDefinitions(NodeKey.FIFO_SEQUENCE)
+            .withParallelism(Parallelism.ONE);
+
 }
