@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,37 +22,50 @@
 package org.ojalgo.optimisation.linear;
 
 import java.util.List;
-import java.util.Map;
 import java.util.function.Function;
 
 import org.ojalgo.optimisation.ExpressionsBasedModel;
+import org.ojalgo.type.keyvalue.KeyValue;
 
 abstract class OptimisationLinearTests {
 
     static final boolean DEBUG = false;
 
-    static final Map<String, ExpressionsBasedModel.Integration<LinearSolver>> INTEGRATIONS = Map.of("Standard-Default",
-            LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
-                opt.experimental = false;
-                opt.sparse = null;
-            }), "Standard-Dense", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
-                opt.experimental = false;
-                opt.sparse = Boolean.FALSE;
-            }), "Standard-Sparse", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
-                opt.experimental = false;
-                opt.sparse = Boolean.TRUE;
-            }), "Experimental-Default", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
-                opt.experimental = true;
-                opt.sparse = null;
-            }), "Experimental-Dense", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
-                opt.experimental = true;
-                opt.sparse = Boolean.FALSE;
-            }), "Experimental-Sparse", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
-                opt.experimental = true;
-                opt.sparse = Boolean.TRUE;
-            }));
+    // static final List<KeyValue<String, ExpressionsBasedModel.Integration<LinearSolver>>> INTEGRATIONS =
+    // List
+    // .of(KeyValue.of("Dual-Sparse", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+    // opt.linear().dual();
+    // opt.sparse = Boolean.TRUE;
+    // })));
 
-    static final List<Function<LinearStructure, SimplexStore>> STORE_FACTORIES = List.of(DenseTableau::new, RevisedStore::new, SparseTableau::new);
+    static final List<KeyValue<String, ExpressionsBasedModel.Integration<LinearSolver>>> INTEGRATIONS = List
+            .of(KeyValue.of("Dual-Sparse", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+                opt.linear().dual();
+                opt.sparse = Boolean.TRUE;
+            })), KeyValue.of("Dual-Default", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+                opt.linear().dual();
+                opt.sparse = null;
+            })), KeyValue.of("Dual-Dense", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+                opt.linear().dual();
+                opt.sparse = Boolean.FALSE;
+            })), KeyValue.of("Primal-Default", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+                opt.linear().primal();
+                opt.sparse = null;
+            })), KeyValue.of("Primal-Dense", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+                opt.linear().primal();
+                opt.sparse = Boolean.FALSE;
+            })), KeyValue.of("Primal-Sparse", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+                opt.linear().primal();
+                opt.sparse = Boolean.TRUE;
+            })), KeyValue.of("Default-Default", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+                opt.sparse = null;
+            })), KeyValue.of("Default-Dense", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+                opt.sparse = Boolean.FALSE;
+            })), KeyValue.of("Default-Sparse", LinearSolver.INTEGRATION.withOptionsModifier(opt -> {
+                opt.sparse = Boolean.TRUE;
+            })));
+
+    static final List<Function<LinearStructure, SimplexStore>> STORE_FACTORIES = List.of(RevisedStore::new, DenseTableau::new, SparseTableau::new);
 
     static final List<Function<LinearStructure, SimplexTableau>> TABLEAU_FACTORIES = List.of(DenseTableau::new, SparseTableau::new);
 
