@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2024 Optimatika
+ * Copyright 1997-2025 Optimatika
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -72,37 +72,44 @@ public class ProductFormInverseTest extends OptimisationLinearTests {
         R064Store act = R064Store.FACTORY.make(3, 1);
 
         LU<Double> lu = LU.R064.make();
-        ProductFormInverse factors = new ProductFormInverse(3, 1E-32);
         lu.decompose(expBase0);
-
-        lu.ftran(random, exp);
-        factors.ftran(random, act);
+        ProductFormInverse factors = new ProductFormInverse(3, 1E-32);
+        factors.reset(expBase0);
+        random.supplyTo(exp);
+        lu.ftran(exp);
+        random.supplyTo(act);
+        factors.ftran(act);
         TestUtils.assertEquals(exp, act);
-
-        lu.btran(random, exp);
-        factors.btran(random, act);
+        random.supplyTo(exp);
+        lu.btran(exp);
+        random.supplyTo(act);
+        factors.btran(act);
         TestUtils.assertEquals(exp, act);
 
         lu.decompose(expBase1);
         factors.update(expBase1, 2, arr0);
-
-        lu.ftran(random, exp);
-        factors.ftran(random, act);
+        random.supplyTo(exp);
+        lu.ftran(exp);
+        random.supplyTo(act);
+        factors.ftran(act);
         TestUtils.assertEquals(exp, act);
-
-        lu.btran(random, exp);
-        factors.btran(random, act);
+        random.supplyTo(exp);
+        lu.btran(exp);
+        random.supplyTo(act);
+        factors.btran(act);
         TestUtils.assertEquals(exp, act);
 
         lu.decompose(expBase2);
         factors.update(expBase2, 1, arr2);
-
-        lu.ftran(random, exp);
-        factors.ftran(random, act);
+        random.supplyTo(exp);
+        lu.ftran(exp);
+        random.supplyTo(act);
+        factors.ftran(act);
         TestUtils.assertEquals(exp, act);
-
-        lu.btran(random, exp);
-        factors.btran(random, act);
+        random.supplyTo(exp);
+        lu.btran(exp);
+        random.supplyTo(act);
+        factors.btran(act);
         TestUtils.assertEquals(exp, act);
     }
 
